/* This file was generated by bstone_glapigen v1.0.0. */

#include "bstone_gl_r3r_api.h"

GLenum GL_ACTIVE_PROGRAM_EXT = 0; /* gles2=0x8259; gl=0x8B8D */

PFNGLACCUMPROC glAccum = 0;
PFNGLACCUMXOESPROC glAccumxOES = 0;
PFNGLACTIVEPROGRAMEXTPROC glActiveProgramEXT = 0;
PFNGLACTIVESHADERPROGRAMPROC glActiveShaderProgram = 0;
PFNGLACTIVESHADERPROGRAMEXTPROC glActiveShaderProgramEXT = 0;
PFNGLACTIVESTENCILFACEEXTPROC glActiveStencilFaceEXT = 0;
PFNGLACTIVETEXTUREPROC glActiveTexture = 0;
PFNGLACTIVETEXTUREARBPROC glActiveTextureARB = 0;
PFNGLACTIVEVARYINGNVPROC glActiveVaryingNV = 0;
PFNGLALPHAFRAGMENTOP1ATIPROC glAlphaFragmentOp1ATI = 0;
PFNGLALPHAFRAGMENTOP2ATIPROC glAlphaFragmentOp2ATI = 0;
PFNGLALPHAFRAGMENTOP3ATIPROC glAlphaFragmentOp3ATI = 0;
PFNGLALPHAFUNCPROC glAlphaFunc = 0;
PFNGLALPHAFUNCQCOMPROC glAlphaFuncQCOM = 0;
PFNGLALPHAFUNCXPROC glAlphaFuncx = 0;
PFNGLALPHAFUNCXOESPROC glAlphaFuncxOES = 0;
PFNGLALPHATOCOVERAGEDITHERCONTROLNVPROC glAlphaToCoverageDitherControlNV = 0;
PFNGLAPPLYFRAMEBUFFERATTACHMENTCMAAINTELPROC glApplyFramebufferAttachmentCMAAINTEL = 0;
PFNGLAPPLYTEXTUREEXTPROC glApplyTextureEXT = 0;
PFNGLACQUIREKEYEDMUTEXWIN32EXTPROC glAcquireKeyedMutexWin32EXT = 0;
PFNGLAREPROGRAMSRESIDENTNVPROC glAreProgramsResidentNV = 0;
PFNGLARETEXTURESRESIDENTPROC glAreTexturesResident = 0;
PFNGLARETEXTURESRESIDENTEXTPROC glAreTexturesResidentEXT = 0;
PFNGLARRAYELEMENTPROC glArrayElement = 0;
PFNGLARRAYELEMENTEXTPROC glArrayElementEXT = 0;
PFNGLARRAYOBJECTATIPROC glArrayObjectATI = 0;
PFNGLASYNCCOPYBUFFERSUBDATANVXPROC glAsyncCopyBufferSubDataNVX = 0;
PFNGLASYNCCOPYIMAGESUBDATANVXPROC glAsyncCopyImageSubDataNVX = 0;
PFNGLASYNCMARKERSGIXPROC glAsyncMarkerSGIX = 0;
PFNGLATTACHOBJECTARBPROC glAttachObjectARB = 0;
PFNGLATTACHSHADERPROC glAttachShader = 0;
PFNGLBEGINPROC glBegin = 0;
PFNGLBEGINCONDITIONALRENDERPROC glBeginConditionalRender = 0;
PFNGLBEGINCONDITIONALRENDERNVPROC glBeginConditionalRenderNV = 0;
PFNGLBEGINCONDITIONALRENDERNVXPROC glBeginConditionalRenderNVX = 0;
PFNGLBEGINFRAGMENTSHADERATIPROC glBeginFragmentShaderATI = 0;
PFNGLBEGINOCCLUSIONQUERYNVPROC glBeginOcclusionQueryNV = 0;
PFNGLBEGINPERFMONITORAMDPROC glBeginPerfMonitorAMD = 0;
PFNGLBEGINPERFQUERYINTELPROC glBeginPerfQueryINTEL = 0;
PFNGLBEGINQUERYPROC glBeginQuery = 0;
PFNGLBEGINQUERYARBPROC glBeginQueryARB = 0;
PFNGLBEGINQUERYEXTPROC glBeginQueryEXT = 0;
PFNGLBEGINQUERYINDEXEDPROC glBeginQueryIndexed = 0;
PFNGLBEGINTRANSFORMFEEDBACKPROC glBeginTransformFeedback = 0;
PFNGLBEGINTRANSFORMFEEDBACKEXTPROC glBeginTransformFeedbackEXT = 0;
PFNGLBEGINTRANSFORMFEEDBACKNVPROC glBeginTransformFeedbackNV = 0;
PFNGLBEGINVERTEXSHADEREXTPROC glBeginVertexShaderEXT = 0;
PFNGLBEGINVIDEOCAPTURENVPROC glBeginVideoCaptureNV = 0;
PFNGLBINDATTRIBLOCATIONPROC glBindAttribLocation = 0;
PFNGLBINDATTRIBLOCATIONARBPROC glBindAttribLocationARB = 0;
PFNGLBINDBUFFERPROC glBindBuffer = 0;
PFNGLBINDBUFFERARBPROC glBindBufferARB = 0;
PFNGLBINDBUFFERBASEPROC glBindBufferBase = 0;
PFNGLBINDBUFFERBASEEXTPROC glBindBufferBaseEXT = 0;
PFNGLBINDBUFFERBASENVPROC glBindBufferBaseNV = 0;
PFNGLBINDBUFFEROFFSETEXTPROC glBindBufferOffsetEXT = 0;
PFNGLBINDBUFFEROFFSETNVPROC glBindBufferOffsetNV = 0;
PFNGLBINDBUFFERRANGEPROC glBindBufferRange = 0;
PFNGLBINDBUFFERRANGEEXTPROC glBindBufferRangeEXT = 0;
PFNGLBINDBUFFERRANGENVPROC glBindBufferRangeNV = 0;
PFNGLBINDBUFFERSBASEPROC glBindBuffersBase = 0;
PFNGLBINDBUFFERSRANGEPROC glBindBuffersRange = 0;
PFNGLBINDFRAGDATALOCATIONPROC glBindFragDataLocation = 0;
PFNGLBINDFRAGDATALOCATIONEXTPROC glBindFragDataLocationEXT = 0;
PFNGLBINDFRAGDATALOCATIONINDEXEDPROC glBindFragDataLocationIndexed = 0;
PFNGLBINDFRAGDATALOCATIONINDEXEDEXTPROC glBindFragDataLocationIndexedEXT = 0;
PFNGLBINDFRAGMENTSHADERATIPROC glBindFragmentShaderATI = 0;
PFNGLBINDFRAMEBUFFERPROC glBindFramebuffer = 0;
PFNGLBINDFRAMEBUFFEREXTPROC glBindFramebufferEXT = 0;
PFNGLBINDFRAMEBUFFEROESPROC glBindFramebufferOES = 0;
PFNGLBINDIMAGETEXTUREPROC glBindImageTexture = 0;
PFNGLBINDIMAGETEXTUREEXTPROC glBindImageTextureEXT = 0;
PFNGLBINDIMAGETEXTURESPROC glBindImageTextures = 0;
PFNGLBINDLIGHTPARAMETEREXTPROC glBindLightParameterEXT = 0;
PFNGLBINDMATERIALPARAMETEREXTPROC glBindMaterialParameterEXT = 0;
PFNGLBINDMULTITEXTUREEXTPROC glBindMultiTextureEXT = 0;
PFNGLBINDPARAMETEREXTPROC glBindParameterEXT = 0;
PFNGLBINDPROGRAMARBPROC glBindProgramARB = 0;
PFNGLBINDPROGRAMNVPROC glBindProgramNV = 0;
PFNGLBINDPROGRAMPIPELINEPROC glBindProgramPipeline = 0;
PFNGLBINDPROGRAMPIPELINEEXTPROC glBindProgramPipelineEXT = 0;
PFNGLBINDRENDERBUFFERPROC glBindRenderbuffer = 0;
PFNGLBINDRENDERBUFFEREXTPROC glBindRenderbufferEXT = 0;
PFNGLBINDRENDERBUFFEROESPROC glBindRenderbufferOES = 0;
PFNGLBINDSAMPLERPROC glBindSampler = 0;
PFNGLBINDSAMPLERSPROC glBindSamplers = 0;
PFNGLBINDSHADINGRATEIMAGENVPROC glBindShadingRateImageNV = 0;
PFNGLBINDTEXGENPARAMETEREXTPROC glBindTexGenParameterEXT = 0;
PFNGLBINDTEXTUREPROC glBindTexture = 0;
PFNGLBINDTEXTUREEXTPROC glBindTextureEXT = 0;
PFNGLBINDTEXTUREUNITPROC glBindTextureUnit = 0;
PFNGLBINDTEXTUREUNITPARAMETEREXTPROC glBindTextureUnitParameterEXT = 0;
PFNGLBINDTEXTURESPROC glBindTextures = 0;
PFNGLBINDTRANSFORMFEEDBACKPROC glBindTransformFeedback = 0;
PFNGLBINDTRANSFORMFEEDBACKNVPROC glBindTransformFeedbackNV = 0;
PFNGLBINDVERTEXARRAYPROC glBindVertexArray = 0;
PFNGLBINDVERTEXARRAYAPPLEPROC glBindVertexArrayAPPLE = 0;
PFNGLBINDVERTEXARRAYOESPROC glBindVertexArrayOES = 0;
PFNGLBINDVERTEXBUFFERPROC glBindVertexBuffer = 0;
PFNGLBINDVERTEXBUFFERSPROC glBindVertexBuffers = 0;
PFNGLBINDVERTEXSHADEREXTPROC glBindVertexShaderEXT = 0;
PFNGLBINDVIDEOCAPTURESTREAMBUFFERNVPROC glBindVideoCaptureStreamBufferNV = 0;
PFNGLBINDVIDEOCAPTURESTREAMTEXTURENVPROC glBindVideoCaptureStreamTextureNV = 0;
PFNGLBINORMAL3BEXTPROC glBinormal3bEXT = 0;
PFNGLBINORMAL3BVEXTPROC glBinormal3bvEXT = 0;
PFNGLBINORMAL3DEXTPROC glBinormal3dEXT = 0;
PFNGLBINORMAL3DVEXTPROC glBinormal3dvEXT = 0;
PFNGLBINORMAL3FEXTPROC glBinormal3fEXT = 0;
PFNGLBINORMAL3FVEXTPROC glBinormal3fvEXT = 0;
PFNGLBINORMAL3IEXTPROC glBinormal3iEXT = 0;
PFNGLBINORMAL3IVEXTPROC glBinormal3ivEXT = 0;
PFNGLBINORMAL3SEXTPROC glBinormal3sEXT = 0;
PFNGLBINORMAL3SVEXTPROC glBinormal3svEXT = 0;
PFNGLBINORMALPOINTEREXTPROC glBinormalPointerEXT = 0;
PFNGLBITMAPPROC glBitmap = 0;
PFNGLBITMAPXOESPROC glBitmapxOES = 0;
PFNGLBLENDBARRIERPROC glBlendBarrier = 0;
PFNGLBLENDBARRIERKHRPROC glBlendBarrierKHR = 0;
PFNGLBLENDBARRIERNVPROC glBlendBarrierNV = 0;
PFNGLBLENDCOLORPROC glBlendColor = 0;
PFNGLBLENDCOLOREXTPROC glBlendColorEXT = 0;
PFNGLBLENDCOLORXOESPROC glBlendColorxOES = 0;
PFNGLBLENDEQUATIONPROC glBlendEquation = 0;
PFNGLBLENDEQUATIONEXTPROC glBlendEquationEXT = 0;
PFNGLBLENDEQUATIONINDEXEDAMDPROC glBlendEquationIndexedAMD = 0;
PFNGLBLENDEQUATIONOESPROC glBlendEquationOES = 0;
PFNGLBLENDEQUATIONSEPARATEPROC glBlendEquationSeparate = 0;
PFNGLBLENDEQUATIONSEPARATEEXTPROC glBlendEquationSeparateEXT = 0;
PFNGLBLENDEQUATIONSEPARATEINDEXEDAMDPROC glBlendEquationSeparateIndexedAMD = 0;
PFNGLBLENDEQUATIONSEPARATEOESPROC glBlendEquationSeparateOES = 0;
PFNGLBLENDEQUATIONSEPARATEIPROC glBlendEquationSeparatei = 0;
PFNGLBLENDEQUATIONSEPARATEIARBPROC glBlendEquationSeparateiARB = 0;
PFNGLBLENDEQUATIONSEPARATEIEXTPROC glBlendEquationSeparateiEXT = 0;
PFNGLBLENDEQUATIONSEPARATEIOESPROC glBlendEquationSeparateiOES = 0;
PFNGLBLENDEQUATIONIPROC glBlendEquationi = 0;
PFNGLBLENDEQUATIONIARBPROC glBlendEquationiARB = 0;
PFNGLBLENDEQUATIONIEXTPROC glBlendEquationiEXT = 0;
PFNGLBLENDEQUATIONIOESPROC glBlendEquationiOES = 0;
PFNGLBLENDFUNCPROC glBlendFunc = 0;
PFNGLBLENDFUNCINDEXEDAMDPROC glBlendFuncIndexedAMD = 0;
PFNGLBLENDFUNCSEPARATEPROC glBlendFuncSeparate = 0;
PFNGLBLENDFUNCSEPARATEEXTPROC glBlendFuncSeparateEXT = 0;
PFNGLBLENDFUNCSEPARATEINGRPROC glBlendFuncSeparateINGR = 0;
PFNGLBLENDFUNCSEPARATEINDEXEDAMDPROC glBlendFuncSeparateIndexedAMD = 0;
PFNGLBLENDFUNCSEPARATEOESPROC glBlendFuncSeparateOES = 0;
PFNGLBLENDFUNCSEPARATEIPROC glBlendFuncSeparatei = 0;
PFNGLBLENDFUNCSEPARATEIARBPROC glBlendFuncSeparateiARB = 0;
PFNGLBLENDFUNCSEPARATEIEXTPROC glBlendFuncSeparateiEXT = 0;
PFNGLBLENDFUNCSEPARATEIOESPROC glBlendFuncSeparateiOES = 0;
PFNGLBLENDFUNCIPROC glBlendFunci = 0;
PFNGLBLENDFUNCIARBPROC glBlendFunciARB = 0;
PFNGLBLENDFUNCIEXTPROC glBlendFunciEXT = 0;
PFNGLBLENDFUNCIOESPROC glBlendFunciOES = 0;
PFNGLBLENDPARAMETERINVPROC glBlendParameteriNV = 0;
PFNGLBLITFRAMEBUFFERPROC glBlitFramebuffer = 0;
PFNGLBLITFRAMEBUFFERANGLEPROC glBlitFramebufferANGLE = 0;
PFNGLBLITFRAMEBUFFEREXTPROC glBlitFramebufferEXT = 0;
PFNGLBLITFRAMEBUFFERLAYEREXTPROC glBlitFramebufferLayerEXT = 0;
PFNGLBLITFRAMEBUFFERLAYERSEXTPROC glBlitFramebufferLayersEXT = 0;
PFNGLBLITFRAMEBUFFERNVPROC glBlitFramebufferNV = 0;
PFNGLBLITNAMEDFRAMEBUFFERPROC glBlitNamedFramebuffer = 0;
PFNGLBUFFERADDRESSRANGENVPROC glBufferAddressRangeNV = 0;
PFNGLBUFFERATTACHMEMORYNVPROC glBufferAttachMemoryNV = 0;
PFNGLBUFFERDATAPROC glBufferData = 0;
PFNGLBUFFERDATAARBPROC glBufferDataARB = 0;
PFNGLBUFFERPAGECOMMITMENTARBPROC glBufferPageCommitmentARB = 0;
PFNGLBUFFERPAGECOMMITMENTMEMNVPROC glBufferPageCommitmentMemNV = 0;
PFNGLBUFFERPARAMETERIAPPLEPROC glBufferParameteriAPPLE = 0;
PFNGLBUFFERSTORAGEPROC glBufferStorage = 0;
PFNGLBUFFERSTORAGEEXTPROC glBufferStorageEXT = 0;
PFNGLBUFFERSTORAGEEXTERNALEXTPROC glBufferStorageExternalEXT = 0;
PFNGLBUFFERSTORAGEMEMEXTPROC glBufferStorageMemEXT = 0;
PFNGLBUFFERSUBDATAPROC glBufferSubData = 0;
PFNGLBUFFERSUBDATAARBPROC glBufferSubDataARB = 0;
PFNGLCALLCOMMANDLISTNVPROC glCallCommandListNV = 0;
PFNGLCALLLISTPROC glCallList = 0;
PFNGLCALLLISTSPROC glCallLists = 0;
PFNGLCHECKFRAMEBUFFERSTATUSPROC glCheckFramebufferStatus = 0;
PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC glCheckFramebufferStatusEXT = 0;
PFNGLCHECKFRAMEBUFFERSTATUSOESPROC glCheckFramebufferStatusOES = 0;
PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC glCheckNamedFramebufferStatus = 0;
PFNGLCHECKNAMEDFRAMEBUFFERSTATUSEXTPROC glCheckNamedFramebufferStatusEXT = 0;
PFNGLCLAMPCOLORPROC glClampColor = 0;
PFNGLCLAMPCOLORARBPROC glClampColorARB = 0;
PFNGLCLEARPROC glClear = 0;
PFNGLCLEARACCUMPROC glClearAccum = 0;
PFNGLCLEARACCUMXOESPROC glClearAccumxOES = 0;
PFNGLCLEARBUFFERDATAPROC glClearBufferData = 0;
PFNGLCLEARBUFFERSUBDATAPROC glClearBufferSubData = 0;
PFNGLCLEARBUFFERFIPROC glClearBufferfi = 0;
PFNGLCLEARBUFFERFVPROC glClearBufferfv = 0;
PFNGLCLEARBUFFERIVPROC glClearBufferiv = 0;
PFNGLCLEARBUFFERUIVPROC glClearBufferuiv = 0;
PFNGLCLEARCOLORPROC glClearColor = 0;
PFNGLCLEARCOLORIIEXTPROC glClearColorIiEXT = 0;
PFNGLCLEARCOLORIUIEXTPROC glClearColorIuiEXT = 0;
PFNGLCLEARCOLORXPROC glClearColorx = 0;
PFNGLCLEARCOLORXOESPROC glClearColorxOES = 0;
PFNGLCLEARDEPTHPROC glClearDepth = 0;
PFNGLCLEARDEPTHDNVPROC glClearDepthdNV = 0;
PFNGLCLEARDEPTHFPROC glClearDepthf = 0;
PFNGLCLEARDEPTHFOESPROC glClearDepthfOES = 0;
PFNGLCLEARDEPTHXPROC glClearDepthx = 0;
PFNGLCLEARDEPTHXOESPROC glClearDepthxOES = 0;
PFNGLCLEARINDEXPROC glClearIndex = 0;
PFNGLCLEARNAMEDBUFFERDATAPROC glClearNamedBufferData = 0;
PFNGLCLEARNAMEDBUFFERDATAEXTPROC glClearNamedBufferDataEXT = 0;
PFNGLCLEARNAMEDBUFFERSUBDATAPROC glClearNamedBufferSubData = 0;
PFNGLCLEARNAMEDBUFFERSUBDATAEXTPROC glClearNamedBufferSubDataEXT = 0;
PFNGLCLEARNAMEDFRAMEBUFFERFIPROC glClearNamedFramebufferfi = 0;
PFNGLCLEARNAMEDFRAMEBUFFERFVPROC glClearNamedFramebufferfv = 0;
PFNGLCLEARNAMEDFRAMEBUFFERIVPROC glClearNamedFramebufferiv = 0;
PFNGLCLEARNAMEDFRAMEBUFFERUIVPROC glClearNamedFramebufferuiv = 0;
PFNGLCLEARPIXELLOCALSTORAGEUIEXTPROC glClearPixelLocalStorageuiEXT = 0;
PFNGLCLEARSTENCILPROC glClearStencil = 0;
PFNGLCLEARTEXIMAGEPROC glClearTexImage = 0;
PFNGLCLEARTEXIMAGEEXTPROC glClearTexImageEXT = 0;
PFNGLCLEARTEXSUBIMAGEPROC glClearTexSubImage = 0;
PFNGLCLEARTEXSUBIMAGEEXTPROC glClearTexSubImageEXT = 0;
PFNGLCLIENTACTIVETEXTUREPROC glClientActiveTexture = 0;
PFNGLCLIENTACTIVETEXTUREARBPROC glClientActiveTextureARB = 0;
PFNGLCLIENTACTIVEVERTEXSTREAMATIPROC glClientActiveVertexStreamATI = 0;
PFNGLCLIENTATTRIBDEFAULTEXTPROC glClientAttribDefaultEXT = 0;
PFNGLCLIENTWAITSEMAPHOREUI64NVXPROC glClientWaitSemaphoreui64NVX = 0;
PFNGLCLIENTWAITSYNCPROC glClientWaitSync = 0;
PFNGLCLIENTWAITSYNCAPPLEPROC glClientWaitSyncAPPLE = 0;
PFNGLCLIPCONTROLPROC glClipControl = 0;
PFNGLCLIPCONTROLEXTPROC glClipControlEXT = 0;
PFNGLCLIPPLANEPROC glClipPlane = 0;
PFNGLCLIPPLANEFPROC glClipPlanef = 0;
PFNGLCLIPPLANEFIMGPROC glClipPlanefIMG = 0;
PFNGLCLIPPLANEFOESPROC glClipPlanefOES = 0;
PFNGLCLIPPLANEXPROC glClipPlanex = 0;
PFNGLCLIPPLANEXIMGPROC glClipPlanexIMG = 0;
PFNGLCLIPPLANEXOESPROC glClipPlanexOES = 0;
PFNGLCOLOR3BPROC glColor3b = 0;
PFNGLCOLOR3BVPROC glColor3bv = 0;
PFNGLCOLOR3DPROC glColor3d = 0;
PFNGLCOLOR3DVPROC glColor3dv = 0;
PFNGLCOLOR3FPROC glColor3f = 0;
PFNGLCOLOR3FVERTEX3FSUNPROC glColor3fVertex3fSUN = 0;
PFNGLCOLOR3FVERTEX3FVSUNPROC glColor3fVertex3fvSUN = 0;
PFNGLCOLOR3FVPROC glColor3fv = 0;
PFNGLCOLOR3HNVPROC glColor3hNV = 0;
PFNGLCOLOR3HVNVPROC glColor3hvNV = 0;
PFNGLCOLOR3IPROC glColor3i = 0;
PFNGLCOLOR3IVPROC glColor3iv = 0;
PFNGLCOLOR3SPROC glColor3s = 0;
PFNGLCOLOR3SVPROC glColor3sv = 0;
PFNGLCOLOR3UBPROC glColor3ub = 0;
PFNGLCOLOR3UBVPROC glColor3ubv = 0;
PFNGLCOLOR3UIPROC glColor3ui = 0;
PFNGLCOLOR3UIVPROC glColor3uiv = 0;
PFNGLCOLOR3USPROC glColor3us = 0;
PFNGLCOLOR3USVPROC glColor3usv = 0;
PFNGLCOLOR3XOESPROC glColor3xOES = 0;
PFNGLCOLOR3XVOESPROC glColor3xvOES = 0;
PFNGLCOLOR4BPROC glColor4b = 0;
PFNGLCOLOR4BVPROC glColor4bv = 0;
PFNGLCOLOR4DPROC glColor4d = 0;
PFNGLCOLOR4DVPROC glColor4dv = 0;
PFNGLCOLOR4FPROC glColor4f = 0;
PFNGLCOLOR4FNORMAL3FVERTEX3FSUNPROC glColor4fNormal3fVertex3fSUN = 0;
PFNGLCOLOR4FNORMAL3FVERTEX3FVSUNPROC glColor4fNormal3fVertex3fvSUN = 0;
PFNGLCOLOR4FVPROC glColor4fv = 0;
PFNGLCOLOR4HNVPROC glColor4hNV = 0;
PFNGLCOLOR4HVNVPROC glColor4hvNV = 0;
PFNGLCOLOR4IPROC glColor4i = 0;
PFNGLCOLOR4IVPROC glColor4iv = 0;
PFNGLCOLOR4SPROC glColor4s = 0;
PFNGLCOLOR4SVPROC glColor4sv = 0;
PFNGLCOLOR4UBPROC glColor4ub = 0;
PFNGLCOLOR4UBVERTEX2FSUNPROC glColor4ubVertex2fSUN = 0;
PFNGLCOLOR4UBVERTEX2FVSUNPROC glColor4ubVertex2fvSUN = 0;
PFNGLCOLOR4UBVERTEX3FSUNPROC glColor4ubVertex3fSUN = 0;
PFNGLCOLOR4UBVERTEX3FVSUNPROC glColor4ubVertex3fvSUN = 0;
PFNGLCOLOR4UBVPROC glColor4ubv = 0;
PFNGLCOLOR4UIPROC glColor4ui = 0;
PFNGLCOLOR4UIVPROC glColor4uiv = 0;
PFNGLCOLOR4USPROC glColor4us = 0;
PFNGLCOLOR4USVPROC glColor4usv = 0;
PFNGLCOLOR4XPROC glColor4x = 0;
PFNGLCOLOR4XOESPROC glColor4xOES = 0;
PFNGLCOLOR4XVOESPROC glColor4xvOES = 0;
PFNGLCOLORFORMATNVPROC glColorFormatNV = 0;
PFNGLCOLORFRAGMENTOP1ATIPROC glColorFragmentOp1ATI = 0;
PFNGLCOLORFRAGMENTOP2ATIPROC glColorFragmentOp2ATI = 0;
PFNGLCOLORFRAGMENTOP3ATIPROC glColorFragmentOp3ATI = 0;
PFNGLCOLORMASKPROC glColorMask = 0;
PFNGLCOLORMASKINDEXEDEXTPROC glColorMaskIndexedEXT = 0;
PFNGLCOLORMASKIPROC glColorMaski = 0;
PFNGLCOLORMASKIEXTPROC glColorMaskiEXT = 0;
PFNGLCOLORMASKIOESPROC glColorMaskiOES = 0;
PFNGLCOLORMATERIALPROC glColorMaterial = 0;
PFNGLCOLORP3UIPROC glColorP3ui = 0;
PFNGLCOLORP3UIVPROC glColorP3uiv = 0;
PFNGLCOLORP4UIPROC glColorP4ui = 0;
PFNGLCOLORP4UIVPROC glColorP4uiv = 0;
PFNGLCOLORPOINTERPROC glColorPointer = 0;
PFNGLCOLORPOINTEREXTPROC glColorPointerEXT = 0;
PFNGLCOLORPOINTERLISTIBMPROC glColorPointerListIBM = 0;
PFNGLCOLORPOINTERVINTELPROC glColorPointervINTEL = 0;
PFNGLCOLORSUBTABLEPROC glColorSubTable = 0;
PFNGLCOLORSUBTABLEEXTPROC glColorSubTableEXT = 0;
PFNGLCOLORTABLEPROC glColorTable = 0;
PFNGLCOLORTABLEEXTPROC glColorTableEXT = 0;
PFNGLCOLORTABLEPARAMETERFVPROC glColorTableParameterfv = 0;
PFNGLCOLORTABLEPARAMETERFVSGIPROC glColorTableParameterfvSGI = 0;
PFNGLCOLORTABLEPARAMETERIVPROC glColorTableParameteriv = 0;
PFNGLCOLORTABLEPARAMETERIVSGIPROC glColorTableParameterivSGI = 0;
PFNGLCOLORTABLESGIPROC glColorTableSGI = 0;
PFNGLCOMBINERINPUTNVPROC glCombinerInputNV = 0;
PFNGLCOMBINEROUTPUTNVPROC glCombinerOutputNV = 0;
PFNGLCOMBINERPARAMETERFNVPROC glCombinerParameterfNV = 0;
PFNGLCOMBINERPARAMETERFVNVPROC glCombinerParameterfvNV = 0;
PFNGLCOMBINERPARAMETERINVPROC glCombinerParameteriNV = 0;
PFNGLCOMBINERPARAMETERIVNVPROC glCombinerParameterivNV = 0;
PFNGLCOMBINERSTAGEPARAMETERFVNVPROC glCombinerStageParameterfvNV = 0;
PFNGLCOMMANDLISTSEGMENTSNVPROC glCommandListSegmentsNV = 0;
PFNGLCOMPILECOMMANDLISTNVPROC glCompileCommandListNV = 0;
PFNGLCOMPILESHADERPROC glCompileShader = 0;
PFNGLCOMPILESHADERARBPROC glCompileShaderARB = 0;
PFNGLCOMPILESHADERINCLUDEARBPROC glCompileShaderIncludeARB = 0;
PFNGLCOMPRESSEDMULTITEXIMAGE1DEXTPROC glCompressedMultiTexImage1DEXT = 0;
PFNGLCOMPRESSEDMULTITEXIMAGE2DEXTPROC glCompressedMultiTexImage2DEXT = 0;
PFNGLCOMPRESSEDMULTITEXIMAGE3DEXTPROC glCompressedMultiTexImage3DEXT = 0;
PFNGLCOMPRESSEDMULTITEXSUBIMAGE1DEXTPROC glCompressedMultiTexSubImage1DEXT = 0;
PFNGLCOMPRESSEDMULTITEXSUBIMAGE2DEXTPROC glCompressedMultiTexSubImage2DEXT = 0;
PFNGLCOMPRESSEDMULTITEXSUBIMAGE3DEXTPROC glCompressedMultiTexSubImage3DEXT = 0;
PFNGLCOMPRESSEDTEXIMAGE1DPROC glCompressedTexImage1D = 0;
PFNGLCOMPRESSEDTEXIMAGE1DARBPROC glCompressedTexImage1DARB = 0;
PFNGLCOMPRESSEDTEXIMAGE2DPROC glCompressedTexImage2D = 0;
PFNGLCOMPRESSEDTEXIMAGE2DARBPROC glCompressedTexImage2DARB = 0;
PFNGLCOMPRESSEDTEXIMAGE3DPROC glCompressedTexImage3D = 0;
PFNGLCOMPRESSEDTEXIMAGE3DARBPROC glCompressedTexImage3DARB = 0;
PFNGLCOMPRESSEDTEXIMAGE3DOESPROC glCompressedTexImage3DOES = 0;
PFNGLCOMPRESSEDTEXSUBIMAGE1DPROC glCompressedTexSubImage1D = 0;
PFNGLCOMPRESSEDTEXSUBIMAGE1DARBPROC glCompressedTexSubImage1DARB = 0;
PFNGLCOMPRESSEDTEXSUBIMAGE2DPROC glCompressedTexSubImage2D = 0;
PFNGLCOMPRESSEDTEXSUBIMAGE2DARBPROC glCompressedTexSubImage2DARB = 0;
PFNGLCOMPRESSEDTEXSUBIMAGE3DPROC glCompressedTexSubImage3D = 0;
PFNGLCOMPRESSEDTEXSUBIMAGE3DARBPROC glCompressedTexSubImage3DARB = 0;
PFNGLCOMPRESSEDTEXSUBIMAGE3DOESPROC glCompressedTexSubImage3DOES = 0;
PFNGLCOMPRESSEDTEXTUREIMAGE1DEXTPROC glCompressedTextureImage1DEXT = 0;
PFNGLCOMPRESSEDTEXTUREIMAGE2DEXTPROC glCompressedTextureImage2DEXT = 0;
PFNGLCOMPRESSEDTEXTUREIMAGE3DEXTPROC glCompressedTextureImage3DEXT = 0;
PFNGLCOMPRESSEDTEXTURESUBIMAGE1DPROC glCompressedTextureSubImage1D = 0;
PFNGLCOMPRESSEDTEXTURESUBIMAGE1DEXTPROC glCompressedTextureSubImage1DEXT = 0;
PFNGLCOMPRESSEDTEXTURESUBIMAGE2DPROC glCompressedTextureSubImage2D = 0;
PFNGLCOMPRESSEDTEXTURESUBIMAGE2DEXTPROC glCompressedTextureSubImage2DEXT = 0;
PFNGLCOMPRESSEDTEXTURESUBIMAGE3DPROC glCompressedTextureSubImage3D = 0;
PFNGLCOMPRESSEDTEXTURESUBIMAGE3DEXTPROC glCompressedTextureSubImage3DEXT = 0;
PFNGLCONSERVATIVERASTERPARAMETERFNVPROC glConservativeRasterParameterfNV = 0;
PFNGLCONSERVATIVERASTERPARAMETERINVPROC glConservativeRasterParameteriNV = 0;
PFNGLCONVOLUTIONFILTER1DPROC glConvolutionFilter1D = 0;
PFNGLCONVOLUTIONFILTER1DEXTPROC glConvolutionFilter1DEXT = 0;
PFNGLCONVOLUTIONFILTER2DPROC glConvolutionFilter2D = 0;
PFNGLCONVOLUTIONFILTER2DEXTPROC glConvolutionFilter2DEXT = 0;
PFNGLCONVOLUTIONPARAMETERFPROC glConvolutionParameterf = 0;
PFNGLCONVOLUTIONPARAMETERFEXTPROC glConvolutionParameterfEXT = 0;
PFNGLCONVOLUTIONPARAMETERFVPROC glConvolutionParameterfv = 0;
PFNGLCONVOLUTIONPARAMETERFVEXTPROC glConvolutionParameterfvEXT = 0;
PFNGLCONVOLUTIONPARAMETERIPROC glConvolutionParameteri = 0;
PFNGLCONVOLUTIONPARAMETERIEXTPROC glConvolutionParameteriEXT = 0;
PFNGLCONVOLUTIONPARAMETERIVPROC glConvolutionParameteriv = 0;
PFNGLCONVOLUTIONPARAMETERIVEXTPROC glConvolutionParameterivEXT = 0;
PFNGLCONVOLUTIONPARAMETERXOESPROC glConvolutionParameterxOES = 0;
PFNGLCONVOLUTIONPARAMETERXVOESPROC glConvolutionParameterxvOES = 0;
PFNGLCOPYBUFFERSUBDATAPROC glCopyBufferSubData = 0;
PFNGLCOPYBUFFERSUBDATANVPROC glCopyBufferSubDataNV = 0;
PFNGLCOPYCOLORSUBTABLEPROC glCopyColorSubTable = 0;
PFNGLCOPYCOLORSUBTABLEEXTPROC glCopyColorSubTableEXT = 0;
PFNGLCOPYCOLORTABLEPROC glCopyColorTable = 0;
PFNGLCOPYCOLORTABLESGIPROC glCopyColorTableSGI = 0;
PFNGLCOPYCONVOLUTIONFILTER1DPROC glCopyConvolutionFilter1D = 0;
PFNGLCOPYCONVOLUTIONFILTER1DEXTPROC glCopyConvolutionFilter1DEXT = 0;
PFNGLCOPYCONVOLUTIONFILTER2DPROC glCopyConvolutionFilter2D = 0;
PFNGLCOPYCONVOLUTIONFILTER2DEXTPROC glCopyConvolutionFilter2DEXT = 0;
PFNGLCOPYIMAGESUBDATAPROC glCopyImageSubData = 0;
PFNGLCOPYIMAGESUBDATAEXTPROC glCopyImageSubDataEXT = 0;
PFNGLCOPYIMAGESUBDATANVPROC glCopyImageSubDataNV = 0;
PFNGLCOPYIMAGESUBDATAOESPROC glCopyImageSubDataOES = 0;
PFNGLCOPYMULTITEXIMAGE1DEXTPROC glCopyMultiTexImage1DEXT = 0;
PFNGLCOPYMULTITEXIMAGE2DEXTPROC glCopyMultiTexImage2DEXT = 0;
PFNGLCOPYMULTITEXSUBIMAGE1DEXTPROC glCopyMultiTexSubImage1DEXT = 0;
PFNGLCOPYMULTITEXSUBIMAGE2DEXTPROC glCopyMultiTexSubImage2DEXT = 0;
PFNGLCOPYMULTITEXSUBIMAGE3DEXTPROC glCopyMultiTexSubImage3DEXT = 0;
PFNGLCOPYNAMEDBUFFERSUBDATAPROC glCopyNamedBufferSubData = 0;
PFNGLCOPYPATHNVPROC glCopyPathNV = 0;
PFNGLCOPYPIXELSPROC glCopyPixels = 0;
PFNGLCOPYTEXIMAGE1DPROC glCopyTexImage1D = 0;
PFNGLCOPYTEXIMAGE1DEXTPROC glCopyTexImage1DEXT = 0;
PFNGLCOPYTEXIMAGE2DPROC glCopyTexImage2D = 0;
PFNGLCOPYTEXIMAGE2DEXTPROC glCopyTexImage2DEXT = 0;
PFNGLCOPYTEXSUBIMAGE1DPROC glCopyTexSubImage1D = 0;
PFNGLCOPYTEXSUBIMAGE1DEXTPROC glCopyTexSubImage1DEXT = 0;
PFNGLCOPYTEXSUBIMAGE2DPROC glCopyTexSubImage2D = 0;
PFNGLCOPYTEXSUBIMAGE2DEXTPROC glCopyTexSubImage2DEXT = 0;
PFNGLCOPYTEXSUBIMAGE3DPROC glCopyTexSubImage3D = 0;
PFNGLCOPYTEXSUBIMAGE3DEXTPROC glCopyTexSubImage3DEXT = 0;
PFNGLCOPYTEXSUBIMAGE3DOESPROC glCopyTexSubImage3DOES = 0;
PFNGLCOPYTEXTUREIMAGE1DEXTPROC glCopyTextureImage1DEXT = 0;
PFNGLCOPYTEXTUREIMAGE2DEXTPROC glCopyTextureImage2DEXT = 0;
PFNGLCOPYTEXTURELEVELSAPPLEPROC glCopyTextureLevelsAPPLE = 0;
PFNGLCOPYTEXTURESUBIMAGE1DPROC glCopyTextureSubImage1D = 0;
PFNGLCOPYTEXTURESUBIMAGE1DEXTPROC glCopyTextureSubImage1DEXT = 0;
PFNGLCOPYTEXTURESUBIMAGE2DPROC glCopyTextureSubImage2D = 0;
PFNGLCOPYTEXTURESUBIMAGE2DEXTPROC glCopyTextureSubImage2DEXT = 0;
PFNGLCOPYTEXTURESUBIMAGE3DPROC glCopyTextureSubImage3D = 0;
PFNGLCOPYTEXTURESUBIMAGE3DEXTPROC glCopyTextureSubImage3DEXT = 0;
PFNGLCOVERFILLPATHINSTANCEDNVPROC glCoverFillPathInstancedNV = 0;
PFNGLCOVERFILLPATHNVPROC glCoverFillPathNV = 0;
PFNGLCOVERSTROKEPATHINSTANCEDNVPROC glCoverStrokePathInstancedNV = 0;
PFNGLCOVERSTROKEPATHNVPROC glCoverStrokePathNV = 0;
PFNGLCOVERAGEMASKNVPROC glCoverageMaskNV = 0;
PFNGLCOVERAGEMODULATIONNVPROC glCoverageModulationNV = 0;
PFNGLCOVERAGEMODULATIONTABLENVPROC glCoverageModulationTableNV = 0;
PFNGLCOVERAGEOPERATIONNVPROC glCoverageOperationNV = 0;
PFNGLCREATEBUFFERSPROC glCreateBuffers = 0;
PFNGLCREATECOMMANDLISTSNVPROC glCreateCommandListsNV = 0;
PFNGLCREATEFRAMEBUFFERSPROC glCreateFramebuffers = 0;
PFNGLCREATEMEMORYOBJECTSEXTPROC glCreateMemoryObjectsEXT = 0;
PFNGLCREATEPERFQUERYINTELPROC glCreatePerfQueryINTEL = 0;
PFNGLCREATEPROGRAMPROC glCreateProgram = 0;
PFNGLCREATEPROGRAMOBJECTARBPROC glCreateProgramObjectARB = 0;
PFNGLCREATEPROGRAMPIPELINESPROC glCreateProgramPipelines = 0;
PFNGLCREATEPROGRESSFENCENVXPROC glCreateProgressFenceNVX = 0;
PFNGLCREATEQUERIESPROC glCreateQueries = 0;
PFNGLCREATERENDERBUFFERSPROC glCreateRenderbuffers = 0;
PFNGLCREATESAMPLERSPROC glCreateSamplers = 0;
PFNGLCREATESEMAPHORESNVPROC glCreateSemaphoresNV = 0;
PFNGLCREATESHADERPROC glCreateShader = 0;
PFNGLCREATESHADEROBJECTARBPROC glCreateShaderObjectARB = 0;
PFNGLCREATESHADERPROGRAMEXTPROC glCreateShaderProgramEXT = 0;
PFNGLCREATESHADERPROGRAMVPROC glCreateShaderProgramv = 0;
PFNGLCREATESHADERPROGRAMVEXTPROC glCreateShaderProgramvEXT = 0;
PFNGLCREATESTATESNVPROC glCreateStatesNV = 0;
PFNGLCREATESYNCFROMCLEVENTARBPROC glCreateSyncFromCLeventARB = 0;
PFNGLCREATETEXTURESPROC glCreateTextures = 0;
PFNGLCREATETRANSFORMFEEDBACKSPROC glCreateTransformFeedbacks = 0;
PFNGLCREATEVERTEXARRAYSPROC glCreateVertexArrays = 0;
PFNGLCULLFACEPROC glCullFace = 0;
PFNGLCULLPARAMETERDVEXTPROC glCullParameterdvEXT = 0;
PFNGLCULLPARAMETERFVEXTPROC glCullParameterfvEXT = 0;
PFNGLCURRENTPALETTEMATRIXARBPROC glCurrentPaletteMatrixARB = 0;
PFNGLCURRENTPALETTEMATRIXOESPROC glCurrentPaletteMatrixOES = 0;
PFNGLDEBUGMESSAGECALLBACKPROC glDebugMessageCallback = 0;
PFNGLDEBUGMESSAGECALLBACKAMDPROC glDebugMessageCallbackAMD = 0;
PFNGLDEBUGMESSAGECALLBACKARBPROC glDebugMessageCallbackARB = 0;
PFNGLDEBUGMESSAGECALLBACKKHRPROC glDebugMessageCallbackKHR = 0;
PFNGLDEBUGMESSAGECONTROLPROC glDebugMessageControl = 0;
PFNGLDEBUGMESSAGECONTROLARBPROC glDebugMessageControlARB = 0;
PFNGLDEBUGMESSAGECONTROLKHRPROC glDebugMessageControlKHR = 0;
PFNGLDEBUGMESSAGEENABLEAMDPROC glDebugMessageEnableAMD = 0;
PFNGLDEBUGMESSAGEINSERTPROC glDebugMessageInsert = 0;
PFNGLDEBUGMESSAGEINSERTAMDPROC glDebugMessageInsertAMD = 0;
PFNGLDEBUGMESSAGEINSERTARBPROC glDebugMessageInsertARB = 0;
PFNGLDEBUGMESSAGEINSERTKHRPROC glDebugMessageInsertKHR = 0;
PFNGLDEFORMSGIXPROC glDeformSGIX = 0;
PFNGLDEFORMATIONMAP3DSGIXPROC glDeformationMap3dSGIX = 0;
PFNGLDEFORMATIONMAP3FSGIXPROC glDeformationMap3fSGIX = 0;
PFNGLDELETEASYNCMARKERSSGIXPROC glDeleteAsyncMarkersSGIX = 0;
PFNGLDELETEBUFFERSPROC glDeleteBuffers = 0;
PFNGLDELETEBUFFERSARBPROC glDeleteBuffersARB = 0;
PFNGLDELETECOMMANDLISTSNVPROC glDeleteCommandListsNV = 0;
PFNGLDELETEFENCESAPPLEPROC glDeleteFencesAPPLE = 0;
PFNGLDELETEFENCESNVPROC glDeleteFencesNV = 0;
PFNGLDELETEFRAGMENTSHADERATIPROC glDeleteFragmentShaderATI = 0;
PFNGLDELETEFRAMEBUFFERSPROC glDeleteFramebuffers = 0;
PFNGLDELETEFRAMEBUFFERSEXTPROC glDeleteFramebuffersEXT = 0;
PFNGLDELETEFRAMEBUFFERSOESPROC glDeleteFramebuffersOES = 0;
PFNGLDELETELISTSPROC glDeleteLists = 0;
PFNGLDELETEMEMORYOBJECTSEXTPROC glDeleteMemoryObjectsEXT = 0;
PFNGLDELETENAMEDSTRINGARBPROC glDeleteNamedStringARB = 0;
PFNGLDELETENAMESAMDPROC glDeleteNamesAMD = 0;
PFNGLDELETEOBJECTARBPROC glDeleteObjectARB = 0;
PFNGLDELETEOCCLUSIONQUERIESNVPROC glDeleteOcclusionQueriesNV = 0;
PFNGLDELETEPATHSNVPROC glDeletePathsNV = 0;
PFNGLDELETEPERFMONITORSAMDPROC glDeletePerfMonitorsAMD = 0;
PFNGLDELETEPERFQUERYINTELPROC glDeletePerfQueryINTEL = 0;
PFNGLDELETEPROGRAMPROC glDeleteProgram = 0;
PFNGLDELETEPROGRAMPIPELINESPROC glDeleteProgramPipelines = 0;
PFNGLDELETEPROGRAMPIPELINESEXTPROC glDeleteProgramPipelinesEXT = 0;
PFNGLDELETEPROGRAMSARBPROC glDeleteProgramsARB = 0;
PFNGLDELETEPROGRAMSNVPROC glDeleteProgramsNV = 0;
PFNGLDELETEQUERIESPROC glDeleteQueries = 0;
PFNGLDELETEQUERIESARBPROC glDeleteQueriesARB = 0;
PFNGLDELETEQUERIESEXTPROC glDeleteQueriesEXT = 0;
PFNGLDELETEQUERYRESOURCETAGNVPROC glDeleteQueryResourceTagNV = 0;
PFNGLDELETERENDERBUFFERSPROC glDeleteRenderbuffers = 0;
PFNGLDELETERENDERBUFFERSEXTPROC glDeleteRenderbuffersEXT = 0;
PFNGLDELETERENDERBUFFERSOESPROC glDeleteRenderbuffersOES = 0;
PFNGLDELETESAMPLERSPROC glDeleteSamplers = 0;
PFNGLDELETESEMAPHORESEXTPROC glDeleteSemaphoresEXT = 0;
PFNGLDELETESHADERPROC glDeleteShader = 0;
PFNGLDELETESTATESNVPROC glDeleteStatesNV = 0;
PFNGLDELETESYNCPROC glDeleteSync = 0;
PFNGLDELETESYNCAPPLEPROC glDeleteSyncAPPLE = 0;
PFNGLDELETETEXTURESPROC glDeleteTextures = 0;
PFNGLDELETETEXTURESEXTPROC glDeleteTexturesEXT = 0;
PFNGLDELETETRANSFORMFEEDBACKSPROC glDeleteTransformFeedbacks = 0;
PFNGLDELETETRANSFORMFEEDBACKSNVPROC glDeleteTransformFeedbacksNV = 0;
PFNGLDELETEVERTEXARRAYSPROC glDeleteVertexArrays = 0;
PFNGLDELETEVERTEXARRAYSAPPLEPROC glDeleteVertexArraysAPPLE = 0;
PFNGLDELETEVERTEXARRAYSOESPROC glDeleteVertexArraysOES = 0;
PFNGLDELETEVERTEXSHADEREXTPROC glDeleteVertexShaderEXT = 0;
PFNGLDEPTHBOUNDSEXTPROC glDepthBoundsEXT = 0;
PFNGLDEPTHBOUNDSDNVPROC glDepthBoundsdNV = 0;
PFNGLDEPTHFUNCPROC glDepthFunc = 0;
PFNGLDEPTHMASKPROC glDepthMask = 0;
PFNGLDEPTHRANGEPROC glDepthRange = 0;
PFNGLDEPTHRANGEARRAYDVNVPROC glDepthRangeArraydvNV = 0;
PFNGLDEPTHRANGEARRAYFVNVPROC glDepthRangeArrayfvNV = 0;
PFNGLDEPTHRANGEARRAYFVOESPROC glDepthRangeArrayfvOES = 0;
PFNGLDEPTHRANGEARRAYVPROC glDepthRangeArrayv = 0;
PFNGLDEPTHRANGEINDEXEDPROC glDepthRangeIndexed = 0;
PFNGLDEPTHRANGEINDEXEDDNVPROC glDepthRangeIndexeddNV = 0;
PFNGLDEPTHRANGEINDEXEDFNVPROC glDepthRangeIndexedfNV = 0;
PFNGLDEPTHRANGEINDEXEDFOESPROC glDepthRangeIndexedfOES = 0;
PFNGLDEPTHRANGEDNVPROC glDepthRangedNV = 0;
PFNGLDEPTHRANGEFPROC glDepthRangef = 0;
PFNGLDEPTHRANGEFOESPROC glDepthRangefOES = 0;
PFNGLDEPTHRANGEXPROC glDepthRangex = 0;
PFNGLDEPTHRANGEXOESPROC glDepthRangexOES = 0;
PFNGLDETACHOBJECTARBPROC glDetachObjectARB = 0;
PFNGLDETACHSHADERPROC glDetachShader = 0;
PFNGLDETAILTEXFUNCSGISPROC glDetailTexFuncSGIS = 0;
PFNGLDISABLEPROC glDisable = 0;
PFNGLDISABLECLIENTSTATEPROC glDisableClientState = 0;
PFNGLDISABLECLIENTSTATEINDEXEDEXTPROC glDisableClientStateIndexedEXT = 0;
PFNGLDISABLECLIENTSTATEIEXTPROC glDisableClientStateiEXT = 0;
PFNGLDISABLEDRIVERCONTROLQCOMPROC glDisableDriverControlQCOM = 0;
PFNGLDISABLEINDEXEDEXTPROC glDisableIndexedEXT = 0;
PFNGLDISABLEVARIANTCLIENTSTATEEXTPROC glDisableVariantClientStateEXT = 0;
PFNGLDISABLEVERTEXARRAYATTRIBPROC glDisableVertexArrayAttrib = 0;
PFNGLDISABLEVERTEXARRAYATTRIBEXTPROC glDisableVertexArrayAttribEXT = 0;
PFNGLDISABLEVERTEXARRAYEXTPROC glDisableVertexArrayEXT = 0;
PFNGLDISABLEVERTEXATTRIBAPPLEPROC glDisableVertexAttribAPPLE = 0;
PFNGLDISABLEVERTEXATTRIBARRAYPROC glDisableVertexAttribArray = 0;
PFNGLDISABLEVERTEXATTRIBARRAYARBPROC glDisableVertexAttribArrayARB = 0;
PFNGLDISABLEIPROC glDisablei = 0;
PFNGLDISABLEIEXTPROC glDisableiEXT = 0;
PFNGLDISABLEINVPROC glDisableiNV = 0;
PFNGLDISABLEIOESPROC glDisableiOES = 0;
PFNGLDISCARDFRAMEBUFFEREXTPROC glDiscardFramebufferEXT = 0;
PFNGLDISPATCHCOMPUTEPROC glDispatchCompute = 0;
PFNGLDISPATCHCOMPUTEGROUPSIZEARBPROC glDispatchComputeGroupSizeARB = 0;
PFNGLDISPATCHCOMPUTEINDIRECTPROC glDispatchComputeIndirect = 0;
PFNGLDRAWARRAYSPROC glDrawArrays = 0;
PFNGLDRAWARRAYSEXTPROC glDrawArraysEXT = 0;
PFNGLDRAWARRAYSINDIRECTPROC glDrawArraysIndirect = 0;
PFNGLDRAWARRAYSINSTANCEDPROC glDrawArraysInstanced = 0;
PFNGLDRAWARRAYSINSTANCEDANGLEPROC glDrawArraysInstancedANGLE = 0;
PFNGLDRAWARRAYSINSTANCEDARBPROC glDrawArraysInstancedARB = 0;
PFNGLDRAWARRAYSINSTANCEDBASEINSTANCEPROC glDrawArraysInstancedBaseInstance = 0;
PFNGLDRAWARRAYSINSTANCEDBASEINSTANCEEXTPROC glDrawArraysInstancedBaseInstanceEXT = 0;
PFNGLDRAWARRAYSINSTANCEDEXTPROC glDrawArraysInstancedEXT = 0;
PFNGLDRAWARRAYSINSTANCEDNVPROC glDrawArraysInstancedNV = 0;
PFNGLDRAWBUFFERPROC glDrawBuffer = 0;
PFNGLDRAWBUFFERSPROC glDrawBuffers = 0;
PFNGLDRAWBUFFERSARBPROC glDrawBuffersARB = 0;
PFNGLDRAWBUFFERSATIPROC glDrawBuffersATI = 0;
PFNGLDRAWBUFFERSEXTPROC glDrawBuffersEXT = 0;
PFNGLDRAWBUFFERSINDEXEDEXTPROC glDrawBuffersIndexedEXT = 0;
PFNGLDRAWBUFFERSNVPROC glDrawBuffersNV = 0;
PFNGLDRAWCOMMANDSADDRESSNVPROC glDrawCommandsAddressNV = 0;
PFNGLDRAWCOMMANDSNVPROC glDrawCommandsNV = 0;
PFNGLDRAWCOMMANDSSTATESADDRESSNVPROC glDrawCommandsStatesAddressNV = 0;
PFNGLDRAWCOMMANDSSTATESNVPROC glDrawCommandsStatesNV = 0;
PFNGLDRAWELEMENTARRAYAPPLEPROC glDrawElementArrayAPPLE = 0;
PFNGLDRAWELEMENTARRAYATIPROC glDrawElementArrayATI = 0;
PFNGLDRAWELEMENTSPROC glDrawElements = 0;
PFNGLDRAWELEMENTSBASEVERTEXPROC glDrawElementsBaseVertex = 0;
PFNGLDRAWELEMENTSBASEVERTEXEXTPROC glDrawElementsBaseVertexEXT = 0;
PFNGLDRAWELEMENTSBASEVERTEXOESPROC glDrawElementsBaseVertexOES = 0;
PFNGLDRAWELEMENTSINDIRECTPROC glDrawElementsIndirect = 0;
PFNGLDRAWELEMENTSINSTANCEDPROC glDrawElementsInstanced = 0;
PFNGLDRAWELEMENTSINSTANCEDANGLEPROC glDrawElementsInstancedANGLE = 0;
PFNGLDRAWELEMENTSINSTANCEDARBPROC glDrawElementsInstancedARB = 0;
PFNGLDRAWELEMENTSINSTANCEDBASEINSTANCEPROC glDrawElementsInstancedBaseInstance = 0;
PFNGLDRAWELEMENTSINSTANCEDBASEINSTANCEEXTPROC glDrawElementsInstancedBaseInstanceEXT = 0;
PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXPROC glDrawElementsInstancedBaseVertex = 0;
PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXBASEINSTANCEPROC glDrawElementsInstancedBaseVertexBaseInstance = 0;
PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXBASEINSTANCEEXTPROC glDrawElementsInstancedBaseVertexBaseInstanceEXT = 0;
PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXEXTPROC glDrawElementsInstancedBaseVertexEXT = 0;
PFNGLDRAWELEMENTSINSTANCEDBASEVERTEXOESPROC glDrawElementsInstancedBaseVertexOES = 0;
PFNGLDRAWELEMENTSINSTANCEDEXTPROC glDrawElementsInstancedEXT = 0;
PFNGLDRAWELEMENTSINSTANCEDNVPROC glDrawElementsInstancedNV = 0;
PFNGLDRAWMESHARRAYSSUNPROC glDrawMeshArraysSUN = 0;
PFNGLDRAWMESHTASKSNVPROC glDrawMeshTasksNV = 0;
PFNGLDRAWMESHTASKSINDIRECTNVPROC glDrawMeshTasksIndirectNV = 0;
PFNGLDRAWPIXELSPROC glDrawPixels = 0;
PFNGLDRAWRANGEELEMENTARRAYAPPLEPROC glDrawRangeElementArrayAPPLE = 0;
PFNGLDRAWRANGEELEMENTARRAYATIPROC glDrawRangeElementArrayATI = 0;
PFNGLDRAWRANGEELEMENTSPROC glDrawRangeElements = 0;
PFNGLDRAWRANGEELEMENTSBASEVERTEXPROC glDrawRangeElementsBaseVertex = 0;
PFNGLDRAWRANGEELEMENTSBASEVERTEXEXTPROC glDrawRangeElementsBaseVertexEXT = 0;
PFNGLDRAWRANGEELEMENTSBASEVERTEXOESPROC glDrawRangeElementsBaseVertexOES = 0;
PFNGLDRAWRANGEELEMENTSEXTPROC glDrawRangeElementsEXT = 0;
PFNGLDRAWTEXFOESPROC glDrawTexfOES = 0;
PFNGLDRAWTEXFVOESPROC glDrawTexfvOES = 0;
PFNGLDRAWTEXIOESPROC glDrawTexiOES = 0;
PFNGLDRAWTEXIVOESPROC glDrawTexivOES = 0;
PFNGLDRAWTEXSOESPROC glDrawTexsOES = 0;
PFNGLDRAWTEXSVOESPROC glDrawTexsvOES = 0;
PFNGLDRAWTEXTURENVPROC glDrawTextureNV = 0;
PFNGLDRAWTEXXOESPROC glDrawTexxOES = 0;
PFNGLDRAWTEXXVOESPROC glDrawTexxvOES = 0;
PFNGLDRAWTRANSFORMFEEDBACKPROC glDrawTransformFeedback = 0;
PFNGLDRAWTRANSFORMFEEDBACKEXTPROC glDrawTransformFeedbackEXT = 0;
PFNGLDRAWTRANSFORMFEEDBACKINSTANCEDPROC glDrawTransformFeedbackInstanced = 0;
PFNGLDRAWTRANSFORMFEEDBACKINSTANCEDEXTPROC glDrawTransformFeedbackInstancedEXT = 0;
PFNGLDRAWTRANSFORMFEEDBACKNVPROC glDrawTransformFeedbackNV = 0;
PFNGLDRAWTRANSFORMFEEDBACKSTREAMPROC glDrawTransformFeedbackStream = 0;
PFNGLDRAWTRANSFORMFEEDBACKSTREAMINSTANCEDPROC glDrawTransformFeedbackStreamInstanced = 0;
PFNGLEGLIMAGETARGETRENDERBUFFERSTORAGEOESPROC glEGLImageTargetRenderbufferStorageOES = 0;
PFNGLEGLIMAGETARGETTEXSTORAGEEXTPROC glEGLImageTargetTexStorageEXT = 0;
PFNGLEGLIMAGETARGETTEXTURE2DOESPROC glEGLImageTargetTexture2DOES = 0;
PFNGLEGLIMAGETARGETTEXTURESTORAGEEXTPROC glEGLImageTargetTextureStorageEXT = 0;
PFNGLEDGEFLAGPROC glEdgeFlag = 0;
PFNGLEDGEFLAGFORMATNVPROC glEdgeFlagFormatNV = 0;
PFNGLEDGEFLAGPOINTERPROC glEdgeFlagPointer = 0;
PFNGLEDGEFLAGPOINTEREXTPROC glEdgeFlagPointerEXT = 0;
PFNGLEDGEFLAGPOINTERLISTIBMPROC glEdgeFlagPointerListIBM = 0;
PFNGLEDGEFLAGVPROC glEdgeFlagv = 0;
PFNGLELEMENTPOINTERAPPLEPROC glElementPointerAPPLE = 0;
PFNGLELEMENTPOINTERATIPROC glElementPointerATI = 0;
PFNGLENABLEPROC glEnable = 0;
PFNGLENABLECLIENTSTATEPROC glEnableClientState = 0;
PFNGLENABLECLIENTSTATEINDEXEDEXTPROC glEnableClientStateIndexedEXT = 0;
PFNGLENABLECLIENTSTATEIEXTPROC glEnableClientStateiEXT = 0;
PFNGLENABLEDRIVERCONTROLQCOMPROC glEnableDriverControlQCOM = 0;
PFNGLENABLEINDEXEDEXTPROC glEnableIndexedEXT = 0;
PFNGLENABLEVARIANTCLIENTSTATEEXTPROC glEnableVariantClientStateEXT = 0;
PFNGLENABLEVERTEXARRAYATTRIBPROC glEnableVertexArrayAttrib = 0;
PFNGLENABLEVERTEXARRAYATTRIBEXTPROC glEnableVertexArrayAttribEXT = 0;
PFNGLENABLEVERTEXARRAYEXTPROC glEnableVertexArrayEXT = 0;
PFNGLENABLEVERTEXATTRIBAPPLEPROC glEnableVertexAttribAPPLE = 0;
PFNGLENABLEVERTEXATTRIBARRAYPROC glEnableVertexAttribArray = 0;
PFNGLENABLEVERTEXATTRIBARRAYARBPROC glEnableVertexAttribArrayARB = 0;
PFNGLENABLEIPROC glEnablei = 0;
PFNGLENABLEIEXTPROC glEnableiEXT = 0;
PFNGLENABLEINVPROC glEnableiNV = 0;
PFNGLENABLEIOESPROC glEnableiOES = 0;
PFNGLENDPROC glEnd = 0;
PFNGLENDCONDITIONALRENDERPROC glEndConditionalRender = 0;
PFNGLENDCONDITIONALRENDERNVPROC glEndConditionalRenderNV = 0;
PFNGLENDCONDITIONALRENDERNVXPROC glEndConditionalRenderNVX = 0;
PFNGLENDFRAGMENTSHADERATIPROC glEndFragmentShaderATI = 0;
PFNGLENDLISTPROC glEndList = 0;
PFNGLENDOCCLUSIONQUERYNVPROC glEndOcclusionQueryNV = 0;
PFNGLENDPERFMONITORAMDPROC glEndPerfMonitorAMD = 0;
PFNGLENDPERFQUERYINTELPROC glEndPerfQueryINTEL = 0;
PFNGLENDQUERYPROC glEndQuery = 0;
PFNGLENDQUERYARBPROC glEndQueryARB = 0;
PFNGLENDQUERYEXTPROC glEndQueryEXT = 0;
PFNGLENDQUERYINDEXEDPROC glEndQueryIndexed = 0;
PFNGLENDTILINGQCOMPROC glEndTilingQCOM = 0;
PFNGLENDTRANSFORMFEEDBACKPROC glEndTransformFeedback = 0;
PFNGLENDTRANSFORMFEEDBACKEXTPROC glEndTransformFeedbackEXT = 0;
PFNGLENDTRANSFORMFEEDBACKNVPROC glEndTransformFeedbackNV = 0;
PFNGLENDVERTEXSHADEREXTPROC glEndVertexShaderEXT = 0;
PFNGLENDVIDEOCAPTURENVPROC glEndVideoCaptureNV = 0;
PFNGLEVALCOORD1DPROC glEvalCoord1d = 0;
PFNGLEVALCOORD1DVPROC glEvalCoord1dv = 0;
PFNGLEVALCOORD1FPROC glEvalCoord1f = 0;
PFNGLEVALCOORD1FVPROC glEvalCoord1fv = 0;
PFNGLEVALCOORD1XOESPROC glEvalCoord1xOES = 0;
PFNGLEVALCOORD1XVOESPROC glEvalCoord1xvOES = 0;
PFNGLEVALCOORD2DPROC glEvalCoord2d = 0;
PFNGLEVALCOORD2DVPROC glEvalCoord2dv = 0;
PFNGLEVALCOORD2FPROC glEvalCoord2f = 0;
PFNGLEVALCOORD2FVPROC glEvalCoord2fv = 0;
PFNGLEVALCOORD2XOESPROC glEvalCoord2xOES = 0;
PFNGLEVALCOORD2XVOESPROC glEvalCoord2xvOES = 0;
PFNGLEVALMAPSNVPROC glEvalMapsNV = 0;
PFNGLEVALMESH1PROC glEvalMesh1 = 0;
PFNGLEVALMESH2PROC glEvalMesh2 = 0;
PFNGLEVALPOINT1PROC glEvalPoint1 = 0;
PFNGLEVALPOINT2PROC glEvalPoint2 = 0;
PFNGLEVALUATEDEPTHVALUESARBPROC glEvaluateDepthValuesARB = 0;
PFNGLEXECUTEPROGRAMNVPROC glExecuteProgramNV = 0;
PFNGLEXTGETBUFFERPOINTERVQCOMPROC glExtGetBufferPointervQCOM = 0;
PFNGLEXTGETBUFFERSQCOMPROC glExtGetBuffersQCOM = 0;
PFNGLEXTGETFRAMEBUFFERSQCOMPROC glExtGetFramebuffersQCOM = 0;
PFNGLEXTGETPROGRAMBINARYSOURCEQCOMPROC glExtGetProgramBinarySourceQCOM = 0;
PFNGLEXTGETPROGRAMSQCOMPROC glExtGetProgramsQCOM = 0;
PFNGLEXTGETRENDERBUFFERSQCOMPROC glExtGetRenderbuffersQCOM = 0;
PFNGLEXTGETSHADERSQCOMPROC glExtGetShadersQCOM = 0;
PFNGLEXTGETTEXLEVELPARAMETERIVQCOMPROC glExtGetTexLevelParameterivQCOM = 0;
PFNGLEXTGETTEXSUBIMAGEQCOMPROC glExtGetTexSubImageQCOM = 0;
PFNGLEXTGETTEXTURESQCOMPROC glExtGetTexturesQCOM = 0;
PFNGLEXTISPROGRAMBINARYQCOMPROC glExtIsProgramBinaryQCOM = 0;
PFNGLEXTTEXOBJECTSTATEOVERRIDEIQCOMPROC glExtTexObjectStateOverrideiQCOM = 0;
PFNGLEXTRACTCOMPONENTEXTPROC glExtractComponentEXT = 0;
PFNGLFEEDBACKBUFFERPROC glFeedbackBuffer = 0;
PFNGLFEEDBACKBUFFERXOESPROC glFeedbackBufferxOES = 0;
PFNGLFENCESYNCPROC glFenceSync = 0;
PFNGLFENCESYNCAPPLEPROC glFenceSyncAPPLE = 0;
PFNGLFINALCOMBINERINPUTNVPROC glFinalCombinerInputNV = 0;
PFNGLFINISHPROC glFinish = 0;
PFNGLFINISHASYNCSGIXPROC glFinishAsyncSGIX = 0;
PFNGLFINISHFENCEAPPLEPROC glFinishFenceAPPLE = 0;
PFNGLFINISHFENCENVPROC glFinishFenceNV = 0;
PFNGLFINISHOBJECTAPPLEPROC glFinishObjectAPPLE = 0;
PFNGLFINISHTEXTURESUNXPROC glFinishTextureSUNX = 0;
PFNGLFLUSHPROC glFlush = 0;
PFNGLFLUSHMAPPEDBUFFERRANGEPROC glFlushMappedBufferRange = 0;
PFNGLFLUSHMAPPEDBUFFERRANGEAPPLEPROC glFlushMappedBufferRangeAPPLE = 0;
PFNGLFLUSHMAPPEDBUFFERRANGEEXTPROC glFlushMappedBufferRangeEXT = 0;
PFNGLFLUSHMAPPEDNAMEDBUFFERRANGEPROC glFlushMappedNamedBufferRange = 0;
PFNGLFLUSHMAPPEDNAMEDBUFFERRANGEEXTPROC glFlushMappedNamedBufferRangeEXT = 0;
PFNGLFLUSHPIXELDATARANGENVPROC glFlushPixelDataRangeNV = 0;
PFNGLFLUSHRASTERSGIXPROC glFlushRasterSGIX = 0;
PFNGLFLUSHSTATICDATAIBMPROC glFlushStaticDataIBM = 0;
PFNGLFLUSHVERTEXARRAYRANGEAPPLEPROC glFlushVertexArrayRangeAPPLE = 0;
PFNGLFLUSHVERTEXARRAYRANGENVPROC glFlushVertexArrayRangeNV = 0;
PFNGLFOGCOORDFORMATNVPROC glFogCoordFormatNV = 0;
PFNGLFOGCOORDPOINTERPROC glFogCoordPointer = 0;
PFNGLFOGCOORDPOINTEREXTPROC glFogCoordPointerEXT = 0;
PFNGLFOGCOORDPOINTERLISTIBMPROC glFogCoordPointerListIBM = 0;
PFNGLFOGCOORDDPROC glFogCoordd = 0;
PFNGLFOGCOORDDEXTPROC glFogCoorddEXT = 0;
PFNGLFOGCOORDDVPROC glFogCoorddv = 0;
PFNGLFOGCOORDDVEXTPROC glFogCoorddvEXT = 0;
PFNGLFOGCOORDFPROC glFogCoordf = 0;
PFNGLFOGCOORDFEXTPROC glFogCoordfEXT = 0;
PFNGLFOGCOORDFVPROC glFogCoordfv = 0;
PFNGLFOGCOORDFVEXTPROC glFogCoordfvEXT = 0;
PFNGLFOGCOORDHNVPROC glFogCoordhNV = 0;
PFNGLFOGCOORDHVNVPROC glFogCoordhvNV = 0;
PFNGLFOGFUNCSGISPROC glFogFuncSGIS = 0;
PFNGLFOGFPROC glFogf = 0;
PFNGLFOGFVPROC glFogfv = 0;
PFNGLFOGIPROC glFogi = 0;
PFNGLFOGIVPROC glFogiv = 0;
PFNGLFOGXPROC glFogx = 0;
PFNGLFOGXOESPROC glFogxOES = 0;
PFNGLFOGXVPROC glFogxv = 0;
PFNGLFOGXVOESPROC glFogxvOES = 0;
PFNGLFRAGMENTCOLORMATERIALSGIXPROC glFragmentColorMaterialSGIX = 0;
PFNGLFRAGMENTCOVERAGECOLORNVPROC glFragmentCoverageColorNV = 0;
PFNGLFRAGMENTLIGHTMODELFSGIXPROC glFragmentLightModelfSGIX = 0;
PFNGLFRAGMENTLIGHTMODELFVSGIXPROC glFragmentLightModelfvSGIX = 0;
PFNGLFRAGMENTLIGHTMODELISGIXPROC glFragmentLightModeliSGIX = 0;
PFNGLFRAGMENTLIGHTMODELIVSGIXPROC glFragmentLightModelivSGIX = 0;
PFNGLFRAGMENTLIGHTFSGIXPROC glFragmentLightfSGIX = 0;
PFNGLFRAGMENTLIGHTFVSGIXPROC glFragmentLightfvSGIX = 0;
PFNGLFRAGMENTLIGHTISGIXPROC glFragmentLightiSGIX = 0;
PFNGLFRAGMENTLIGHTIVSGIXPROC glFragmentLightivSGIX = 0;
PFNGLFRAGMENTMATERIALFSGIXPROC glFragmentMaterialfSGIX = 0;
PFNGLFRAGMENTMATERIALFVSGIXPROC glFragmentMaterialfvSGIX = 0;
PFNGLFRAGMENTMATERIALISGIXPROC glFragmentMaterialiSGIX = 0;
PFNGLFRAGMENTMATERIALIVSGIXPROC glFragmentMaterialivSGIX = 0;
PFNGLFRAMETERMINATORGREMEDYPROC glFrameTerminatorGREMEDY = 0;
PFNGLFRAMEZOOMSGIXPROC glFrameZoomSGIX = 0;
PFNGLFRAMEBUFFERDRAWBUFFEREXTPROC glFramebufferDrawBufferEXT = 0;
PFNGLFRAMEBUFFERDRAWBUFFERSEXTPROC glFramebufferDrawBuffersEXT = 0;
PFNGLFRAMEBUFFERFETCHBARRIEREXTPROC glFramebufferFetchBarrierEXT = 0;
PFNGLFRAMEBUFFERFETCHBARRIERQCOMPROC glFramebufferFetchBarrierQCOM = 0;
PFNGLFRAMEBUFFERFOVEATIONCONFIGQCOMPROC glFramebufferFoveationConfigQCOM = 0;
PFNGLFRAMEBUFFERFOVEATIONPARAMETERSQCOMPROC glFramebufferFoveationParametersQCOM = 0;
PFNGLFRAMEBUFFERPARAMETERIPROC glFramebufferParameteri = 0;
PFNGLFRAMEBUFFERPIXELLOCALSTORAGESIZEEXTPROC glFramebufferPixelLocalStorageSizeEXT = 0;
PFNGLFRAMEBUFFERREADBUFFEREXTPROC glFramebufferReadBufferEXT = 0;
PFNGLFRAMEBUFFERRENDERBUFFERPROC glFramebufferRenderbuffer = 0;
PFNGLFRAMEBUFFERRENDERBUFFEREXTPROC glFramebufferRenderbufferEXT = 0;
PFNGLFRAMEBUFFERRENDERBUFFEROESPROC glFramebufferRenderbufferOES = 0;
PFNGLFRAMEBUFFERSAMPLELOCATIONSFVARBPROC glFramebufferSampleLocationsfvARB = 0;
PFNGLFRAMEBUFFERSAMPLELOCATIONSFVNVPROC glFramebufferSampleLocationsfvNV = 0;
PFNGLFRAMEBUFFERSAMPLEPOSITIONSFVAMDPROC glFramebufferSamplePositionsfvAMD = 0;
PFNGLFRAMEBUFFERSHADINGRATEEXTPROC glFramebufferShadingRateEXT = 0;
PFNGLFRAMEBUFFERTEXTUREPROC glFramebufferTexture = 0;
PFNGLFRAMEBUFFERTEXTURE1DPROC glFramebufferTexture1D = 0;
PFNGLFRAMEBUFFERTEXTURE1DEXTPROC glFramebufferTexture1DEXT = 0;
PFNGLFRAMEBUFFERTEXTURE2DPROC glFramebufferTexture2D = 0;
PFNGLFRAMEBUFFERTEXTURE2DEXTPROC glFramebufferTexture2DEXT = 0;
PFNGLFRAMEBUFFERTEXTURE2DDOWNSAMPLEIMGPROC glFramebufferTexture2DDownsampleIMG = 0;
PFNGLFRAMEBUFFERTEXTURE2DMULTISAMPLEEXTPROC glFramebufferTexture2DMultisampleEXT = 0;
PFNGLFRAMEBUFFERTEXTURE2DMULTISAMPLEIMGPROC glFramebufferTexture2DMultisampleIMG = 0;
PFNGLFRAMEBUFFERTEXTURE2DOESPROC glFramebufferTexture2DOES = 0;
PFNGLFRAMEBUFFERTEXTURE3DPROC glFramebufferTexture3D = 0;
PFNGLFRAMEBUFFERTEXTURE3DEXTPROC glFramebufferTexture3DEXT = 0;
PFNGLFRAMEBUFFERTEXTURE3DOESPROC glFramebufferTexture3DOES = 0;
PFNGLFRAMEBUFFERTEXTUREARBPROC glFramebufferTextureARB = 0;
PFNGLFRAMEBUFFERTEXTUREEXTPROC glFramebufferTextureEXT = 0;
PFNGLFRAMEBUFFERTEXTUREFACEARBPROC glFramebufferTextureFaceARB = 0;
PFNGLFRAMEBUFFERTEXTUREFACEEXTPROC glFramebufferTextureFaceEXT = 0;
PFNGLFRAMEBUFFERTEXTURELAYERPROC glFramebufferTextureLayer = 0;
PFNGLFRAMEBUFFERTEXTURELAYERARBPROC glFramebufferTextureLayerARB = 0;
PFNGLFRAMEBUFFERTEXTURELAYEREXTPROC glFramebufferTextureLayerEXT = 0;
PFNGLFRAMEBUFFERTEXTURELAYERDOWNSAMPLEIMGPROC glFramebufferTextureLayerDownsampleIMG = 0;
PFNGLFRAMEBUFFERTEXTUREMULTISAMPLEMULTIVIEWOVRPROC glFramebufferTextureMultisampleMultiviewOVR = 0;
PFNGLFRAMEBUFFERTEXTUREMULTIVIEWOVRPROC glFramebufferTextureMultiviewOVR = 0;
PFNGLFRAMEBUFFERTEXTUREOESPROC glFramebufferTextureOES = 0;
PFNGLFREEOBJECTBUFFERATIPROC glFreeObjectBufferATI = 0;
PFNGLFRONTFACEPROC glFrontFace = 0;
PFNGLFRUSTUMPROC glFrustum = 0;
PFNGLFRUSTUMFPROC glFrustumf = 0;
PFNGLFRUSTUMFOESPROC glFrustumfOES = 0;
PFNGLFRUSTUMXPROC glFrustumx = 0;
PFNGLFRUSTUMXOESPROC glFrustumxOES = 0;
PFNGLGENASYNCMARKERSSGIXPROC glGenAsyncMarkersSGIX = 0;
PFNGLGENBUFFERSPROC glGenBuffers = 0;
PFNGLGENBUFFERSARBPROC glGenBuffersARB = 0;
PFNGLGENFENCESAPPLEPROC glGenFencesAPPLE = 0;
PFNGLGENFENCESNVPROC glGenFencesNV = 0;
PFNGLGENFRAGMENTSHADERSATIPROC glGenFragmentShadersATI = 0;
PFNGLGENFRAMEBUFFERSPROC glGenFramebuffers = 0;
PFNGLGENFRAMEBUFFERSEXTPROC glGenFramebuffersEXT = 0;
PFNGLGENFRAMEBUFFERSOESPROC glGenFramebuffersOES = 0;
PFNGLGENLISTSPROC glGenLists = 0;
PFNGLGENNAMESAMDPROC glGenNamesAMD = 0;
PFNGLGENOCCLUSIONQUERIESNVPROC glGenOcclusionQueriesNV = 0;
PFNGLGENPATHSNVPROC glGenPathsNV = 0;
PFNGLGENPERFMONITORSAMDPROC glGenPerfMonitorsAMD = 0;
PFNGLGENPROGRAMPIPELINESPROC glGenProgramPipelines = 0;
PFNGLGENPROGRAMPIPELINESEXTPROC glGenProgramPipelinesEXT = 0;
PFNGLGENPROGRAMSARBPROC glGenProgramsARB = 0;
PFNGLGENPROGRAMSNVPROC glGenProgramsNV = 0;
PFNGLGENQUERIESPROC glGenQueries = 0;
PFNGLGENQUERIESARBPROC glGenQueriesARB = 0;
PFNGLGENQUERIESEXTPROC glGenQueriesEXT = 0;
PFNGLGENQUERYRESOURCETAGNVPROC glGenQueryResourceTagNV = 0;
PFNGLGENRENDERBUFFERSPROC glGenRenderbuffers = 0;
PFNGLGENRENDERBUFFERSEXTPROC glGenRenderbuffersEXT = 0;
PFNGLGENRENDERBUFFERSOESPROC glGenRenderbuffersOES = 0;
PFNGLGENSAMPLERSPROC glGenSamplers = 0;
PFNGLGENSEMAPHORESEXTPROC glGenSemaphoresEXT = 0;
PFNGLGENSYMBOLSEXTPROC glGenSymbolsEXT = 0;
PFNGLGENTEXTURESPROC glGenTextures = 0;
PFNGLGENTEXTURESEXTPROC glGenTexturesEXT = 0;
PFNGLGENTRANSFORMFEEDBACKSPROC glGenTransformFeedbacks = 0;
PFNGLGENTRANSFORMFEEDBACKSNVPROC glGenTransformFeedbacksNV = 0;
PFNGLGENVERTEXARRAYSPROC glGenVertexArrays = 0;
PFNGLGENVERTEXARRAYSAPPLEPROC glGenVertexArraysAPPLE = 0;
PFNGLGENVERTEXARRAYSOESPROC glGenVertexArraysOES = 0;
PFNGLGENVERTEXSHADERSEXTPROC glGenVertexShadersEXT = 0;
PFNGLGENERATEMIPMAPPROC glGenerateMipmap = 0;
PFNGLGENERATEMIPMAPEXTPROC glGenerateMipmapEXT = 0;
PFNGLGENERATEMIPMAPOESPROC glGenerateMipmapOES = 0;
PFNGLGENERATEMULTITEXMIPMAPEXTPROC glGenerateMultiTexMipmapEXT = 0;
PFNGLGENERATETEXTUREMIPMAPPROC glGenerateTextureMipmap = 0;
PFNGLGENERATETEXTUREMIPMAPEXTPROC glGenerateTextureMipmapEXT = 0;
PFNGLGETACTIVEATOMICCOUNTERBUFFERIVPROC glGetActiveAtomicCounterBufferiv = 0;
PFNGLGETACTIVEATTRIBPROC glGetActiveAttrib = 0;
PFNGLGETACTIVEATTRIBARBPROC glGetActiveAttribARB = 0;
PFNGLGETACTIVESUBROUTINENAMEPROC glGetActiveSubroutineName = 0;
PFNGLGETACTIVESUBROUTINEUNIFORMNAMEPROC glGetActiveSubroutineUniformName = 0;
PFNGLGETACTIVESUBROUTINEUNIFORMIVPROC glGetActiveSubroutineUniformiv = 0;
PFNGLGETACTIVEUNIFORMPROC glGetActiveUniform = 0;
PFNGLGETACTIVEUNIFORMARBPROC glGetActiveUniformARB = 0;
PFNGLGETACTIVEUNIFORMBLOCKNAMEPROC glGetActiveUniformBlockName = 0;
PFNGLGETACTIVEUNIFORMBLOCKIVPROC glGetActiveUniformBlockiv = 0;
PFNGLGETACTIVEUNIFORMNAMEPROC glGetActiveUniformName = 0;
PFNGLGETACTIVEUNIFORMSIVPROC glGetActiveUniformsiv = 0;
PFNGLGETACTIVEVARYINGNVPROC glGetActiveVaryingNV = 0;
PFNGLGETARRAYOBJECTFVATIPROC glGetArrayObjectfvATI = 0;
PFNGLGETARRAYOBJECTIVATIPROC glGetArrayObjectivATI = 0;
PFNGLGETATTACHEDOBJECTSARBPROC glGetAttachedObjectsARB = 0;
PFNGLGETATTACHEDSHADERSPROC glGetAttachedShaders = 0;
PFNGLGETATTRIBLOCATIONPROC glGetAttribLocation = 0;
PFNGLGETATTRIBLOCATIONARBPROC glGetAttribLocationARB = 0;
PFNGLGETBOOLEANINDEXEDVEXTPROC glGetBooleanIndexedvEXT = 0;
PFNGLGETBOOLEANI_VPROC glGetBooleani_v = 0;
PFNGLGETBOOLEANVPROC glGetBooleanv = 0;
PFNGLGETBUFFERPARAMETERI64VPROC glGetBufferParameteri64v = 0;
PFNGLGETBUFFERPARAMETERIVPROC glGetBufferParameteriv = 0;
PFNGLGETBUFFERPARAMETERIVARBPROC glGetBufferParameterivARB = 0;
PFNGLGETBUFFERPARAMETERUI64VNVPROC glGetBufferParameterui64vNV = 0;
PFNGLGETBUFFERPOINTERVPROC glGetBufferPointerv = 0;
PFNGLGETBUFFERPOINTERVARBPROC glGetBufferPointervARB = 0;
PFNGLGETBUFFERPOINTERVOESPROC glGetBufferPointervOES = 0;
PFNGLGETBUFFERSUBDATAPROC glGetBufferSubData = 0;
PFNGLGETBUFFERSUBDATAARBPROC glGetBufferSubDataARB = 0;
PFNGLGETCLIPPLANEPROC glGetClipPlane = 0;
PFNGLGETCLIPPLANEFPROC glGetClipPlanef = 0;
PFNGLGETCLIPPLANEFOESPROC glGetClipPlanefOES = 0;
PFNGLGETCLIPPLANEXPROC glGetClipPlanex = 0;
PFNGLGETCLIPPLANEXOESPROC glGetClipPlanexOES = 0;
PFNGLGETCOLORTABLEPROC glGetColorTable = 0;
PFNGLGETCOLORTABLEEXTPROC glGetColorTableEXT = 0;
PFNGLGETCOLORTABLEPARAMETERFVPROC glGetColorTableParameterfv = 0;
PFNGLGETCOLORTABLEPARAMETERFVEXTPROC glGetColorTableParameterfvEXT = 0;
PFNGLGETCOLORTABLEPARAMETERFVSGIPROC glGetColorTableParameterfvSGI = 0;
PFNGLGETCOLORTABLEPARAMETERIVPROC glGetColorTableParameteriv = 0;
PFNGLGETCOLORTABLEPARAMETERIVEXTPROC glGetColorTableParameterivEXT = 0;
PFNGLGETCOLORTABLEPARAMETERIVSGIPROC glGetColorTableParameterivSGI = 0;
PFNGLGETCOLORTABLESGIPROC glGetColorTableSGI = 0;
PFNGLGETCOMBINERINPUTPARAMETERFVNVPROC glGetCombinerInputParameterfvNV = 0;
PFNGLGETCOMBINERINPUTPARAMETERIVNVPROC glGetCombinerInputParameterivNV = 0;
PFNGLGETCOMBINEROUTPUTPARAMETERFVNVPROC glGetCombinerOutputParameterfvNV = 0;
PFNGLGETCOMBINEROUTPUTPARAMETERIVNVPROC glGetCombinerOutputParameterivNV = 0;
PFNGLGETCOMBINERSTAGEPARAMETERFVNVPROC glGetCombinerStageParameterfvNV = 0;
PFNGLGETCOMMANDHEADERNVPROC glGetCommandHeaderNV = 0;
PFNGLGETCOMPRESSEDMULTITEXIMAGEEXTPROC glGetCompressedMultiTexImageEXT = 0;
PFNGLGETCOMPRESSEDTEXIMAGEPROC glGetCompressedTexImage = 0;
PFNGLGETCOMPRESSEDTEXIMAGEARBPROC glGetCompressedTexImageARB = 0;
PFNGLGETCOMPRESSEDTEXTUREIMAGEPROC glGetCompressedTextureImage = 0;
PFNGLGETCOMPRESSEDTEXTUREIMAGEEXTPROC glGetCompressedTextureImageEXT = 0;
PFNGLGETCOMPRESSEDTEXTURESUBIMAGEPROC glGetCompressedTextureSubImage = 0;
PFNGLGETCONVOLUTIONFILTERPROC glGetConvolutionFilter = 0;
PFNGLGETCONVOLUTIONFILTEREXTPROC glGetConvolutionFilterEXT = 0;
PFNGLGETCONVOLUTIONPARAMETERFVPROC glGetConvolutionParameterfv = 0;
PFNGLGETCONVOLUTIONPARAMETERFVEXTPROC glGetConvolutionParameterfvEXT = 0;
PFNGLGETCONVOLUTIONPARAMETERIVPROC glGetConvolutionParameteriv = 0;
PFNGLGETCONVOLUTIONPARAMETERIVEXTPROC glGetConvolutionParameterivEXT = 0;
PFNGLGETCONVOLUTIONPARAMETERXVOESPROC glGetConvolutionParameterxvOES = 0;
PFNGLGETCOVERAGEMODULATIONTABLENVPROC glGetCoverageModulationTableNV = 0;
PFNGLGETDEBUGMESSAGELOGPROC glGetDebugMessageLog = 0;
PFNGLGETDEBUGMESSAGELOGAMDPROC glGetDebugMessageLogAMD = 0;
PFNGLGETDEBUGMESSAGELOGARBPROC glGetDebugMessageLogARB = 0;
PFNGLGETDEBUGMESSAGELOGKHRPROC glGetDebugMessageLogKHR = 0;
PFNGLGETDETAILTEXFUNCSGISPROC glGetDetailTexFuncSGIS = 0;
PFNGLGETDOUBLEINDEXEDVEXTPROC glGetDoubleIndexedvEXT = 0;
PFNGLGETDOUBLEI_VPROC glGetDoublei_v = 0;
PFNGLGETDOUBLEI_VEXTPROC glGetDoublei_vEXT = 0;
PFNGLGETDOUBLEVPROC glGetDoublev = 0;
PFNGLGETDRIVERCONTROLSTRINGQCOMPROC glGetDriverControlStringQCOM = 0;
PFNGLGETDRIVERCONTROLSQCOMPROC glGetDriverControlsQCOM = 0;
PFNGLGETERRORPROC glGetError = 0;
PFNGLGETFENCEIVNVPROC glGetFenceivNV = 0;
PFNGLGETFINALCOMBINERINPUTPARAMETERFVNVPROC glGetFinalCombinerInputParameterfvNV = 0;
PFNGLGETFINALCOMBINERINPUTPARAMETERIVNVPROC glGetFinalCombinerInputParameterivNV = 0;
PFNGLGETFIRSTPERFQUERYIDINTELPROC glGetFirstPerfQueryIdINTEL = 0;
PFNGLGETFIXEDVPROC glGetFixedv = 0;
PFNGLGETFIXEDVOESPROC glGetFixedvOES = 0;
PFNGLGETFLOATINDEXEDVEXTPROC glGetFloatIndexedvEXT = 0;
PFNGLGETFLOATI_VPROC glGetFloati_v = 0;
PFNGLGETFLOATI_VEXTPROC glGetFloati_vEXT = 0;
PFNGLGETFLOATI_VNVPROC glGetFloati_vNV = 0;
PFNGLGETFLOATI_VOESPROC glGetFloati_vOES = 0;
PFNGLGETFLOATVPROC glGetFloatv = 0;
PFNGLGETFOGFUNCSGISPROC glGetFogFuncSGIS = 0;
PFNGLGETFRAGDATAINDEXPROC glGetFragDataIndex = 0;
PFNGLGETFRAGDATAINDEXEXTPROC glGetFragDataIndexEXT = 0;
PFNGLGETFRAGDATALOCATIONPROC glGetFragDataLocation = 0;
PFNGLGETFRAGDATALOCATIONEXTPROC glGetFragDataLocationEXT = 0;
PFNGLGETFRAGMENTLIGHTFVSGIXPROC glGetFragmentLightfvSGIX = 0;
PFNGLGETFRAGMENTLIGHTIVSGIXPROC glGetFragmentLightivSGIX = 0;
PFNGLGETFRAGMENTMATERIALFVSGIXPROC glGetFragmentMaterialfvSGIX = 0;
PFNGLGETFRAGMENTMATERIALIVSGIXPROC glGetFragmentMaterialivSGIX = 0;
PFNGLGETFRAGMENTSHADINGRATESEXTPROC glGetFragmentShadingRatesEXT = 0;
PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVPROC glGetFramebufferAttachmentParameteriv = 0;
PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC glGetFramebufferAttachmentParameterivEXT = 0;
PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVOESPROC glGetFramebufferAttachmentParameterivOES = 0;
PFNGLGETFRAMEBUFFERPARAMETERFVAMDPROC glGetFramebufferParameterfvAMD = 0;
PFNGLGETFRAMEBUFFERPARAMETERIVPROC glGetFramebufferParameteriv = 0;
PFNGLGETFRAMEBUFFERPARAMETERIVEXTPROC glGetFramebufferParameterivEXT = 0;
PFNGLGETFRAMEBUFFERPIXELLOCALSTORAGESIZEEXTPROC glGetFramebufferPixelLocalStorageSizeEXT = 0;
PFNGLGETGRAPHICSRESETSTATUSPROC glGetGraphicsResetStatus = 0;
PFNGLGETGRAPHICSRESETSTATUSARBPROC glGetGraphicsResetStatusARB = 0;
PFNGLGETGRAPHICSRESETSTATUSEXTPROC glGetGraphicsResetStatusEXT = 0;
PFNGLGETGRAPHICSRESETSTATUSKHRPROC glGetGraphicsResetStatusKHR = 0;
PFNGLGETHANDLEARBPROC glGetHandleARB = 0;
PFNGLGETHISTOGRAMPROC glGetHistogram = 0;
PFNGLGETHISTOGRAMEXTPROC glGetHistogramEXT = 0;
PFNGLGETHISTOGRAMPARAMETERFVPROC glGetHistogramParameterfv = 0;
PFNGLGETHISTOGRAMPARAMETERFVEXTPROC glGetHistogramParameterfvEXT = 0;
PFNGLGETHISTOGRAMPARAMETERIVPROC glGetHistogramParameteriv = 0;
PFNGLGETHISTOGRAMPARAMETERIVEXTPROC glGetHistogramParameterivEXT = 0;
PFNGLGETHISTOGRAMPARAMETERXVOESPROC glGetHistogramParameterxvOES = 0;
PFNGLGETIMAGEHANDLEARBPROC glGetImageHandleARB = 0;
PFNGLGETIMAGEHANDLENVPROC glGetImageHandleNV = 0;
PFNGLGETIMAGETRANSFORMPARAMETERFVHPPROC glGetImageTransformParameterfvHP = 0;
PFNGLGETIMAGETRANSFORMPARAMETERIVHPPROC glGetImageTransformParameterivHP = 0;
PFNGLGETINFOLOGARBPROC glGetInfoLogARB = 0;
PFNGLGETINSTRUMENTSSGIXPROC glGetInstrumentsSGIX = 0;
PFNGLGETINTEGER64I_VPROC glGetInteger64i_v = 0;
PFNGLGETINTEGER64VPROC glGetInteger64v = 0;
PFNGLGETINTEGER64VAPPLEPROC glGetInteger64vAPPLE = 0;
PFNGLGETINTEGER64VEXTPROC glGetInteger64vEXT = 0;
PFNGLGETINTEGERINDEXEDVEXTPROC glGetIntegerIndexedvEXT = 0;
PFNGLGETINTEGERI_VPROC glGetIntegeri_v = 0;
PFNGLGETINTEGERI_VEXTPROC glGetIntegeri_vEXT = 0;
PFNGLGETINTEGERUI64I_VNVPROC glGetIntegerui64i_vNV = 0;
PFNGLGETINTEGERUI64VNVPROC glGetIntegerui64vNV = 0;
PFNGLGETINTEGERVPROC glGetIntegerv = 0;
PFNGLGETINTERNALFORMATSAMPLEIVNVPROC glGetInternalformatSampleivNV = 0;
PFNGLGETINTERNALFORMATI64VPROC glGetInternalformati64v = 0;
PFNGLGETINTERNALFORMATIVPROC glGetInternalformativ = 0;
PFNGLGETINVARIANTBOOLEANVEXTPROC glGetInvariantBooleanvEXT = 0;
PFNGLGETINVARIANTFLOATVEXTPROC glGetInvariantFloatvEXT = 0;
PFNGLGETINVARIANTINTEGERVEXTPROC glGetInvariantIntegervEXT = 0;
PFNGLGETLIGHTFVPROC glGetLightfv = 0;
PFNGLGETLIGHTIVPROC glGetLightiv = 0;
PFNGLGETLIGHTXOESPROC glGetLightxOES = 0;
PFNGLGETLIGHTXVPROC glGetLightxv = 0;
PFNGLGETLIGHTXVOESPROC glGetLightxvOES = 0;
PFNGLGETLISTPARAMETERFVSGIXPROC glGetListParameterfvSGIX = 0;
PFNGLGETLISTPARAMETERIVSGIXPROC glGetListParameterivSGIX = 0;
PFNGLGETLOCALCONSTANTBOOLEANVEXTPROC glGetLocalConstantBooleanvEXT = 0;
PFNGLGETLOCALCONSTANTFLOATVEXTPROC glGetLocalConstantFloatvEXT = 0;
PFNGLGETLOCALCONSTANTINTEGERVEXTPROC glGetLocalConstantIntegervEXT = 0;
PFNGLGETMAPATTRIBPARAMETERFVNVPROC glGetMapAttribParameterfvNV = 0;
PFNGLGETMAPATTRIBPARAMETERIVNVPROC glGetMapAttribParameterivNV = 0;
PFNGLGETMAPCONTROLPOINTSNVPROC glGetMapControlPointsNV = 0;
PFNGLGETMAPPARAMETERFVNVPROC glGetMapParameterfvNV = 0;
PFNGLGETMAPPARAMETERIVNVPROC glGetMapParameterivNV = 0;
PFNGLGETMAPDVPROC glGetMapdv = 0;
PFNGLGETMAPFVPROC glGetMapfv = 0;
PFNGLGETMAPIVPROC glGetMapiv = 0;
PFNGLGETMAPXVOESPROC glGetMapxvOES = 0;
PFNGLGETMATERIALFVPROC glGetMaterialfv = 0;
PFNGLGETMATERIALIVPROC glGetMaterialiv = 0;
PFNGLGETMATERIALXOESPROC glGetMaterialxOES = 0;
PFNGLGETMATERIALXVPROC glGetMaterialxv = 0;
PFNGLGETMATERIALXVOESPROC glGetMaterialxvOES = 0;
PFNGLGETMEMORYOBJECTDETACHEDRESOURCESUIVNVPROC glGetMemoryObjectDetachedResourcesuivNV = 0;
PFNGLGETMEMORYOBJECTPARAMETERIVEXTPROC glGetMemoryObjectParameterivEXT = 0;
PFNGLGETMINMAXPROC glGetMinmax = 0;
PFNGLGETMINMAXEXTPROC glGetMinmaxEXT = 0;
PFNGLGETMINMAXPARAMETERFVPROC glGetMinmaxParameterfv = 0;
PFNGLGETMINMAXPARAMETERFVEXTPROC glGetMinmaxParameterfvEXT = 0;
PFNGLGETMINMAXPARAMETERIVPROC glGetMinmaxParameteriv = 0;
PFNGLGETMINMAXPARAMETERIVEXTPROC glGetMinmaxParameterivEXT = 0;
PFNGLGETMULTITEXENVFVEXTPROC glGetMultiTexEnvfvEXT = 0;
PFNGLGETMULTITEXENVIVEXTPROC glGetMultiTexEnvivEXT = 0;
PFNGLGETMULTITEXGENDVEXTPROC glGetMultiTexGendvEXT = 0;
PFNGLGETMULTITEXGENFVEXTPROC glGetMultiTexGenfvEXT = 0;
PFNGLGETMULTITEXGENIVEXTPROC glGetMultiTexGenivEXT = 0;
PFNGLGETMULTITEXIMAGEEXTPROC glGetMultiTexImageEXT = 0;
PFNGLGETMULTITEXLEVELPARAMETERFVEXTPROC glGetMultiTexLevelParameterfvEXT = 0;
PFNGLGETMULTITEXLEVELPARAMETERIVEXTPROC glGetMultiTexLevelParameterivEXT = 0;
PFNGLGETMULTITEXPARAMETERIIVEXTPROC glGetMultiTexParameterIivEXT = 0;
PFNGLGETMULTITEXPARAMETERIUIVEXTPROC glGetMultiTexParameterIuivEXT = 0;
PFNGLGETMULTITEXPARAMETERFVEXTPROC glGetMultiTexParameterfvEXT = 0;
PFNGLGETMULTITEXPARAMETERIVEXTPROC glGetMultiTexParameterivEXT = 0;
PFNGLGETMULTISAMPLEFVPROC glGetMultisamplefv = 0;
PFNGLGETMULTISAMPLEFVNVPROC glGetMultisamplefvNV = 0;
PFNGLGETNAMEDBUFFERPARAMETERI64VPROC glGetNamedBufferParameteri64v = 0;
PFNGLGETNAMEDBUFFERPARAMETERIVPROC glGetNamedBufferParameteriv = 0;
PFNGLGETNAMEDBUFFERPARAMETERIVEXTPROC glGetNamedBufferParameterivEXT = 0;
PFNGLGETNAMEDBUFFERPARAMETERUI64VNVPROC glGetNamedBufferParameterui64vNV = 0;
PFNGLGETNAMEDBUFFERPOINTERVPROC glGetNamedBufferPointerv = 0;
PFNGLGETNAMEDBUFFERPOINTERVEXTPROC glGetNamedBufferPointervEXT = 0;
PFNGLGETNAMEDBUFFERSUBDATAPROC glGetNamedBufferSubData = 0;
PFNGLGETNAMEDBUFFERSUBDATAEXTPROC glGetNamedBufferSubDataEXT = 0;
PFNGLGETNAMEDFRAMEBUFFERPARAMETERFVAMDPROC glGetNamedFramebufferParameterfvAMD = 0;
PFNGLGETNAMEDFRAMEBUFFERATTACHMENTPARAMETERIVPROC glGetNamedFramebufferAttachmentParameteriv = 0;
PFNGLGETNAMEDFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC glGetNamedFramebufferAttachmentParameterivEXT = 0;
PFNGLGETNAMEDFRAMEBUFFERPARAMETERIVPROC glGetNamedFramebufferParameteriv = 0;
PFNGLGETNAMEDFRAMEBUFFERPARAMETERIVEXTPROC glGetNamedFramebufferParameterivEXT = 0;
PFNGLGETNAMEDPROGRAMLOCALPARAMETERIIVEXTPROC glGetNamedProgramLocalParameterIivEXT = 0;
PFNGLGETNAMEDPROGRAMLOCALPARAMETERIUIVEXTPROC glGetNamedProgramLocalParameterIuivEXT = 0;
PFNGLGETNAMEDPROGRAMLOCALPARAMETERDVEXTPROC glGetNamedProgramLocalParameterdvEXT = 0;
PFNGLGETNAMEDPROGRAMLOCALPARAMETERFVEXTPROC glGetNamedProgramLocalParameterfvEXT = 0;
PFNGLGETNAMEDPROGRAMSTRINGEXTPROC glGetNamedProgramStringEXT = 0;
PFNGLGETNAMEDPROGRAMIVEXTPROC glGetNamedProgramivEXT = 0;
PFNGLGETNAMEDRENDERBUFFERPARAMETERIVPROC glGetNamedRenderbufferParameteriv = 0;
PFNGLGETNAMEDRENDERBUFFERPARAMETERIVEXTPROC glGetNamedRenderbufferParameterivEXT = 0;
PFNGLGETNAMEDSTRINGARBPROC glGetNamedStringARB = 0;
PFNGLGETNAMEDSTRINGIVARBPROC glGetNamedStringivARB = 0;
PFNGLGETNEXTPERFQUERYIDINTELPROC glGetNextPerfQueryIdINTEL = 0;
PFNGLGETOBJECTBUFFERFVATIPROC glGetObjectBufferfvATI = 0;
PFNGLGETOBJECTBUFFERIVATIPROC glGetObjectBufferivATI = 0;
PFNGLGETOBJECTLABELPROC glGetObjectLabel = 0;
PFNGLGETOBJECTLABELEXTPROC glGetObjectLabelEXT = 0;
PFNGLGETOBJECTLABELKHRPROC glGetObjectLabelKHR = 0;
PFNGLGETOBJECTPARAMETERFVARBPROC glGetObjectParameterfvARB = 0;
PFNGLGETOBJECTPARAMETERIVAPPLEPROC glGetObjectParameterivAPPLE = 0;
PFNGLGETOBJECTPARAMETERIVARBPROC glGetObjectParameterivARB = 0;
PFNGLGETOBJECTPTRLABELPROC glGetObjectPtrLabel = 0;
PFNGLGETOBJECTPTRLABELKHRPROC glGetObjectPtrLabelKHR = 0;
PFNGLGETOCCLUSIONQUERYIVNVPROC glGetOcclusionQueryivNV = 0;
PFNGLGETOCCLUSIONQUERYUIVNVPROC glGetOcclusionQueryuivNV = 0;
PFNGLGETPATHCOLORGENFVNVPROC glGetPathColorGenfvNV = 0;
PFNGLGETPATHCOLORGENIVNVPROC glGetPathColorGenivNV = 0;
PFNGLGETPATHCOMMANDSNVPROC glGetPathCommandsNV = 0;
PFNGLGETPATHCOORDSNVPROC glGetPathCoordsNV = 0;
PFNGLGETPATHDASHARRAYNVPROC glGetPathDashArrayNV = 0;
PFNGLGETPATHLENGTHNVPROC glGetPathLengthNV = 0;
PFNGLGETPATHMETRICRANGENVPROC glGetPathMetricRangeNV = 0;
PFNGLGETPATHMETRICSNVPROC glGetPathMetricsNV = 0;
PFNGLGETPATHPARAMETERFVNVPROC glGetPathParameterfvNV = 0;
PFNGLGETPATHPARAMETERIVNVPROC glGetPathParameterivNV = 0;
PFNGLGETPATHSPACINGNVPROC glGetPathSpacingNV = 0;
PFNGLGETPATHTEXGENFVNVPROC glGetPathTexGenfvNV = 0;
PFNGLGETPATHTEXGENIVNVPROC glGetPathTexGenivNV = 0;
PFNGLGETPERFCOUNTERINFOINTELPROC glGetPerfCounterInfoINTEL = 0;
PFNGLGETPERFMONITORCOUNTERDATAAMDPROC glGetPerfMonitorCounterDataAMD = 0;
PFNGLGETPERFMONITORCOUNTERINFOAMDPROC glGetPerfMonitorCounterInfoAMD = 0;
PFNGLGETPERFMONITORCOUNTERSTRINGAMDPROC glGetPerfMonitorCounterStringAMD = 0;
PFNGLGETPERFMONITORCOUNTERSAMDPROC glGetPerfMonitorCountersAMD = 0;
PFNGLGETPERFMONITORGROUPSTRINGAMDPROC glGetPerfMonitorGroupStringAMD = 0;
PFNGLGETPERFMONITORGROUPSAMDPROC glGetPerfMonitorGroupsAMD = 0;
PFNGLGETPERFQUERYDATAINTELPROC glGetPerfQueryDataINTEL = 0;
PFNGLGETPERFQUERYIDBYNAMEINTELPROC glGetPerfQueryIdByNameINTEL = 0;
PFNGLGETPERFQUERYINFOINTELPROC glGetPerfQueryInfoINTEL = 0;
PFNGLGETPIXELMAPFVPROC glGetPixelMapfv = 0;
PFNGLGETPIXELMAPUIVPROC glGetPixelMapuiv = 0;
PFNGLGETPIXELMAPUSVPROC glGetPixelMapusv = 0;
PFNGLGETPIXELMAPXVPROC glGetPixelMapxv = 0;
PFNGLGETPIXELTEXGENPARAMETERFVSGISPROC glGetPixelTexGenParameterfvSGIS = 0;
PFNGLGETPIXELTEXGENPARAMETERIVSGISPROC glGetPixelTexGenParameterivSGIS = 0;
PFNGLGETPIXELTRANSFORMPARAMETERFVEXTPROC glGetPixelTransformParameterfvEXT = 0;
PFNGLGETPIXELTRANSFORMPARAMETERIVEXTPROC glGetPixelTransformParameterivEXT = 0;
PFNGLGETPOINTERINDEXEDVEXTPROC glGetPointerIndexedvEXT = 0;
PFNGLGETPOINTERI_VEXTPROC glGetPointeri_vEXT = 0;
PFNGLGETPOINTERVPROC glGetPointerv = 0;
PFNGLGETPOINTERVEXTPROC glGetPointervEXT = 0;
PFNGLGETPOINTERVKHRPROC glGetPointervKHR = 0;
PFNGLGETPOLYGONSTIPPLEPROC glGetPolygonStipple = 0;
PFNGLGETPROGRAMBINARYPROC glGetProgramBinary = 0;
PFNGLGETPROGRAMBINARYOESPROC glGetProgramBinaryOES = 0;
PFNGLGETPROGRAMENVPARAMETERIIVNVPROC glGetProgramEnvParameterIivNV = 0;
PFNGLGETPROGRAMENVPARAMETERIUIVNVPROC glGetProgramEnvParameterIuivNV = 0;
PFNGLGETPROGRAMENVPARAMETERDVARBPROC glGetProgramEnvParameterdvARB = 0;
PFNGLGETPROGRAMENVPARAMETERFVARBPROC glGetProgramEnvParameterfvARB = 0;
PFNGLGETPROGRAMINFOLOGPROC glGetProgramInfoLog = 0;
PFNGLGETPROGRAMINTERFACEIVPROC glGetProgramInterfaceiv = 0;
PFNGLGETPROGRAMLOCALPARAMETERIIVNVPROC glGetProgramLocalParameterIivNV = 0;
PFNGLGETPROGRAMLOCALPARAMETERIUIVNVPROC glGetProgramLocalParameterIuivNV = 0;
PFNGLGETPROGRAMLOCALPARAMETERDVARBPROC glGetProgramLocalParameterdvARB = 0;
PFNGLGETPROGRAMLOCALPARAMETERFVARBPROC glGetProgramLocalParameterfvARB = 0;
PFNGLGETPROGRAMNAMEDPARAMETERDVNVPROC glGetProgramNamedParameterdvNV = 0;
PFNGLGETPROGRAMNAMEDPARAMETERFVNVPROC glGetProgramNamedParameterfvNV = 0;
PFNGLGETPROGRAMPARAMETERDVNVPROC glGetProgramParameterdvNV = 0;
PFNGLGETPROGRAMPARAMETERFVNVPROC glGetProgramParameterfvNV = 0;
PFNGLGETPROGRAMPIPELINEINFOLOGPROC glGetProgramPipelineInfoLog = 0;
PFNGLGETPROGRAMPIPELINEINFOLOGEXTPROC glGetProgramPipelineInfoLogEXT = 0;
PFNGLGETPROGRAMPIPELINEIVPROC glGetProgramPipelineiv = 0;
PFNGLGETPROGRAMPIPELINEIVEXTPROC glGetProgramPipelineivEXT = 0;
PFNGLGETPROGRAMRESOURCEINDEXPROC glGetProgramResourceIndex = 0;
PFNGLGETPROGRAMRESOURCELOCATIONPROC glGetProgramResourceLocation = 0;
PFNGLGETPROGRAMRESOURCELOCATIONINDEXPROC glGetProgramResourceLocationIndex = 0;
PFNGLGETPROGRAMRESOURCELOCATIONINDEXEXTPROC glGetProgramResourceLocationIndexEXT = 0;
PFNGLGETPROGRAMRESOURCENAMEPROC glGetProgramResourceName = 0;
PFNGLGETPROGRAMRESOURCEFVNVPROC glGetProgramResourcefvNV = 0;
PFNGLGETPROGRAMRESOURCEIVPROC glGetProgramResourceiv = 0;
PFNGLGETPROGRAMSTAGEIVPROC glGetProgramStageiv = 0;
PFNGLGETPROGRAMSTRINGARBPROC glGetProgramStringARB = 0;
PFNGLGETPROGRAMSTRINGNVPROC glGetProgramStringNV = 0;
PFNGLGETPROGRAMSUBROUTINEPARAMETERUIVNVPROC glGetProgramSubroutineParameteruivNV = 0;
PFNGLGETPROGRAMIVPROC glGetProgramiv = 0;
PFNGLGETPROGRAMIVARBPROC glGetProgramivARB = 0;
PFNGLGETPROGRAMIVNVPROC glGetProgramivNV = 0;
PFNGLGETQUERYBUFFEROBJECTI64VPROC glGetQueryBufferObjecti64v = 0;
PFNGLGETQUERYBUFFEROBJECTIVPROC glGetQueryBufferObjectiv = 0;
PFNGLGETQUERYBUFFEROBJECTUI64VPROC glGetQueryBufferObjectui64v = 0;
PFNGLGETQUERYBUFFEROBJECTUIVPROC glGetQueryBufferObjectuiv = 0;
PFNGLGETQUERYINDEXEDIVPROC glGetQueryIndexediv = 0;
PFNGLGETQUERYOBJECTI64VPROC glGetQueryObjecti64v = 0;
PFNGLGETQUERYOBJECTI64VEXTPROC glGetQueryObjecti64vEXT = 0;
PFNGLGETQUERYOBJECTIVPROC glGetQueryObjectiv = 0;
PFNGLGETQUERYOBJECTIVARBPROC glGetQueryObjectivARB = 0;
PFNGLGETQUERYOBJECTIVEXTPROC glGetQueryObjectivEXT = 0;
PFNGLGETQUERYOBJECTUI64VPROC glGetQueryObjectui64v = 0;
PFNGLGETQUERYOBJECTUI64VEXTPROC glGetQueryObjectui64vEXT = 0;
PFNGLGETQUERYOBJECTUIVPROC glGetQueryObjectuiv = 0;
PFNGLGETQUERYOBJECTUIVARBPROC glGetQueryObjectuivARB = 0;
PFNGLGETQUERYOBJECTUIVEXTPROC glGetQueryObjectuivEXT = 0;
PFNGLGETQUERYIVPROC glGetQueryiv = 0;
PFNGLGETQUERYIVARBPROC glGetQueryivARB = 0;
PFNGLGETQUERYIVEXTPROC glGetQueryivEXT = 0;
PFNGLGETRENDERBUFFERPARAMETERIVPROC glGetRenderbufferParameteriv = 0;
PFNGLGETRENDERBUFFERPARAMETERIVEXTPROC glGetRenderbufferParameterivEXT = 0;
PFNGLGETRENDERBUFFERPARAMETERIVOESPROC glGetRenderbufferParameterivOES = 0;
PFNGLGETSAMPLERPARAMETERIIVPROC glGetSamplerParameterIiv = 0;
PFNGLGETSAMPLERPARAMETERIIVEXTPROC glGetSamplerParameterIivEXT = 0;
PFNGLGETSAMPLERPARAMETERIIVOESPROC glGetSamplerParameterIivOES = 0;
PFNGLGETSAMPLERPARAMETERIUIVPROC glGetSamplerParameterIuiv = 0;
PFNGLGETSAMPLERPARAMETERIUIVEXTPROC glGetSamplerParameterIuivEXT = 0;
PFNGLGETSAMPLERPARAMETERIUIVOESPROC glGetSamplerParameterIuivOES = 0;
PFNGLGETSAMPLERPARAMETERFVPROC glGetSamplerParameterfv = 0;
PFNGLGETSAMPLERPARAMETERIVPROC glGetSamplerParameteriv = 0;
PFNGLGETSEMAPHOREPARAMETERIVNVPROC glGetSemaphoreParameterivNV = 0;
PFNGLGETSEMAPHOREPARAMETERUI64VEXTPROC glGetSemaphoreParameterui64vEXT = 0;
PFNGLGETSEPARABLEFILTERPROC glGetSeparableFilter = 0;
PFNGLGETSEPARABLEFILTEREXTPROC glGetSeparableFilterEXT = 0;
PFNGLGETSHADERINFOLOGPROC glGetShaderInfoLog = 0;
PFNGLGETSHADERPRECISIONFORMATPROC glGetShaderPrecisionFormat = 0;
PFNGLGETSHADERSOURCEPROC glGetShaderSource = 0;
PFNGLGETSHADERSOURCEARBPROC glGetShaderSourceARB = 0;
PFNGLGETSHADERIVPROC glGetShaderiv = 0;
PFNGLGETSHADINGRATEIMAGEPALETTENVPROC glGetShadingRateImagePaletteNV = 0;
PFNGLGETSHADINGRATESAMPLELOCATIONIVNVPROC glGetShadingRateSampleLocationivNV = 0;
PFNGLGETSHARPENTEXFUNCSGISPROC glGetSharpenTexFuncSGIS = 0;
PFNGLGETSTAGEINDEXNVPROC glGetStageIndexNV = 0;
PFNGLGETSTRINGPROC glGetString = 0;
PFNGLGETSTRINGIPROC glGetStringi = 0;
PFNGLGETSUBROUTINEINDEXPROC glGetSubroutineIndex = 0;
PFNGLGETSUBROUTINEUNIFORMLOCATIONPROC glGetSubroutineUniformLocation = 0;
PFNGLGETSYNCIVPROC glGetSynciv = 0;
PFNGLGETSYNCIVAPPLEPROC glGetSyncivAPPLE = 0;
PFNGLGETTEXBUMPPARAMETERFVATIPROC glGetTexBumpParameterfvATI = 0;
PFNGLGETTEXBUMPPARAMETERIVATIPROC glGetTexBumpParameterivATI = 0;
PFNGLGETTEXENVFVPROC glGetTexEnvfv = 0;
PFNGLGETTEXENVIVPROC glGetTexEnviv = 0;
PFNGLGETTEXENVXVPROC glGetTexEnvxv = 0;
PFNGLGETTEXENVXVOESPROC glGetTexEnvxvOES = 0;
PFNGLGETTEXFILTERFUNCSGISPROC glGetTexFilterFuncSGIS = 0;
PFNGLGETTEXGENDVPROC glGetTexGendv = 0;
PFNGLGETTEXGENFVPROC glGetTexGenfv = 0;
PFNGLGETTEXGENFVOESPROC glGetTexGenfvOES = 0;
PFNGLGETTEXGENIVPROC glGetTexGeniv = 0;
PFNGLGETTEXGENIVOESPROC glGetTexGenivOES = 0;
PFNGLGETTEXGENXVOESPROC glGetTexGenxvOES = 0;
PFNGLGETTEXIMAGEPROC glGetTexImage = 0;
PFNGLGETTEXLEVELPARAMETERFVPROC glGetTexLevelParameterfv = 0;
PFNGLGETTEXLEVELPARAMETERIVPROC glGetTexLevelParameteriv = 0;
PFNGLGETTEXLEVELPARAMETERXVOESPROC glGetTexLevelParameterxvOES = 0;
PFNGLGETTEXPARAMETERIIVPROC glGetTexParameterIiv = 0;
PFNGLGETTEXPARAMETERIIVEXTPROC glGetTexParameterIivEXT = 0;
PFNGLGETTEXPARAMETERIIVOESPROC glGetTexParameterIivOES = 0;
PFNGLGETTEXPARAMETERIUIVPROC glGetTexParameterIuiv = 0;
PFNGLGETTEXPARAMETERIUIVEXTPROC glGetTexParameterIuivEXT = 0;
PFNGLGETTEXPARAMETERIUIVOESPROC glGetTexParameterIuivOES = 0;
PFNGLGETTEXPARAMETERPOINTERVAPPLEPROC glGetTexParameterPointervAPPLE = 0;
PFNGLGETTEXPARAMETERFVPROC glGetTexParameterfv = 0;
PFNGLGETTEXPARAMETERIVPROC glGetTexParameteriv = 0;
PFNGLGETTEXPARAMETERXVPROC glGetTexParameterxv = 0;
PFNGLGETTEXPARAMETERXVOESPROC glGetTexParameterxvOES = 0;
PFNGLGETTEXTUREHANDLEARBPROC glGetTextureHandleARB = 0;
PFNGLGETTEXTUREHANDLEIMGPROC glGetTextureHandleIMG = 0;
PFNGLGETTEXTUREHANDLENVPROC glGetTextureHandleNV = 0;
PFNGLGETTEXTUREIMAGEPROC glGetTextureImage = 0;
PFNGLGETTEXTUREIMAGEEXTPROC glGetTextureImageEXT = 0;
PFNGLGETTEXTURELEVELPARAMETERFVPROC glGetTextureLevelParameterfv = 0;
PFNGLGETTEXTURELEVELPARAMETERFVEXTPROC glGetTextureLevelParameterfvEXT = 0;
PFNGLGETTEXTURELEVELPARAMETERIVPROC glGetTextureLevelParameteriv = 0;
PFNGLGETTEXTURELEVELPARAMETERIVEXTPROC glGetTextureLevelParameterivEXT = 0;
PFNGLGETTEXTUREPARAMETERIIVPROC glGetTextureParameterIiv = 0;
PFNGLGETTEXTUREPARAMETERIIVEXTPROC glGetTextureParameterIivEXT = 0;
PFNGLGETTEXTUREPARAMETERIUIVPROC glGetTextureParameterIuiv = 0;
PFNGLGETTEXTUREPARAMETERIUIVEXTPROC glGetTextureParameterIuivEXT = 0;
PFNGLGETTEXTUREPARAMETERFVPROC glGetTextureParameterfv = 0;
PFNGLGETTEXTUREPARAMETERFVEXTPROC glGetTextureParameterfvEXT = 0;
PFNGLGETTEXTUREPARAMETERIVPROC glGetTextureParameteriv = 0;
PFNGLGETTEXTUREPARAMETERIVEXTPROC glGetTextureParameterivEXT = 0;
PFNGLGETTEXTURESAMPLERHANDLEARBPROC glGetTextureSamplerHandleARB = 0;
PFNGLGETTEXTURESAMPLERHANDLEIMGPROC glGetTextureSamplerHandleIMG = 0;
PFNGLGETTEXTURESAMPLERHANDLENVPROC glGetTextureSamplerHandleNV = 0;
PFNGLGETTEXTURESUBIMAGEPROC glGetTextureSubImage = 0;
PFNGLGETTRACKMATRIXIVNVPROC glGetTrackMatrixivNV = 0;
PFNGLGETTRANSFORMFEEDBACKVARYINGPROC glGetTransformFeedbackVarying = 0;
PFNGLGETTRANSFORMFEEDBACKVARYINGEXTPROC glGetTransformFeedbackVaryingEXT = 0;
PFNGLGETTRANSFORMFEEDBACKVARYINGNVPROC glGetTransformFeedbackVaryingNV = 0;
PFNGLGETTRANSFORMFEEDBACKI64_VPROC glGetTransformFeedbacki64_v = 0;
PFNGLGETTRANSFORMFEEDBACKI_VPROC glGetTransformFeedbacki_v = 0;
PFNGLGETTRANSFORMFEEDBACKIVPROC glGetTransformFeedbackiv = 0;
PFNGLGETTRANSLATEDSHADERSOURCEANGLEPROC glGetTranslatedShaderSourceANGLE = 0;
PFNGLGETUNIFORMBLOCKINDEXPROC glGetUniformBlockIndex = 0;
PFNGLGETUNIFORMBUFFERSIZEEXTPROC glGetUniformBufferSizeEXT = 0;
PFNGLGETUNIFORMINDICESPROC glGetUniformIndices = 0;
PFNGLGETUNIFORMLOCATIONPROC glGetUniformLocation = 0;
PFNGLGETUNIFORMLOCATIONARBPROC glGetUniformLocationARB = 0;
PFNGLGETUNIFORMOFFSETEXTPROC glGetUniformOffsetEXT = 0;
PFNGLGETUNIFORMSUBROUTINEUIVPROC glGetUniformSubroutineuiv = 0;
PFNGLGETUNIFORMDVPROC glGetUniformdv = 0;
PFNGLGETUNIFORMFVPROC glGetUniformfv = 0;
PFNGLGETUNIFORMFVARBPROC glGetUniformfvARB = 0;
PFNGLGETUNIFORMI64VARBPROC glGetUniformi64vARB = 0;
PFNGLGETUNIFORMI64VNVPROC glGetUniformi64vNV = 0;
PFNGLGETUNIFORMIVPROC glGetUniformiv = 0;
PFNGLGETUNIFORMIVARBPROC glGetUniformivARB = 0;
PFNGLGETUNIFORMUI64VARBPROC glGetUniformui64vARB = 0;
PFNGLGETUNIFORMUI64VNVPROC glGetUniformui64vNV = 0;
PFNGLGETUNIFORMUIVPROC glGetUniformuiv = 0;
PFNGLGETUNIFORMUIVEXTPROC glGetUniformuivEXT = 0;
PFNGLGETUNSIGNEDBYTEVEXTPROC glGetUnsignedBytevEXT = 0;
PFNGLGETUNSIGNEDBYTEI_VEXTPROC glGetUnsignedBytei_vEXT = 0;
PFNGLGETVARIANTARRAYOBJECTFVATIPROC glGetVariantArrayObjectfvATI = 0;
PFNGLGETVARIANTARRAYOBJECTIVATIPROC glGetVariantArrayObjectivATI = 0;
PFNGLGETVARIANTBOOLEANVEXTPROC glGetVariantBooleanvEXT = 0;
PFNGLGETVARIANTFLOATVEXTPROC glGetVariantFloatvEXT = 0;
PFNGLGETVARIANTINTEGERVEXTPROC glGetVariantIntegervEXT = 0;
PFNGLGETVARIANTPOINTERVEXTPROC glGetVariantPointervEXT = 0;
PFNGLGETVARYINGLOCATIONNVPROC glGetVaryingLocationNV = 0;
PFNGLGETVERTEXARRAYINDEXED64IVPROC glGetVertexArrayIndexed64iv = 0;
PFNGLGETVERTEXARRAYINDEXEDIVPROC glGetVertexArrayIndexediv = 0;
PFNGLGETVERTEXARRAYINTEGERI_VEXTPROC glGetVertexArrayIntegeri_vEXT = 0;
PFNGLGETVERTEXARRAYINTEGERVEXTPROC glGetVertexArrayIntegervEXT = 0;
PFNGLGETVERTEXARRAYPOINTERI_VEXTPROC glGetVertexArrayPointeri_vEXT = 0;
PFNGLGETVERTEXARRAYPOINTERVEXTPROC glGetVertexArrayPointervEXT = 0;
PFNGLGETVERTEXARRAYIVPROC glGetVertexArrayiv = 0;
PFNGLGETVERTEXATTRIBARRAYOBJECTFVATIPROC glGetVertexAttribArrayObjectfvATI = 0;
PFNGLGETVERTEXATTRIBARRAYOBJECTIVATIPROC glGetVertexAttribArrayObjectivATI = 0;
PFNGLGETVERTEXATTRIBIIVPROC glGetVertexAttribIiv = 0;
PFNGLGETVERTEXATTRIBIIVEXTPROC glGetVertexAttribIivEXT = 0;
PFNGLGETVERTEXATTRIBIUIVPROC glGetVertexAttribIuiv = 0;
PFNGLGETVERTEXATTRIBIUIVEXTPROC glGetVertexAttribIuivEXT = 0;
PFNGLGETVERTEXATTRIBLDVPROC glGetVertexAttribLdv = 0;
PFNGLGETVERTEXATTRIBLDVEXTPROC glGetVertexAttribLdvEXT = 0;
PFNGLGETVERTEXATTRIBLI64VNVPROC glGetVertexAttribLi64vNV = 0;
PFNGLGETVERTEXATTRIBLUI64VARBPROC glGetVertexAttribLui64vARB = 0;
PFNGLGETVERTEXATTRIBLUI64VNVPROC glGetVertexAttribLui64vNV = 0;
PFNGLGETVERTEXATTRIBPOINTERVPROC glGetVertexAttribPointerv = 0;
PFNGLGETVERTEXATTRIBPOINTERVARBPROC glGetVertexAttribPointervARB = 0;
PFNGLGETVERTEXATTRIBPOINTERVNVPROC glGetVertexAttribPointervNV = 0;
PFNGLGETVERTEXATTRIBDVPROC glGetVertexAttribdv = 0;
PFNGLGETVERTEXATTRIBDVARBPROC glGetVertexAttribdvARB = 0;
PFNGLGETVERTEXATTRIBDVNVPROC glGetVertexAttribdvNV = 0;
PFNGLGETVERTEXATTRIBFVPROC glGetVertexAttribfv = 0;
PFNGLGETVERTEXATTRIBFVARBPROC glGetVertexAttribfvARB = 0;
PFNGLGETVERTEXATTRIBFVNVPROC glGetVertexAttribfvNV = 0;
PFNGLGETVERTEXATTRIBIVPROC glGetVertexAttribiv = 0;
PFNGLGETVERTEXATTRIBIVARBPROC glGetVertexAttribivARB = 0;
PFNGLGETVERTEXATTRIBIVNVPROC glGetVertexAttribivNV = 0;
PFNGLGETVIDEOCAPTURESTREAMDVNVPROC glGetVideoCaptureStreamdvNV = 0;
PFNGLGETVIDEOCAPTURESTREAMFVNVPROC glGetVideoCaptureStreamfvNV = 0;
PFNGLGETVIDEOCAPTURESTREAMIVNVPROC glGetVideoCaptureStreamivNV = 0;
PFNGLGETVIDEOCAPTUREIVNVPROC glGetVideoCaptureivNV = 0;
PFNGLGETVIDEOI64VNVPROC glGetVideoi64vNV = 0;
PFNGLGETVIDEOIVNVPROC glGetVideoivNV = 0;
PFNGLGETVIDEOUI64VNVPROC glGetVideoui64vNV = 0;
PFNGLGETVIDEOUIVNVPROC glGetVideouivNV = 0;
PFNGLGETNCOLORTABLEPROC glGetnColorTable = 0;
PFNGLGETNCOLORTABLEARBPROC glGetnColorTableARB = 0;
PFNGLGETNCOMPRESSEDTEXIMAGEPROC glGetnCompressedTexImage = 0;
PFNGLGETNCOMPRESSEDTEXIMAGEARBPROC glGetnCompressedTexImageARB = 0;
PFNGLGETNCONVOLUTIONFILTERPROC glGetnConvolutionFilter = 0;
PFNGLGETNCONVOLUTIONFILTERARBPROC glGetnConvolutionFilterARB = 0;
PFNGLGETNHISTOGRAMPROC glGetnHistogram = 0;
PFNGLGETNHISTOGRAMARBPROC glGetnHistogramARB = 0;
PFNGLGETNMAPDVPROC glGetnMapdv = 0;
PFNGLGETNMAPDVARBPROC glGetnMapdvARB = 0;
PFNGLGETNMAPFVPROC glGetnMapfv = 0;
PFNGLGETNMAPFVARBPROC glGetnMapfvARB = 0;
PFNGLGETNMAPIVPROC glGetnMapiv = 0;
PFNGLGETNMAPIVARBPROC glGetnMapivARB = 0;
PFNGLGETNMINMAXPROC glGetnMinmax = 0;
PFNGLGETNMINMAXARBPROC glGetnMinmaxARB = 0;
PFNGLGETNPIXELMAPFVPROC glGetnPixelMapfv = 0;
PFNGLGETNPIXELMAPFVARBPROC glGetnPixelMapfvARB = 0;
PFNGLGETNPIXELMAPUIVPROC glGetnPixelMapuiv = 0;
PFNGLGETNPIXELMAPUIVARBPROC glGetnPixelMapuivARB = 0;
PFNGLGETNPIXELMAPUSVPROC glGetnPixelMapusv = 0;
PFNGLGETNPIXELMAPUSVARBPROC glGetnPixelMapusvARB = 0;
PFNGLGETNPOLYGONSTIPPLEPROC glGetnPolygonStipple = 0;
PFNGLGETNPOLYGONSTIPPLEARBPROC glGetnPolygonStippleARB = 0;
PFNGLGETNSEPARABLEFILTERPROC glGetnSeparableFilter = 0;
PFNGLGETNSEPARABLEFILTERARBPROC glGetnSeparableFilterARB = 0;
PFNGLGETNTEXIMAGEPROC glGetnTexImage = 0;
PFNGLGETNTEXIMAGEARBPROC glGetnTexImageARB = 0;
PFNGLGETNUNIFORMDVPROC glGetnUniformdv = 0;
PFNGLGETNUNIFORMDVARBPROC glGetnUniformdvARB = 0;
PFNGLGETNUNIFORMFVPROC glGetnUniformfv = 0;
PFNGLGETNUNIFORMFVARBPROC glGetnUniformfvARB = 0;
PFNGLGETNUNIFORMFVEXTPROC glGetnUniformfvEXT = 0;
PFNGLGETNUNIFORMFVKHRPROC glGetnUniformfvKHR = 0;
PFNGLGETNUNIFORMI64VARBPROC glGetnUniformi64vARB = 0;
PFNGLGETNUNIFORMIVPROC glGetnUniformiv = 0;
PFNGLGETNUNIFORMIVARBPROC glGetnUniformivARB = 0;
PFNGLGETNUNIFORMIVEXTPROC glGetnUniformivEXT = 0;
PFNGLGETNUNIFORMIVKHRPROC glGetnUniformivKHR = 0;
PFNGLGETNUNIFORMUI64VARBPROC glGetnUniformui64vARB = 0;
PFNGLGETNUNIFORMUIVPROC glGetnUniformuiv = 0;
PFNGLGETNUNIFORMUIVARBPROC glGetnUniformuivARB = 0;
PFNGLGETNUNIFORMUIVKHRPROC glGetnUniformuivKHR = 0;
PFNGLGLOBALALPHAFACTORBSUNPROC glGlobalAlphaFactorbSUN = 0;
PFNGLGLOBALALPHAFACTORDSUNPROC glGlobalAlphaFactordSUN = 0;
PFNGLGLOBALALPHAFACTORFSUNPROC glGlobalAlphaFactorfSUN = 0;
PFNGLGLOBALALPHAFACTORISUNPROC glGlobalAlphaFactoriSUN = 0;
PFNGLGLOBALALPHAFACTORSSUNPROC glGlobalAlphaFactorsSUN = 0;
PFNGLGLOBALALPHAFACTORUBSUNPROC glGlobalAlphaFactorubSUN = 0;
PFNGLGLOBALALPHAFACTORUISUNPROC glGlobalAlphaFactoruiSUN = 0;
PFNGLGLOBALALPHAFACTORUSSUNPROC glGlobalAlphaFactorusSUN = 0;
PFNGLHINTPROC glHint = 0;
PFNGLHINTPGIPROC glHintPGI = 0;
PFNGLHISTOGRAMPROC glHistogram = 0;
PFNGLHISTOGRAMEXTPROC glHistogramEXT = 0;
PFNGLIGLOOINTERFACESGIXPROC glIglooInterfaceSGIX = 0;
PFNGLIMAGETRANSFORMPARAMETERFHPPROC glImageTransformParameterfHP = 0;
PFNGLIMAGETRANSFORMPARAMETERFVHPPROC glImageTransformParameterfvHP = 0;
PFNGLIMAGETRANSFORMPARAMETERIHPPROC glImageTransformParameteriHP = 0;
PFNGLIMAGETRANSFORMPARAMETERIVHPPROC glImageTransformParameterivHP = 0;
PFNGLIMPORTMEMORYFDEXTPROC glImportMemoryFdEXT = 0;
PFNGLIMPORTMEMORYWIN32HANDLEEXTPROC glImportMemoryWin32HandleEXT = 0;
PFNGLIMPORTMEMORYWIN32NAMEEXTPROC glImportMemoryWin32NameEXT = 0;
PFNGLIMPORTSEMAPHOREFDEXTPROC glImportSemaphoreFdEXT = 0;
PFNGLIMPORTSEMAPHOREWIN32HANDLEEXTPROC glImportSemaphoreWin32HandleEXT = 0;
PFNGLIMPORTSEMAPHOREWIN32NAMEEXTPROC glImportSemaphoreWin32NameEXT = 0;
PFNGLIMPORTSYNCEXTPROC glImportSyncEXT = 0;
PFNGLINDEXFORMATNVPROC glIndexFormatNV = 0;
PFNGLINDEXFUNCEXTPROC glIndexFuncEXT = 0;
PFNGLINDEXMASKPROC glIndexMask = 0;
PFNGLINDEXMATERIALEXTPROC glIndexMaterialEXT = 0;
PFNGLINDEXPOINTERPROC glIndexPointer = 0;
PFNGLINDEXPOINTEREXTPROC glIndexPointerEXT = 0;
PFNGLINDEXPOINTERLISTIBMPROC glIndexPointerListIBM = 0;
PFNGLINDEXDPROC glIndexd = 0;
PFNGLINDEXDVPROC glIndexdv = 0;
PFNGLINDEXFPROC glIndexf = 0;
PFNGLINDEXFVPROC glIndexfv = 0;
PFNGLINDEXIPROC glIndexi = 0;
PFNGLINDEXIVPROC glIndexiv = 0;
PFNGLINDEXSPROC glIndexs = 0;
PFNGLINDEXSVPROC glIndexsv = 0;
PFNGLINDEXUBPROC glIndexub = 0;
PFNGLINDEXUBVPROC glIndexubv = 0;
PFNGLINDEXXOESPROC glIndexxOES = 0;
PFNGLINDEXXVOESPROC glIndexxvOES = 0;
PFNGLINITNAMESPROC glInitNames = 0;
PFNGLINSERTCOMPONENTEXTPROC glInsertComponentEXT = 0;
PFNGLINSERTEVENTMARKEREXTPROC glInsertEventMarkerEXT = 0;
PFNGLINSTRUMENTSBUFFERSGIXPROC glInstrumentsBufferSGIX = 0;
PFNGLINTERLEAVEDARRAYSPROC glInterleavedArrays = 0;
PFNGLINTERPOLATEPATHSNVPROC glInterpolatePathsNV = 0;
PFNGLINVALIDATEBUFFERDATAPROC glInvalidateBufferData = 0;
PFNGLINVALIDATEBUFFERSUBDATAPROC glInvalidateBufferSubData = 0;
PFNGLINVALIDATEFRAMEBUFFERPROC glInvalidateFramebuffer = 0;
PFNGLINVALIDATENAMEDFRAMEBUFFERDATAPROC glInvalidateNamedFramebufferData = 0;
PFNGLINVALIDATENAMEDFRAMEBUFFERSUBDATAPROC glInvalidateNamedFramebufferSubData = 0;
PFNGLINVALIDATESUBFRAMEBUFFERPROC glInvalidateSubFramebuffer = 0;
PFNGLINVALIDATETEXIMAGEPROC glInvalidateTexImage = 0;
PFNGLINVALIDATETEXSUBIMAGEPROC glInvalidateTexSubImage = 0;
PFNGLISASYNCMARKERSGIXPROC glIsAsyncMarkerSGIX = 0;
PFNGLISBUFFERPROC glIsBuffer = 0;
PFNGLISBUFFERARBPROC glIsBufferARB = 0;
PFNGLISBUFFERRESIDENTNVPROC glIsBufferResidentNV = 0;
PFNGLISCOMMANDLISTNVPROC glIsCommandListNV = 0;
PFNGLISENABLEDPROC glIsEnabled = 0;
PFNGLISENABLEDINDEXEDEXTPROC glIsEnabledIndexedEXT = 0;
PFNGLISENABLEDIPROC glIsEnabledi = 0;
PFNGLISENABLEDIEXTPROC glIsEnablediEXT = 0;
PFNGLISENABLEDINVPROC glIsEnablediNV = 0;
PFNGLISENABLEDIOESPROC glIsEnablediOES = 0;
PFNGLISFENCEAPPLEPROC glIsFenceAPPLE = 0;
PFNGLISFENCENVPROC glIsFenceNV = 0;
PFNGLISFRAMEBUFFERPROC glIsFramebuffer = 0;
PFNGLISFRAMEBUFFEREXTPROC glIsFramebufferEXT = 0;
PFNGLISFRAMEBUFFEROESPROC glIsFramebufferOES = 0;
PFNGLISIMAGEHANDLERESIDENTARBPROC glIsImageHandleResidentARB = 0;
PFNGLISIMAGEHANDLERESIDENTNVPROC glIsImageHandleResidentNV = 0;
PFNGLISLISTPROC glIsList = 0;
PFNGLISMEMORYOBJECTEXTPROC glIsMemoryObjectEXT = 0;
PFNGLISNAMEAMDPROC glIsNameAMD = 0;
PFNGLISNAMEDBUFFERRESIDENTNVPROC glIsNamedBufferResidentNV = 0;
PFNGLISNAMEDSTRINGARBPROC glIsNamedStringARB = 0;
PFNGLISOBJECTBUFFERATIPROC glIsObjectBufferATI = 0;
PFNGLISOCCLUSIONQUERYNVPROC glIsOcclusionQueryNV = 0;
PFNGLISPATHNVPROC glIsPathNV = 0;
PFNGLISPOINTINFILLPATHNVPROC glIsPointInFillPathNV = 0;
PFNGLISPOINTINSTROKEPATHNVPROC glIsPointInStrokePathNV = 0;
PFNGLISPROGRAMPROC glIsProgram = 0;
PFNGLISPROGRAMARBPROC glIsProgramARB = 0;
PFNGLISPROGRAMNVPROC glIsProgramNV = 0;
PFNGLISPROGRAMPIPELINEPROC glIsProgramPipeline = 0;
PFNGLISPROGRAMPIPELINEEXTPROC glIsProgramPipelineEXT = 0;
PFNGLISQUERYPROC glIsQuery = 0;
PFNGLISQUERYARBPROC glIsQueryARB = 0;
PFNGLISQUERYEXTPROC glIsQueryEXT = 0;
PFNGLISRENDERBUFFERPROC glIsRenderbuffer = 0;
PFNGLISRENDERBUFFEREXTPROC glIsRenderbufferEXT = 0;
PFNGLISRENDERBUFFEROESPROC glIsRenderbufferOES = 0;
PFNGLISSEMAPHOREEXTPROC glIsSemaphoreEXT = 0;
PFNGLISSAMPLERPROC glIsSampler = 0;
PFNGLISSHADERPROC glIsShader = 0;
PFNGLISSTATENVPROC glIsStateNV = 0;
PFNGLISSYNCPROC glIsSync = 0;
PFNGLISSYNCAPPLEPROC glIsSyncAPPLE = 0;
PFNGLISTEXTUREPROC glIsTexture = 0;
PFNGLISTEXTUREEXTPROC glIsTextureEXT = 0;
PFNGLISTEXTUREHANDLERESIDENTARBPROC glIsTextureHandleResidentARB = 0;
PFNGLISTEXTUREHANDLERESIDENTNVPROC glIsTextureHandleResidentNV = 0;
PFNGLISTRANSFORMFEEDBACKPROC glIsTransformFeedback = 0;
PFNGLISTRANSFORMFEEDBACKNVPROC glIsTransformFeedbackNV = 0;
PFNGLISVARIANTENABLEDEXTPROC glIsVariantEnabledEXT = 0;
PFNGLISVERTEXARRAYPROC glIsVertexArray = 0;
PFNGLISVERTEXARRAYAPPLEPROC glIsVertexArrayAPPLE = 0;
PFNGLISVERTEXARRAYOESPROC glIsVertexArrayOES = 0;
PFNGLISVERTEXATTRIBENABLEDAPPLEPROC glIsVertexAttribEnabledAPPLE = 0;
PFNGLLGPUCOPYIMAGESUBDATANVXPROC glLGPUCopyImageSubDataNVX = 0;
PFNGLLGPUINTERLOCKNVXPROC glLGPUInterlockNVX = 0;
PFNGLLGPUNAMEDBUFFERSUBDATANVXPROC glLGPUNamedBufferSubDataNVX = 0;
PFNGLLABELOBJECTEXTPROC glLabelObjectEXT = 0;
PFNGLLIGHTENVISGIXPROC glLightEnviSGIX = 0;
PFNGLLIGHTMODELFPROC glLightModelf = 0;
PFNGLLIGHTMODELFVPROC glLightModelfv = 0;
PFNGLLIGHTMODELIPROC glLightModeli = 0;
PFNGLLIGHTMODELIVPROC glLightModeliv = 0;
PFNGLLIGHTMODELXPROC glLightModelx = 0;
PFNGLLIGHTMODELXOESPROC glLightModelxOES = 0;
PFNGLLIGHTMODELXVPROC glLightModelxv = 0;
PFNGLLIGHTMODELXVOESPROC glLightModelxvOES = 0;
PFNGLLIGHTFPROC glLightf = 0;
PFNGLLIGHTFVPROC glLightfv = 0;
PFNGLLIGHTIPROC glLighti = 0;
PFNGLLIGHTIVPROC glLightiv = 0;
PFNGLLIGHTXPROC glLightx = 0;
PFNGLLIGHTXOESPROC glLightxOES = 0;
PFNGLLIGHTXVPROC glLightxv = 0;
PFNGLLIGHTXVOESPROC glLightxvOES = 0;
PFNGLLINESTIPPLEPROC glLineStipple = 0;
PFNGLLINEWIDTHPROC glLineWidth = 0;
PFNGLLINEWIDTHXPROC glLineWidthx = 0;
PFNGLLINEWIDTHXOESPROC glLineWidthxOES = 0;
PFNGLLINKPROGRAMPROC glLinkProgram = 0;
PFNGLLINKPROGRAMARBPROC glLinkProgramARB = 0;
PFNGLLISTBASEPROC glListBase = 0;
PFNGLLISTDRAWCOMMANDSSTATESCLIENTNVPROC glListDrawCommandsStatesClientNV = 0;
PFNGLLISTPARAMETERFSGIXPROC glListParameterfSGIX = 0;
PFNGLLISTPARAMETERFVSGIXPROC glListParameterfvSGIX = 0;
PFNGLLISTPARAMETERISGIXPROC glListParameteriSGIX = 0;
PFNGLLISTPARAMETERIVSGIXPROC glListParameterivSGIX = 0;
PFNGLLOADIDENTITYPROC glLoadIdentity = 0;
PFNGLLOADIDENTITYDEFORMATIONMAPSGIXPROC glLoadIdentityDeformationMapSGIX = 0;
PFNGLLOADMATRIXDPROC glLoadMatrixd = 0;
PFNGLLOADMATRIXFPROC glLoadMatrixf = 0;
PFNGLLOADMATRIXXPROC glLoadMatrixx = 0;
PFNGLLOADMATRIXXOESPROC glLoadMatrixxOES = 0;
PFNGLLOADNAMEPROC glLoadName = 0;
PFNGLLOADPALETTEFROMMODELVIEWMATRIXOESPROC glLoadPaletteFromModelViewMatrixOES = 0;
PFNGLLOADPROGRAMNVPROC glLoadProgramNV = 0;
PFNGLLOADTRANSPOSEMATRIXDPROC glLoadTransposeMatrixd = 0;
PFNGLLOADTRANSPOSEMATRIXDARBPROC glLoadTransposeMatrixdARB = 0;
PFNGLLOADTRANSPOSEMATRIXFPROC glLoadTransposeMatrixf = 0;
PFNGLLOADTRANSPOSEMATRIXFARBPROC glLoadTransposeMatrixfARB = 0;
PFNGLLOADTRANSPOSEMATRIXXOESPROC glLoadTransposeMatrixxOES = 0;
PFNGLLOCKARRAYSEXTPROC glLockArraysEXT = 0;
PFNGLLOGICOPPROC glLogicOp = 0;
PFNGLMAKEBUFFERNONRESIDENTNVPROC glMakeBufferNonResidentNV = 0;
PFNGLMAKEBUFFERRESIDENTNVPROC glMakeBufferResidentNV = 0;
PFNGLMAKEIMAGEHANDLENONRESIDENTARBPROC glMakeImageHandleNonResidentARB = 0;
PFNGLMAKEIMAGEHANDLENONRESIDENTNVPROC glMakeImageHandleNonResidentNV = 0;
PFNGLMAKEIMAGEHANDLERESIDENTARBPROC glMakeImageHandleResidentARB = 0;
PFNGLMAKEIMAGEHANDLERESIDENTNVPROC glMakeImageHandleResidentNV = 0;
PFNGLMAKENAMEDBUFFERNONRESIDENTNVPROC glMakeNamedBufferNonResidentNV = 0;
PFNGLMAKENAMEDBUFFERRESIDENTNVPROC glMakeNamedBufferResidentNV = 0;
PFNGLMAKETEXTUREHANDLENONRESIDENTARBPROC glMakeTextureHandleNonResidentARB = 0;
PFNGLMAKETEXTUREHANDLENONRESIDENTNVPROC glMakeTextureHandleNonResidentNV = 0;
PFNGLMAKETEXTUREHANDLERESIDENTARBPROC glMakeTextureHandleResidentARB = 0;
PFNGLMAKETEXTUREHANDLERESIDENTNVPROC glMakeTextureHandleResidentNV = 0;
PFNGLMAP1DPROC glMap1d = 0;
PFNGLMAP1FPROC glMap1f = 0;
PFNGLMAP1XOESPROC glMap1xOES = 0;
PFNGLMAP2DPROC glMap2d = 0;
PFNGLMAP2FPROC glMap2f = 0;
PFNGLMAP2XOESPROC glMap2xOES = 0;
PFNGLMAPBUFFERPROC glMapBuffer = 0;
PFNGLMAPBUFFERARBPROC glMapBufferARB = 0;
PFNGLMAPBUFFEROESPROC glMapBufferOES = 0;
PFNGLMAPBUFFERRANGEPROC glMapBufferRange = 0;
PFNGLMAPBUFFERRANGEEXTPROC glMapBufferRangeEXT = 0;
PFNGLMAPCONTROLPOINTSNVPROC glMapControlPointsNV = 0;
PFNGLMAPGRID1DPROC glMapGrid1d = 0;
PFNGLMAPGRID1FPROC glMapGrid1f = 0;
PFNGLMAPGRID1XOESPROC glMapGrid1xOES = 0;
PFNGLMAPGRID2DPROC glMapGrid2d = 0;
PFNGLMAPGRID2FPROC glMapGrid2f = 0;
PFNGLMAPGRID2XOESPROC glMapGrid2xOES = 0;
PFNGLMAPNAMEDBUFFERPROC glMapNamedBuffer = 0;
PFNGLMAPNAMEDBUFFEREXTPROC glMapNamedBufferEXT = 0;
PFNGLMAPNAMEDBUFFERRANGEPROC glMapNamedBufferRange = 0;
PFNGLMAPNAMEDBUFFERRANGEEXTPROC glMapNamedBufferRangeEXT = 0;
PFNGLMAPOBJECTBUFFERATIPROC glMapObjectBufferATI = 0;
PFNGLMAPPARAMETERFVNVPROC glMapParameterfvNV = 0;
PFNGLMAPPARAMETERIVNVPROC glMapParameterivNV = 0;
PFNGLMAPTEXTURE2DINTELPROC glMapTexture2DINTEL = 0;
PFNGLMAPVERTEXATTRIB1DAPPLEPROC glMapVertexAttrib1dAPPLE = 0;
PFNGLMAPVERTEXATTRIB1FAPPLEPROC glMapVertexAttrib1fAPPLE = 0;
PFNGLMAPVERTEXATTRIB2DAPPLEPROC glMapVertexAttrib2dAPPLE = 0;
PFNGLMAPVERTEXATTRIB2FAPPLEPROC glMapVertexAttrib2fAPPLE = 0;
PFNGLMATERIALFPROC glMaterialf = 0;
PFNGLMATERIALFVPROC glMaterialfv = 0;
PFNGLMATERIALIPROC glMateriali = 0;
PFNGLMATERIALIVPROC glMaterialiv = 0;
PFNGLMATERIALXPROC glMaterialx = 0;
PFNGLMATERIALXOESPROC glMaterialxOES = 0;
PFNGLMATERIALXVPROC glMaterialxv = 0;
PFNGLMATERIALXVOESPROC glMaterialxvOES = 0;
PFNGLMATRIXFRUSTUMEXTPROC glMatrixFrustumEXT = 0;
PFNGLMATRIXINDEXPOINTERARBPROC glMatrixIndexPointerARB = 0;
PFNGLMATRIXINDEXPOINTEROESPROC glMatrixIndexPointerOES = 0;
PFNGLMATRIXINDEXUBVARBPROC glMatrixIndexubvARB = 0;
PFNGLMATRIXINDEXUIVARBPROC glMatrixIndexuivARB = 0;
PFNGLMATRIXINDEXUSVARBPROC glMatrixIndexusvARB = 0;
PFNGLMATRIXLOAD3X2FNVPROC glMatrixLoad3x2fNV = 0;
PFNGLMATRIXLOAD3X3FNVPROC glMatrixLoad3x3fNV = 0;
PFNGLMATRIXLOADIDENTITYEXTPROC glMatrixLoadIdentityEXT = 0;
PFNGLMATRIXLOADTRANSPOSE3X3FNVPROC glMatrixLoadTranspose3x3fNV = 0;
PFNGLMATRIXLOADTRANSPOSEDEXTPROC glMatrixLoadTransposedEXT = 0;
PFNGLMATRIXLOADTRANSPOSEFEXTPROC glMatrixLoadTransposefEXT = 0;
PFNGLMATRIXLOADDEXTPROC glMatrixLoaddEXT = 0;
PFNGLMATRIXLOADFEXTPROC glMatrixLoadfEXT = 0;
PFNGLMATRIXMODEPROC glMatrixMode = 0;
PFNGLMATRIXMULT3X2FNVPROC glMatrixMult3x2fNV = 0;
PFNGLMATRIXMULT3X3FNVPROC glMatrixMult3x3fNV = 0;
PFNGLMATRIXMULTTRANSPOSE3X3FNVPROC glMatrixMultTranspose3x3fNV = 0;
PFNGLMATRIXMULTTRANSPOSEDEXTPROC glMatrixMultTransposedEXT = 0;
PFNGLMATRIXMULTTRANSPOSEFEXTPROC glMatrixMultTransposefEXT = 0;
PFNGLMATRIXMULTDEXTPROC glMatrixMultdEXT = 0;
PFNGLMATRIXMULTFEXTPROC glMatrixMultfEXT = 0;
PFNGLMATRIXORTHOEXTPROC glMatrixOrthoEXT = 0;
PFNGLMATRIXPOPEXTPROC glMatrixPopEXT = 0;
PFNGLMATRIXPUSHEXTPROC glMatrixPushEXT = 0;
PFNGLMATRIXROTATEDEXTPROC glMatrixRotatedEXT = 0;
PFNGLMATRIXROTATEFEXTPROC glMatrixRotatefEXT = 0;
PFNGLMATRIXSCALEDEXTPROC glMatrixScaledEXT = 0;
PFNGLMATRIXSCALEFEXTPROC glMatrixScalefEXT = 0;
PFNGLMATRIXTRANSLATEDEXTPROC glMatrixTranslatedEXT = 0;
PFNGLMATRIXTRANSLATEFEXTPROC glMatrixTranslatefEXT = 0;
PFNGLMAXACTIVESHADERCORESARMPROC glMaxActiveShaderCoresARM = 0;
PFNGLMAXSHADERCOMPILERTHREADSKHRPROC glMaxShaderCompilerThreadsKHR = 0;
PFNGLMAXSHADERCOMPILERTHREADSARBPROC glMaxShaderCompilerThreadsARB = 0;
PFNGLMEMORYBARRIERPROC glMemoryBarrier = 0;
PFNGLMEMORYBARRIERBYREGIONPROC glMemoryBarrierByRegion = 0;
PFNGLMEMORYBARRIEREXTPROC glMemoryBarrierEXT = 0;
PFNGLMEMORYOBJECTPARAMETERIVEXTPROC glMemoryObjectParameterivEXT = 0;
PFNGLMINSAMPLESHADINGPROC glMinSampleShading = 0;
PFNGLMINSAMPLESHADINGARBPROC glMinSampleShadingARB = 0;
PFNGLMINSAMPLESHADINGOESPROC glMinSampleShadingOES = 0;
PFNGLMINMAXPROC glMinmax = 0;
PFNGLMINMAXEXTPROC glMinmaxEXT = 0;
PFNGLMULTMATRIXDPROC glMultMatrixd = 0;
PFNGLMULTMATRIXFPROC glMultMatrixf = 0;
PFNGLMULTMATRIXXPROC glMultMatrixx = 0;
PFNGLMULTMATRIXXOESPROC glMultMatrixxOES = 0;
PFNGLMULTTRANSPOSEMATRIXDPROC glMultTransposeMatrixd = 0;
PFNGLMULTTRANSPOSEMATRIXDARBPROC glMultTransposeMatrixdARB = 0;
PFNGLMULTTRANSPOSEMATRIXFPROC glMultTransposeMatrixf = 0;
PFNGLMULTTRANSPOSEMATRIXFARBPROC glMultTransposeMatrixfARB = 0;
PFNGLMULTTRANSPOSEMATRIXXOESPROC glMultTransposeMatrixxOES = 0;
PFNGLMULTIDRAWARRAYSPROC glMultiDrawArrays = 0;
PFNGLMULTIDRAWARRAYSEXTPROC glMultiDrawArraysEXT = 0;
PFNGLMULTIDRAWARRAYSINDIRECTPROC glMultiDrawArraysIndirect = 0;
PFNGLMULTIDRAWARRAYSINDIRECTAMDPROC glMultiDrawArraysIndirectAMD = 0;
PFNGLMULTIDRAWARRAYSINDIRECTBINDLESSCOUNTNVPROC glMultiDrawArraysIndirectBindlessCountNV = 0;
PFNGLMULTIDRAWARRAYSINDIRECTBINDLESSNVPROC glMultiDrawArraysIndirectBindlessNV = 0;
PFNGLMULTIDRAWARRAYSINDIRECTCOUNTPROC glMultiDrawArraysIndirectCount = 0;
PFNGLMULTIDRAWARRAYSINDIRECTCOUNTARBPROC glMultiDrawArraysIndirectCountARB = 0;
PFNGLMULTIDRAWARRAYSINDIRECTEXTPROC glMultiDrawArraysIndirectEXT = 0;
PFNGLMULTIDRAWELEMENTARRAYAPPLEPROC glMultiDrawElementArrayAPPLE = 0;
PFNGLMULTIDRAWELEMENTSPROC glMultiDrawElements = 0;
PFNGLMULTIDRAWELEMENTSBASEVERTEXPROC glMultiDrawElementsBaseVertex = 0;
PFNGLMULTIDRAWELEMENTSBASEVERTEXEXTPROC glMultiDrawElementsBaseVertexEXT = 0;
PFNGLMULTIDRAWELEMENTSEXTPROC glMultiDrawElementsEXT = 0;
PFNGLMULTIDRAWELEMENTSINDIRECTPROC glMultiDrawElementsIndirect = 0;
PFNGLMULTIDRAWELEMENTSINDIRECTAMDPROC glMultiDrawElementsIndirectAMD = 0;
PFNGLMULTIDRAWELEMENTSINDIRECTBINDLESSCOUNTNVPROC glMultiDrawElementsIndirectBindlessCountNV = 0;
PFNGLMULTIDRAWELEMENTSINDIRECTBINDLESSNVPROC glMultiDrawElementsIndirectBindlessNV = 0;
PFNGLMULTIDRAWELEMENTSINDIRECTCOUNTPROC glMultiDrawElementsIndirectCount = 0;
PFNGLMULTIDRAWELEMENTSINDIRECTCOUNTARBPROC glMultiDrawElementsIndirectCountARB = 0;
PFNGLMULTIDRAWELEMENTSINDIRECTEXTPROC glMultiDrawElementsIndirectEXT = 0;
PFNGLMULTIDRAWMESHTASKSINDIRECTNVPROC glMultiDrawMeshTasksIndirectNV = 0;
PFNGLMULTIDRAWMESHTASKSINDIRECTCOUNTNVPROC glMultiDrawMeshTasksIndirectCountNV = 0;
PFNGLMULTIDRAWRANGEELEMENTARRAYAPPLEPROC glMultiDrawRangeElementArrayAPPLE = 0;
PFNGLMULTIMODEDRAWARRAYSIBMPROC glMultiModeDrawArraysIBM = 0;
PFNGLMULTIMODEDRAWELEMENTSIBMPROC glMultiModeDrawElementsIBM = 0;
PFNGLMULTITEXBUFFEREXTPROC glMultiTexBufferEXT = 0;
PFNGLMULTITEXCOORD1BOESPROC glMultiTexCoord1bOES = 0;
PFNGLMULTITEXCOORD1BVOESPROC glMultiTexCoord1bvOES = 0;
PFNGLMULTITEXCOORD1DPROC glMultiTexCoord1d = 0;
PFNGLMULTITEXCOORD1DARBPROC glMultiTexCoord1dARB = 0;
PFNGLMULTITEXCOORD1DVPROC glMultiTexCoord1dv = 0;
PFNGLMULTITEXCOORD1DVARBPROC glMultiTexCoord1dvARB = 0;
PFNGLMULTITEXCOORD1FPROC glMultiTexCoord1f = 0;
PFNGLMULTITEXCOORD1FARBPROC glMultiTexCoord1fARB = 0;
PFNGLMULTITEXCOORD1FVPROC glMultiTexCoord1fv = 0;
PFNGLMULTITEXCOORD1FVARBPROC glMultiTexCoord1fvARB = 0;
PFNGLMULTITEXCOORD1HNVPROC glMultiTexCoord1hNV = 0;
PFNGLMULTITEXCOORD1HVNVPROC glMultiTexCoord1hvNV = 0;
PFNGLMULTITEXCOORD1IPROC glMultiTexCoord1i = 0;
PFNGLMULTITEXCOORD1IARBPROC glMultiTexCoord1iARB = 0;
PFNGLMULTITEXCOORD1IVPROC glMultiTexCoord1iv = 0;
PFNGLMULTITEXCOORD1IVARBPROC glMultiTexCoord1ivARB = 0;
PFNGLMULTITEXCOORD1SPROC glMultiTexCoord1s = 0;
PFNGLMULTITEXCOORD1SARBPROC glMultiTexCoord1sARB = 0;
PFNGLMULTITEXCOORD1SVPROC glMultiTexCoord1sv = 0;
PFNGLMULTITEXCOORD1SVARBPROC glMultiTexCoord1svARB = 0;
PFNGLMULTITEXCOORD1XOESPROC glMultiTexCoord1xOES = 0;
PFNGLMULTITEXCOORD1XVOESPROC glMultiTexCoord1xvOES = 0;
PFNGLMULTITEXCOORD2BOESPROC glMultiTexCoord2bOES = 0;
PFNGLMULTITEXCOORD2BVOESPROC glMultiTexCoord2bvOES = 0;
PFNGLMULTITEXCOORD2DPROC glMultiTexCoord2d = 0;
PFNGLMULTITEXCOORD2DARBPROC glMultiTexCoord2dARB = 0;
PFNGLMULTITEXCOORD2DVPROC glMultiTexCoord2dv = 0;
PFNGLMULTITEXCOORD2DVARBPROC glMultiTexCoord2dvARB = 0;
PFNGLMULTITEXCOORD2FPROC glMultiTexCoord2f = 0;
PFNGLMULTITEXCOORD2FARBPROC glMultiTexCoord2fARB = 0;
PFNGLMULTITEXCOORD2FVPROC glMultiTexCoord2fv = 0;
PFNGLMULTITEXCOORD2FVARBPROC glMultiTexCoord2fvARB = 0;
PFNGLMULTITEXCOORD2HNVPROC glMultiTexCoord2hNV = 0;
PFNGLMULTITEXCOORD2HVNVPROC glMultiTexCoord2hvNV = 0;
PFNGLMULTITEXCOORD2IPROC glMultiTexCoord2i = 0;
PFNGLMULTITEXCOORD2IARBPROC glMultiTexCoord2iARB = 0;
PFNGLMULTITEXCOORD2IVPROC glMultiTexCoord2iv = 0;
PFNGLMULTITEXCOORD2IVARBPROC glMultiTexCoord2ivARB = 0;
PFNGLMULTITEXCOORD2SPROC glMultiTexCoord2s = 0;
PFNGLMULTITEXCOORD2SARBPROC glMultiTexCoord2sARB = 0;
PFNGLMULTITEXCOORD2SVPROC glMultiTexCoord2sv = 0;
PFNGLMULTITEXCOORD2SVARBPROC glMultiTexCoord2svARB = 0;
PFNGLMULTITEXCOORD2XOESPROC glMultiTexCoord2xOES = 0;
PFNGLMULTITEXCOORD2XVOESPROC glMultiTexCoord2xvOES = 0;
PFNGLMULTITEXCOORD3BOESPROC glMultiTexCoord3bOES = 0;
PFNGLMULTITEXCOORD3BVOESPROC glMultiTexCoord3bvOES = 0;
PFNGLMULTITEXCOORD3DPROC glMultiTexCoord3d = 0;
PFNGLMULTITEXCOORD3DARBPROC glMultiTexCoord3dARB = 0;
PFNGLMULTITEXCOORD3DVPROC glMultiTexCoord3dv = 0;
PFNGLMULTITEXCOORD3DVARBPROC glMultiTexCoord3dvARB = 0;
PFNGLMULTITEXCOORD3FPROC glMultiTexCoord3f = 0;
PFNGLMULTITEXCOORD3FARBPROC glMultiTexCoord3fARB = 0;
PFNGLMULTITEXCOORD3FVPROC glMultiTexCoord3fv = 0;
PFNGLMULTITEXCOORD3FVARBPROC glMultiTexCoord3fvARB = 0;
PFNGLMULTITEXCOORD3HNVPROC glMultiTexCoord3hNV = 0;
PFNGLMULTITEXCOORD3HVNVPROC glMultiTexCoord3hvNV = 0;
PFNGLMULTITEXCOORD3IPROC glMultiTexCoord3i = 0;
PFNGLMULTITEXCOORD3IARBPROC glMultiTexCoord3iARB = 0;
PFNGLMULTITEXCOORD3IVPROC glMultiTexCoord3iv = 0;
PFNGLMULTITEXCOORD3IVARBPROC glMultiTexCoord3ivARB = 0;
PFNGLMULTITEXCOORD3SPROC glMultiTexCoord3s = 0;
PFNGLMULTITEXCOORD3SARBPROC glMultiTexCoord3sARB = 0;
PFNGLMULTITEXCOORD3SVPROC glMultiTexCoord3sv = 0;
PFNGLMULTITEXCOORD3SVARBPROC glMultiTexCoord3svARB = 0;
PFNGLMULTITEXCOORD3XOESPROC glMultiTexCoord3xOES = 0;
PFNGLMULTITEXCOORD3XVOESPROC glMultiTexCoord3xvOES = 0;
PFNGLMULTITEXCOORD4BOESPROC glMultiTexCoord4bOES = 0;
PFNGLMULTITEXCOORD4BVOESPROC glMultiTexCoord4bvOES = 0;
PFNGLMULTITEXCOORD4DPROC glMultiTexCoord4d = 0;
PFNGLMULTITEXCOORD4DARBPROC glMultiTexCoord4dARB = 0;
PFNGLMULTITEXCOORD4DVPROC glMultiTexCoord4dv = 0;
PFNGLMULTITEXCOORD4DVARBPROC glMultiTexCoord4dvARB = 0;
PFNGLMULTITEXCOORD4FPROC glMultiTexCoord4f = 0;
PFNGLMULTITEXCOORD4FARBPROC glMultiTexCoord4fARB = 0;
PFNGLMULTITEXCOORD4FVPROC glMultiTexCoord4fv = 0;
PFNGLMULTITEXCOORD4FVARBPROC glMultiTexCoord4fvARB = 0;
PFNGLMULTITEXCOORD4HNVPROC glMultiTexCoord4hNV = 0;
PFNGLMULTITEXCOORD4HVNVPROC glMultiTexCoord4hvNV = 0;
PFNGLMULTITEXCOORD4IPROC glMultiTexCoord4i = 0;
PFNGLMULTITEXCOORD4IARBPROC glMultiTexCoord4iARB = 0;
PFNGLMULTITEXCOORD4IVPROC glMultiTexCoord4iv = 0;
PFNGLMULTITEXCOORD4IVARBPROC glMultiTexCoord4ivARB = 0;
PFNGLMULTITEXCOORD4SPROC glMultiTexCoord4s = 0;
PFNGLMULTITEXCOORD4SARBPROC glMultiTexCoord4sARB = 0;
PFNGLMULTITEXCOORD4SVPROC glMultiTexCoord4sv = 0;
PFNGLMULTITEXCOORD4SVARBPROC glMultiTexCoord4svARB = 0;
PFNGLMULTITEXCOORD4XPROC glMultiTexCoord4x = 0;
PFNGLMULTITEXCOORD4XOESPROC glMultiTexCoord4xOES = 0;
PFNGLMULTITEXCOORD4XVOESPROC glMultiTexCoord4xvOES = 0;
PFNGLMULTITEXCOORDP1UIPROC glMultiTexCoordP1ui = 0;
PFNGLMULTITEXCOORDP1UIVPROC glMultiTexCoordP1uiv = 0;
PFNGLMULTITEXCOORDP2UIPROC glMultiTexCoordP2ui = 0;
PFNGLMULTITEXCOORDP2UIVPROC glMultiTexCoordP2uiv = 0;
PFNGLMULTITEXCOORDP3UIPROC glMultiTexCoordP3ui = 0;
PFNGLMULTITEXCOORDP3UIVPROC glMultiTexCoordP3uiv = 0;
PFNGLMULTITEXCOORDP4UIPROC glMultiTexCoordP4ui = 0;
PFNGLMULTITEXCOORDP4UIVPROC glMultiTexCoordP4uiv = 0;
PFNGLMULTITEXCOORDPOINTEREXTPROC glMultiTexCoordPointerEXT = 0;
PFNGLMULTITEXENVFEXTPROC glMultiTexEnvfEXT = 0;
PFNGLMULTITEXENVFVEXTPROC glMultiTexEnvfvEXT = 0;
PFNGLMULTITEXENVIEXTPROC glMultiTexEnviEXT = 0;
PFNGLMULTITEXENVIVEXTPROC glMultiTexEnvivEXT = 0;
PFNGLMULTITEXGENDEXTPROC glMultiTexGendEXT = 0;
PFNGLMULTITEXGENDVEXTPROC glMultiTexGendvEXT = 0;
PFNGLMULTITEXGENFEXTPROC glMultiTexGenfEXT = 0;
PFNGLMULTITEXGENFVEXTPROC glMultiTexGenfvEXT = 0;
PFNGLMULTITEXGENIEXTPROC glMultiTexGeniEXT = 0;
PFNGLMULTITEXGENIVEXTPROC glMultiTexGenivEXT = 0;
PFNGLMULTITEXIMAGE1DEXTPROC glMultiTexImage1DEXT = 0;
PFNGLMULTITEXIMAGE2DEXTPROC glMultiTexImage2DEXT = 0;
PFNGLMULTITEXIMAGE3DEXTPROC glMultiTexImage3DEXT = 0;
PFNGLMULTITEXPARAMETERIIVEXTPROC glMultiTexParameterIivEXT = 0;
PFNGLMULTITEXPARAMETERIUIVEXTPROC glMultiTexParameterIuivEXT = 0;
PFNGLMULTITEXPARAMETERFEXTPROC glMultiTexParameterfEXT = 0;
PFNGLMULTITEXPARAMETERFVEXTPROC glMultiTexParameterfvEXT = 0;
PFNGLMULTITEXPARAMETERIEXTPROC glMultiTexParameteriEXT = 0;
PFNGLMULTITEXPARAMETERIVEXTPROC glMultiTexParameterivEXT = 0;
PFNGLMULTITEXRENDERBUFFEREXTPROC glMultiTexRenderbufferEXT = 0;
PFNGLMULTITEXSUBIMAGE1DEXTPROC glMultiTexSubImage1DEXT = 0;
PFNGLMULTITEXSUBIMAGE2DEXTPROC glMultiTexSubImage2DEXT = 0;
PFNGLMULTITEXSUBIMAGE3DEXTPROC glMultiTexSubImage3DEXT = 0;
PFNGLMULTICASTBARRIERNVPROC glMulticastBarrierNV = 0;
PFNGLMULTICASTBLITFRAMEBUFFERNVPROC glMulticastBlitFramebufferNV = 0;
PFNGLMULTICASTBUFFERSUBDATANVPROC glMulticastBufferSubDataNV = 0;
PFNGLMULTICASTCOPYBUFFERSUBDATANVPROC glMulticastCopyBufferSubDataNV = 0;
PFNGLMULTICASTCOPYIMAGESUBDATANVPROC glMulticastCopyImageSubDataNV = 0;
PFNGLMULTICASTFRAMEBUFFERSAMPLELOCATIONSFVNVPROC glMulticastFramebufferSampleLocationsfvNV = 0;
PFNGLMULTICASTGETQUERYOBJECTI64VNVPROC glMulticastGetQueryObjecti64vNV = 0;
PFNGLMULTICASTGETQUERYOBJECTIVNVPROC glMulticastGetQueryObjectivNV = 0;
PFNGLMULTICASTGETQUERYOBJECTUI64VNVPROC glMulticastGetQueryObjectui64vNV = 0;
PFNGLMULTICASTGETQUERYOBJECTUIVNVPROC glMulticastGetQueryObjectuivNV = 0;
PFNGLMULTICASTSCISSORARRAYVNVXPROC glMulticastScissorArrayvNVX = 0;
PFNGLMULTICASTVIEWPORTARRAYVNVXPROC glMulticastViewportArrayvNVX = 0;
PFNGLMULTICASTVIEWPORTPOSITIONWSCALENVXPROC glMulticastViewportPositionWScaleNVX = 0;
PFNGLMULTICASTWAITSYNCNVPROC glMulticastWaitSyncNV = 0;
PFNGLNAMEDBUFFERATTACHMEMORYNVPROC glNamedBufferAttachMemoryNV = 0;
PFNGLNAMEDBUFFERDATAPROC glNamedBufferData = 0;
PFNGLNAMEDBUFFERDATAEXTPROC glNamedBufferDataEXT = 0;
PFNGLNAMEDBUFFERPAGECOMMITMENTARBPROC glNamedBufferPageCommitmentARB = 0;
PFNGLNAMEDBUFFERPAGECOMMITMENTEXTPROC glNamedBufferPageCommitmentEXT = 0;
PFNGLNAMEDBUFFERPAGECOMMITMENTMEMNVPROC glNamedBufferPageCommitmentMemNV = 0;
PFNGLNAMEDBUFFERSTORAGEPROC glNamedBufferStorage = 0;
PFNGLNAMEDBUFFERSTORAGEEXTERNALEXTPROC glNamedBufferStorageExternalEXT = 0;
PFNGLNAMEDBUFFERSTORAGEEXTPROC glNamedBufferStorageEXT = 0;
PFNGLNAMEDBUFFERSTORAGEMEMEXTPROC glNamedBufferStorageMemEXT = 0;
PFNGLNAMEDBUFFERSUBDATAPROC glNamedBufferSubData = 0;
PFNGLNAMEDBUFFERSUBDATAEXTPROC glNamedBufferSubDataEXT = 0;
PFNGLNAMEDCOPYBUFFERSUBDATAEXTPROC glNamedCopyBufferSubDataEXT = 0;
PFNGLNAMEDFRAMEBUFFERDRAWBUFFERPROC glNamedFramebufferDrawBuffer = 0;
PFNGLNAMEDFRAMEBUFFERDRAWBUFFERSPROC glNamedFramebufferDrawBuffers = 0;
PFNGLNAMEDFRAMEBUFFERPARAMETERIPROC glNamedFramebufferParameteri = 0;
PFNGLNAMEDFRAMEBUFFERPARAMETERIEXTPROC glNamedFramebufferParameteriEXT = 0;
PFNGLNAMEDFRAMEBUFFERREADBUFFERPROC glNamedFramebufferReadBuffer = 0;
PFNGLNAMEDFRAMEBUFFERRENDERBUFFERPROC glNamedFramebufferRenderbuffer = 0;
PFNGLNAMEDFRAMEBUFFERRENDERBUFFEREXTPROC glNamedFramebufferRenderbufferEXT = 0;
PFNGLNAMEDFRAMEBUFFERSAMPLELOCATIONSFVARBPROC glNamedFramebufferSampleLocationsfvARB = 0;
PFNGLNAMEDFRAMEBUFFERSAMPLELOCATIONSFVNVPROC glNamedFramebufferSampleLocationsfvNV = 0;
PFNGLNAMEDFRAMEBUFFERTEXTUREPROC glNamedFramebufferTexture = 0;
PFNGLNAMEDFRAMEBUFFERSAMPLEPOSITIONSFVAMDPROC glNamedFramebufferSamplePositionsfvAMD = 0;
PFNGLNAMEDFRAMEBUFFERTEXTURE1DEXTPROC glNamedFramebufferTexture1DEXT = 0;
PFNGLNAMEDFRAMEBUFFERTEXTURE2DEXTPROC glNamedFramebufferTexture2DEXT = 0;
PFNGLNAMEDFRAMEBUFFERTEXTURE3DEXTPROC glNamedFramebufferTexture3DEXT = 0;
PFNGLNAMEDFRAMEBUFFERTEXTUREEXTPROC glNamedFramebufferTextureEXT = 0;
PFNGLNAMEDFRAMEBUFFERTEXTUREFACEEXTPROC glNamedFramebufferTextureFaceEXT = 0;
PFNGLNAMEDFRAMEBUFFERTEXTURELAYERPROC glNamedFramebufferTextureLayer = 0;
PFNGLNAMEDFRAMEBUFFERTEXTURELAYEREXTPROC glNamedFramebufferTextureLayerEXT = 0;
PFNGLNAMEDFRAMEBUFFERTEXTUREMULTIVIEWOVRPROC glNamedFramebufferTextureMultiviewOVR = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETER4DEXTPROC glNamedProgramLocalParameter4dEXT = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETER4DVEXTPROC glNamedProgramLocalParameter4dvEXT = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETER4FEXTPROC glNamedProgramLocalParameter4fEXT = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETER4FVEXTPROC glNamedProgramLocalParameter4fvEXT = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETERI4IEXTPROC glNamedProgramLocalParameterI4iEXT = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETERI4IVEXTPROC glNamedProgramLocalParameterI4ivEXT = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETERI4UIEXTPROC glNamedProgramLocalParameterI4uiEXT = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETERI4UIVEXTPROC glNamedProgramLocalParameterI4uivEXT = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETERS4FVEXTPROC glNamedProgramLocalParameters4fvEXT = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETERSI4IVEXTPROC glNamedProgramLocalParametersI4ivEXT = 0;
PFNGLNAMEDPROGRAMLOCALPARAMETERSI4UIVEXTPROC glNamedProgramLocalParametersI4uivEXT = 0;
PFNGLNAMEDPROGRAMSTRINGEXTPROC glNamedProgramStringEXT = 0;
PFNGLNAMEDRENDERBUFFERSTORAGEPROC glNamedRenderbufferStorage = 0;
PFNGLNAMEDRENDERBUFFERSTORAGEEXTPROC glNamedRenderbufferStorageEXT = 0;
PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEPROC glNamedRenderbufferStorageMultisample = 0;
PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEADVANCEDAMDPROC glNamedRenderbufferStorageMultisampleAdvancedAMD = 0;
PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLECOVERAGEEXTPROC glNamedRenderbufferStorageMultisampleCoverageEXT = 0;
PFNGLNAMEDRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC glNamedRenderbufferStorageMultisampleEXT = 0;
PFNGLNAMEDSTRINGARBPROC glNamedStringARB = 0;
PFNGLNEWLISTPROC glNewList = 0;
PFNGLNEWOBJECTBUFFERATIPROC glNewObjectBufferATI = 0;
PFNGLNORMAL3BPROC glNormal3b = 0;
PFNGLNORMAL3BVPROC glNormal3bv = 0;
PFNGLNORMAL3DPROC glNormal3d = 0;
PFNGLNORMAL3DVPROC glNormal3dv = 0;
PFNGLNORMAL3FPROC glNormal3f = 0;
PFNGLNORMAL3FVERTEX3FSUNPROC glNormal3fVertex3fSUN = 0;
PFNGLNORMAL3FVERTEX3FVSUNPROC glNormal3fVertex3fvSUN = 0;
PFNGLNORMAL3FVPROC glNormal3fv = 0;
PFNGLNORMAL3HNVPROC glNormal3hNV = 0;
PFNGLNORMAL3HVNVPROC glNormal3hvNV = 0;
PFNGLNORMAL3IPROC glNormal3i = 0;
PFNGLNORMAL3IVPROC glNormal3iv = 0;
PFNGLNORMAL3SPROC glNormal3s = 0;
PFNGLNORMAL3SVPROC glNormal3sv = 0;
PFNGLNORMAL3XPROC glNormal3x = 0;
PFNGLNORMAL3XOESPROC glNormal3xOES = 0;
PFNGLNORMAL3XVOESPROC glNormal3xvOES = 0;
PFNGLNORMALFORMATNVPROC glNormalFormatNV = 0;
PFNGLNORMALP3UIPROC glNormalP3ui = 0;
PFNGLNORMALP3UIVPROC glNormalP3uiv = 0;
PFNGLNORMALPOINTERPROC glNormalPointer = 0;
PFNGLNORMALPOINTEREXTPROC glNormalPointerEXT = 0;
PFNGLNORMALPOINTERLISTIBMPROC glNormalPointerListIBM = 0;
PFNGLNORMALPOINTERVINTELPROC glNormalPointervINTEL = 0;
PFNGLNORMALSTREAM3BATIPROC glNormalStream3bATI = 0;
PFNGLNORMALSTREAM3BVATIPROC glNormalStream3bvATI = 0;
PFNGLNORMALSTREAM3DATIPROC glNormalStream3dATI = 0;
PFNGLNORMALSTREAM3DVATIPROC glNormalStream3dvATI = 0;
PFNGLNORMALSTREAM3FATIPROC glNormalStream3fATI = 0;
PFNGLNORMALSTREAM3FVATIPROC glNormalStream3fvATI = 0;
PFNGLNORMALSTREAM3IATIPROC glNormalStream3iATI = 0;
PFNGLNORMALSTREAM3IVATIPROC glNormalStream3ivATI = 0;
PFNGLNORMALSTREAM3SATIPROC glNormalStream3sATI = 0;
PFNGLNORMALSTREAM3SVATIPROC glNormalStream3svATI = 0;
PFNGLOBJECTLABELPROC glObjectLabel = 0;
PFNGLOBJECTLABELKHRPROC glObjectLabelKHR = 0;
PFNGLOBJECTPTRLABELPROC glObjectPtrLabel = 0;
PFNGLOBJECTPTRLABELKHRPROC glObjectPtrLabelKHR = 0;
PFNGLOBJECTPURGEABLEAPPLEPROC glObjectPurgeableAPPLE = 0;
PFNGLOBJECTUNPURGEABLEAPPLEPROC glObjectUnpurgeableAPPLE = 0;
PFNGLORTHOPROC glOrtho = 0;
PFNGLORTHOFPROC glOrthof = 0;
PFNGLORTHOFOESPROC glOrthofOES = 0;
PFNGLORTHOXPROC glOrthox = 0;
PFNGLORTHOXOESPROC glOrthoxOES = 0;
PFNGLPNTRIANGLESFATIPROC glPNTrianglesfATI = 0;
PFNGLPNTRIANGLESIATIPROC glPNTrianglesiATI = 0;
PFNGLPASSTEXCOORDATIPROC glPassTexCoordATI = 0;
PFNGLPASSTHROUGHPROC glPassThrough = 0;
PFNGLPASSTHROUGHXOESPROC glPassThroughxOES = 0;
PFNGLPATCHPARAMETERFVPROC glPatchParameterfv = 0;
PFNGLPATCHPARAMETERIPROC glPatchParameteri = 0;
PFNGLPATCHPARAMETERIEXTPROC glPatchParameteriEXT = 0;
PFNGLPATCHPARAMETERIOESPROC glPatchParameteriOES = 0;
PFNGLPATHCOLORGENNVPROC glPathColorGenNV = 0;
PFNGLPATHCOMMANDSNVPROC glPathCommandsNV = 0;
PFNGLPATHCOORDSNVPROC glPathCoordsNV = 0;
PFNGLPATHCOVERDEPTHFUNCNVPROC glPathCoverDepthFuncNV = 0;
PFNGLPATHDASHARRAYNVPROC glPathDashArrayNV = 0;
PFNGLPATHFOGGENNVPROC glPathFogGenNV = 0;
PFNGLPATHGLYPHINDEXARRAYNVPROC glPathGlyphIndexArrayNV = 0;
PFNGLPATHGLYPHINDEXRANGENVPROC glPathGlyphIndexRangeNV = 0;
PFNGLPATHGLYPHRANGENVPROC glPathGlyphRangeNV = 0;
PFNGLPATHGLYPHSNVPROC glPathGlyphsNV = 0;
PFNGLPATHMEMORYGLYPHINDEXARRAYNVPROC glPathMemoryGlyphIndexArrayNV = 0;
PFNGLPATHPARAMETERFNVPROC glPathParameterfNV = 0;
PFNGLPATHPARAMETERFVNVPROC glPathParameterfvNV = 0;
PFNGLPATHPARAMETERINVPROC glPathParameteriNV = 0;
PFNGLPATHPARAMETERIVNVPROC glPathParameterivNV = 0;
PFNGLPATHSTENCILDEPTHOFFSETNVPROC glPathStencilDepthOffsetNV = 0;
PFNGLPATHSTENCILFUNCNVPROC glPathStencilFuncNV = 0;
PFNGLPATHSTRINGNVPROC glPathStringNV = 0;
PFNGLPATHSUBCOMMANDSNVPROC glPathSubCommandsNV = 0;
PFNGLPATHSUBCOORDSNVPROC glPathSubCoordsNV = 0;
PFNGLPATHTEXGENNVPROC glPathTexGenNV = 0;
PFNGLPAUSETRANSFORMFEEDBACKPROC glPauseTransformFeedback = 0;
PFNGLPAUSETRANSFORMFEEDBACKNVPROC glPauseTransformFeedbackNV = 0;
PFNGLPIXELDATARANGENVPROC glPixelDataRangeNV = 0;
PFNGLPIXELMAPFVPROC glPixelMapfv = 0;
PFNGLPIXELMAPUIVPROC glPixelMapuiv = 0;
PFNGLPIXELMAPUSVPROC glPixelMapusv = 0;
PFNGLPIXELMAPXPROC glPixelMapx = 0;
PFNGLPIXELSTOREFPROC glPixelStoref = 0;
PFNGLPIXELSTOREIPROC glPixelStorei = 0;
PFNGLPIXELSTOREXPROC glPixelStorex = 0;
PFNGLPIXELTEXGENPARAMETERFSGISPROC glPixelTexGenParameterfSGIS = 0;
PFNGLPIXELTEXGENPARAMETERFVSGISPROC glPixelTexGenParameterfvSGIS = 0;
PFNGLPIXELTEXGENPARAMETERISGISPROC glPixelTexGenParameteriSGIS = 0;
PFNGLPIXELTEXGENPARAMETERIVSGISPROC glPixelTexGenParameterivSGIS = 0;
PFNGLPIXELTEXGENSGIXPROC glPixelTexGenSGIX = 0;
PFNGLPIXELTRANSFERFPROC glPixelTransferf = 0;
PFNGLPIXELTRANSFERIPROC glPixelTransferi = 0;
PFNGLPIXELTRANSFERXOESPROC glPixelTransferxOES = 0;
PFNGLPIXELTRANSFORMPARAMETERFEXTPROC glPixelTransformParameterfEXT = 0;
PFNGLPIXELTRANSFORMPARAMETERFVEXTPROC glPixelTransformParameterfvEXT = 0;
PFNGLPIXELTRANSFORMPARAMETERIEXTPROC glPixelTransformParameteriEXT = 0;
PFNGLPIXELTRANSFORMPARAMETERIVEXTPROC glPixelTransformParameterivEXT = 0;
PFNGLPIXELZOOMPROC glPixelZoom = 0;
PFNGLPIXELZOOMXOESPROC glPixelZoomxOES = 0;
PFNGLPOINTALONGPATHNVPROC glPointAlongPathNV = 0;
PFNGLPOINTPARAMETERFPROC glPointParameterf = 0;
PFNGLPOINTPARAMETERFARBPROC glPointParameterfARB = 0;
PFNGLPOINTPARAMETERFEXTPROC glPointParameterfEXT = 0;
PFNGLPOINTPARAMETERFSGISPROC glPointParameterfSGIS = 0;
PFNGLPOINTPARAMETERFVPROC glPointParameterfv = 0;
PFNGLPOINTPARAMETERFVARBPROC glPointParameterfvARB = 0;
PFNGLPOINTPARAMETERFVEXTPROC glPointParameterfvEXT = 0;
PFNGLPOINTPARAMETERFVSGISPROC glPointParameterfvSGIS = 0;
PFNGLPOINTPARAMETERIPROC glPointParameteri = 0;
PFNGLPOINTPARAMETERINVPROC glPointParameteriNV = 0;
PFNGLPOINTPARAMETERIVPROC glPointParameteriv = 0;
PFNGLPOINTPARAMETERIVNVPROC glPointParameterivNV = 0;
PFNGLPOINTPARAMETERXPROC glPointParameterx = 0;
PFNGLPOINTPARAMETERXOESPROC glPointParameterxOES = 0;
PFNGLPOINTPARAMETERXVPROC glPointParameterxv = 0;
PFNGLPOINTPARAMETERXVOESPROC glPointParameterxvOES = 0;
PFNGLPOINTSIZEPROC glPointSize = 0;
PFNGLPOINTSIZEPOINTEROESPROC glPointSizePointerOES = 0;
PFNGLPOINTSIZEXPROC glPointSizex = 0;
PFNGLPOINTSIZEXOESPROC glPointSizexOES = 0;
PFNGLPOLLASYNCSGIXPROC glPollAsyncSGIX = 0;
PFNGLPOLLINSTRUMENTSSGIXPROC glPollInstrumentsSGIX = 0;
PFNGLPOLYGONMODEPROC glPolygonMode = 0;
PFNGLPOLYGONMODENVPROC glPolygonModeNV = 0;
PFNGLPOLYGONOFFSETPROC glPolygonOffset = 0;
PFNGLPOLYGONOFFSETCLAMPPROC glPolygonOffsetClamp = 0;
PFNGLPOLYGONOFFSETCLAMPEXTPROC glPolygonOffsetClampEXT = 0;
PFNGLPOLYGONOFFSETEXTPROC glPolygonOffsetEXT = 0;
PFNGLPOLYGONOFFSETXPROC glPolygonOffsetx = 0;
PFNGLPOLYGONOFFSETXOESPROC glPolygonOffsetxOES = 0;
PFNGLPOLYGONSTIPPLEPROC glPolygonStipple = 0;
PFNGLPOPATTRIBPROC glPopAttrib = 0;
PFNGLPOPCLIENTATTRIBPROC glPopClientAttrib = 0;
PFNGLPOPDEBUGGROUPPROC glPopDebugGroup = 0;
PFNGLPOPDEBUGGROUPKHRPROC glPopDebugGroupKHR = 0;
PFNGLPOPGROUPMARKEREXTPROC glPopGroupMarkerEXT = 0;
PFNGLPOPMATRIXPROC glPopMatrix = 0;
PFNGLPOPNAMEPROC glPopName = 0;
PFNGLPRESENTFRAMEDUALFILLNVPROC glPresentFrameDualFillNV = 0;
PFNGLPRESENTFRAMEKEYEDNVPROC glPresentFrameKeyedNV = 0;
PFNGLPRIMITIVEBOUNDINGBOXPROC glPrimitiveBoundingBox = 0;
PFNGLPRIMITIVEBOUNDINGBOXARBPROC glPrimitiveBoundingBoxARB = 0;
PFNGLPRIMITIVEBOUNDINGBOXEXTPROC glPrimitiveBoundingBoxEXT = 0;
PFNGLPRIMITIVEBOUNDINGBOXOESPROC glPrimitiveBoundingBoxOES = 0;
PFNGLPRIMITIVERESTARTINDEXPROC glPrimitiveRestartIndex = 0;
PFNGLPRIMITIVERESTARTINDEXNVPROC glPrimitiveRestartIndexNV = 0;
PFNGLPRIMITIVERESTARTNVPROC glPrimitiveRestartNV = 0;
PFNGLPRIORITIZETEXTURESPROC glPrioritizeTextures = 0;
PFNGLPRIORITIZETEXTURESEXTPROC glPrioritizeTexturesEXT = 0;
PFNGLPRIORITIZETEXTURESXOESPROC glPrioritizeTexturesxOES = 0;
PFNGLPROGRAMBINARYPROC glProgramBinary = 0;
PFNGLPROGRAMBINARYOESPROC glProgramBinaryOES = 0;
PFNGLPROGRAMBUFFERPARAMETERSIIVNVPROC glProgramBufferParametersIivNV = 0;
PFNGLPROGRAMBUFFERPARAMETERSIUIVNVPROC glProgramBufferParametersIuivNV = 0;
PFNGLPROGRAMBUFFERPARAMETERSFVNVPROC glProgramBufferParametersfvNV = 0;
PFNGLPROGRAMENVPARAMETER4DARBPROC glProgramEnvParameter4dARB = 0;
PFNGLPROGRAMENVPARAMETER4DVARBPROC glProgramEnvParameter4dvARB = 0;
PFNGLPROGRAMENVPARAMETER4FARBPROC glProgramEnvParameter4fARB = 0;
PFNGLPROGRAMENVPARAMETER4FVARBPROC glProgramEnvParameter4fvARB = 0;
PFNGLPROGRAMENVPARAMETERI4INVPROC glProgramEnvParameterI4iNV = 0;
PFNGLPROGRAMENVPARAMETERI4IVNVPROC glProgramEnvParameterI4ivNV = 0;
PFNGLPROGRAMENVPARAMETERI4UINVPROC glProgramEnvParameterI4uiNV = 0;
PFNGLPROGRAMENVPARAMETERI4UIVNVPROC glProgramEnvParameterI4uivNV = 0;
PFNGLPROGRAMENVPARAMETERS4FVEXTPROC glProgramEnvParameters4fvEXT = 0;
PFNGLPROGRAMENVPARAMETERSI4IVNVPROC glProgramEnvParametersI4ivNV = 0;
PFNGLPROGRAMENVPARAMETERSI4UIVNVPROC glProgramEnvParametersI4uivNV = 0;
PFNGLPROGRAMLOCALPARAMETER4DARBPROC glProgramLocalParameter4dARB = 0;
PFNGLPROGRAMLOCALPARAMETER4DVARBPROC glProgramLocalParameter4dvARB = 0;
PFNGLPROGRAMLOCALPARAMETER4FARBPROC glProgramLocalParameter4fARB = 0;
PFNGLPROGRAMLOCALPARAMETER4FVARBPROC glProgramLocalParameter4fvARB = 0;
PFNGLPROGRAMLOCALPARAMETERI4INVPROC glProgramLocalParameterI4iNV = 0;
PFNGLPROGRAMLOCALPARAMETERI4IVNVPROC glProgramLocalParameterI4ivNV = 0;
PFNGLPROGRAMLOCALPARAMETERI4UINVPROC glProgramLocalParameterI4uiNV = 0;
PFNGLPROGRAMLOCALPARAMETERI4UIVNVPROC glProgramLocalParameterI4uivNV = 0;
PFNGLPROGRAMLOCALPARAMETERS4FVEXTPROC glProgramLocalParameters4fvEXT = 0;
PFNGLPROGRAMLOCALPARAMETERSI4IVNVPROC glProgramLocalParametersI4ivNV = 0;
PFNGLPROGRAMLOCALPARAMETERSI4UIVNVPROC glProgramLocalParametersI4uivNV = 0;
PFNGLPROGRAMNAMEDPARAMETER4DNVPROC glProgramNamedParameter4dNV = 0;
PFNGLPROGRAMNAMEDPARAMETER4DVNVPROC glProgramNamedParameter4dvNV = 0;
PFNGLPROGRAMNAMEDPARAMETER4FNVPROC glProgramNamedParameter4fNV = 0;
PFNGLPROGRAMNAMEDPARAMETER4FVNVPROC glProgramNamedParameter4fvNV = 0;
PFNGLPROGRAMPARAMETER4DNVPROC glProgramParameter4dNV = 0;
PFNGLPROGRAMPARAMETER4DVNVPROC glProgramParameter4dvNV = 0;
PFNGLPROGRAMPARAMETER4FNVPROC glProgramParameter4fNV = 0;
PFNGLPROGRAMPARAMETER4FVNVPROC glProgramParameter4fvNV = 0;
PFNGLPROGRAMPARAMETERIPROC glProgramParameteri = 0;
PFNGLPROGRAMPARAMETERIARBPROC glProgramParameteriARB = 0;
PFNGLPROGRAMPARAMETERIEXTPROC glProgramParameteriEXT = 0;
PFNGLPROGRAMPARAMETERS4DVNVPROC glProgramParameters4dvNV = 0;
PFNGLPROGRAMPARAMETERS4FVNVPROC glProgramParameters4fvNV = 0;
PFNGLPROGRAMPATHFRAGMENTINPUTGENNVPROC glProgramPathFragmentInputGenNV = 0;
PFNGLPROGRAMSTRINGARBPROC glProgramStringARB = 0;
PFNGLPROGRAMSUBROUTINEPARAMETERSUIVNVPROC glProgramSubroutineParametersuivNV = 0;
PFNGLPROGRAMUNIFORM1DPROC glProgramUniform1d = 0;
PFNGLPROGRAMUNIFORM1DEXTPROC glProgramUniform1dEXT = 0;
PFNGLPROGRAMUNIFORM1DVPROC glProgramUniform1dv = 0;
PFNGLPROGRAMUNIFORM1DVEXTPROC glProgramUniform1dvEXT = 0;
PFNGLPROGRAMUNIFORM1FPROC glProgramUniform1f = 0;
PFNGLPROGRAMUNIFORM1FEXTPROC glProgramUniform1fEXT = 0;
PFNGLPROGRAMUNIFORM1FVPROC glProgramUniform1fv = 0;
PFNGLPROGRAMUNIFORM1FVEXTPROC glProgramUniform1fvEXT = 0;
PFNGLPROGRAMUNIFORM1IPROC glProgramUniform1i = 0;
PFNGLPROGRAMUNIFORM1I64ARBPROC glProgramUniform1i64ARB = 0;
PFNGLPROGRAMUNIFORM1I64NVPROC glProgramUniform1i64NV = 0;
PFNGLPROGRAMUNIFORM1I64VARBPROC glProgramUniform1i64vARB = 0;
PFNGLPROGRAMUNIFORM1I64VNVPROC glProgramUniform1i64vNV = 0;
PFNGLPROGRAMUNIFORM1IEXTPROC glProgramUniform1iEXT = 0;
PFNGLPROGRAMUNIFORM1IVPROC glProgramUniform1iv = 0;
PFNGLPROGRAMUNIFORM1IVEXTPROC glProgramUniform1ivEXT = 0;
PFNGLPROGRAMUNIFORM1UIPROC glProgramUniform1ui = 0;
PFNGLPROGRAMUNIFORM1UI64ARBPROC glProgramUniform1ui64ARB = 0;
PFNGLPROGRAMUNIFORM1UI64NVPROC glProgramUniform1ui64NV = 0;
PFNGLPROGRAMUNIFORM1UI64VARBPROC glProgramUniform1ui64vARB = 0;
PFNGLPROGRAMUNIFORM1UI64VNVPROC glProgramUniform1ui64vNV = 0;
PFNGLPROGRAMUNIFORM1UIEXTPROC glProgramUniform1uiEXT = 0;
PFNGLPROGRAMUNIFORM1UIVPROC glProgramUniform1uiv = 0;
PFNGLPROGRAMUNIFORM1UIVEXTPROC glProgramUniform1uivEXT = 0;
PFNGLPROGRAMUNIFORM2DPROC glProgramUniform2d = 0;
PFNGLPROGRAMUNIFORM2DEXTPROC glProgramUniform2dEXT = 0;
PFNGLPROGRAMUNIFORM2DVPROC glProgramUniform2dv = 0;
PFNGLPROGRAMUNIFORM2DVEXTPROC glProgramUniform2dvEXT = 0;
PFNGLPROGRAMUNIFORM2FPROC glProgramUniform2f = 0;
PFNGLPROGRAMUNIFORM2FEXTPROC glProgramUniform2fEXT = 0;
PFNGLPROGRAMUNIFORM2FVPROC glProgramUniform2fv = 0;
PFNGLPROGRAMUNIFORM2FVEXTPROC glProgramUniform2fvEXT = 0;
PFNGLPROGRAMUNIFORM2IPROC glProgramUniform2i = 0;
PFNGLPROGRAMUNIFORM2I64ARBPROC glProgramUniform2i64ARB = 0;
PFNGLPROGRAMUNIFORM2I64NVPROC glProgramUniform2i64NV = 0;
PFNGLPROGRAMUNIFORM2I64VARBPROC glProgramUniform2i64vARB = 0;
PFNGLPROGRAMUNIFORM2I64VNVPROC glProgramUniform2i64vNV = 0;
PFNGLPROGRAMUNIFORM2IEXTPROC glProgramUniform2iEXT = 0;
PFNGLPROGRAMUNIFORM2IVPROC glProgramUniform2iv = 0;
PFNGLPROGRAMUNIFORM2IVEXTPROC glProgramUniform2ivEXT = 0;
PFNGLPROGRAMUNIFORM2UIPROC glProgramUniform2ui = 0;
PFNGLPROGRAMUNIFORM2UI64ARBPROC glProgramUniform2ui64ARB = 0;
PFNGLPROGRAMUNIFORM2UI64NVPROC glProgramUniform2ui64NV = 0;
PFNGLPROGRAMUNIFORM2UI64VARBPROC glProgramUniform2ui64vARB = 0;
PFNGLPROGRAMUNIFORM2UI64VNVPROC glProgramUniform2ui64vNV = 0;
PFNGLPROGRAMUNIFORM2UIEXTPROC glProgramUniform2uiEXT = 0;
PFNGLPROGRAMUNIFORM2UIVPROC glProgramUniform2uiv = 0;
PFNGLPROGRAMUNIFORM2UIVEXTPROC glProgramUniform2uivEXT = 0;
PFNGLPROGRAMUNIFORM3DPROC glProgramUniform3d = 0;
PFNGLPROGRAMUNIFORM3DEXTPROC glProgramUniform3dEXT = 0;
PFNGLPROGRAMUNIFORM3DVPROC glProgramUniform3dv = 0;
PFNGLPROGRAMUNIFORM3DVEXTPROC glProgramUniform3dvEXT = 0;
PFNGLPROGRAMUNIFORM3FPROC glProgramUniform3f = 0;
PFNGLPROGRAMUNIFORM3FEXTPROC glProgramUniform3fEXT = 0;
PFNGLPROGRAMUNIFORM3FVPROC glProgramUniform3fv = 0;
PFNGLPROGRAMUNIFORM3FVEXTPROC glProgramUniform3fvEXT = 0;
PFNGLPROGRAMUNIFORM3IPROC glProgramUniform3i = 0;
PFNGLPROGRAMUNIFORM3I64ARBPROC glProgramUniform3i64ARB = 0;
PFNGLPROGRAMUNIFORM3I64NVPROC glProgramUniform3i64NV = 0;
PFNGLPROGRAMUNIFORM3I64VARBPROC glProgramUniform3i64vARB = 0;
PFNGLPROGRAMUNIFORM3I64VNVPROC glProgramUniform3i64vNV = 0;
PFNGLPROGRAMUNIFORM3IEXTPROC glProgramUniform3iEXT = 0;
PFNGLPROGRAMUNIFORM3IVPROC glProgramUniform3iv = 0;
PFNGLPROGRAMUNIFORM3IVEXTPROC glProgramUniform3ivEXT = 0;
PFNGLPROGRAMUNIFORM3UIPROC glProgramUniform3ui = 0;
PFNGLPROGRAMUNIFORM3UI64ARBPROC glProgramUniform3ui64ARB = 0;
PFNGLPROGRAMUNIFORM3UI64NVPROC glProgramUniform3ui64NV = 0;
PFNGLPROGRAMUNIFORM3UI64VARBPROC glProgramUniform3ui64vARB = 0;
PFNGLPROGRAMUNIFORM3UI64VNVPROC glProgramUniform3ui64vNV = 0;
PFNGLPROGRAMUNIFORM3UIEXTPROC glProgramUniform3uiEXT = 0;
PFNGLPROGRAMUNIFORM3UIVPROC glProgramUniform3uiv = 0;
PFNGLPROGRAMUNIFORM3UIVEXTPROC glProgramUniform3uivEXT = 0;
PFNGLPROGRAMUNIFORM4DPROC glProgramUniform4d = 0;
PFNGLPROGRAMUNIFORM4DEXTPROC glProgramUniform4dEXT = 0;
PFNGLPROGRAMUNIFORM4DVPROC glProgramUniform4dv = 0;
PFNGLPROGRAMUNIFORM4DVEXTPROC glProgramUniform4dvEXT = 0;
PFNGLPROGRAMUNIFORM4FPROC glProgramUniform4f = 0;
PFNGLPROGRAMUNIFORM4FEXTPROC glProgramUniform4fEXT = 0;
PFNGLPROGRAMUNIFORM4FVPROC glProgramUniform4fv = 0;
PFNGLPROGRAMUNIFORM4FVEXTPROC glProgramUniform4fvEXT = 0;
PFNGLPROGRAMUNIFORM4IPROC glProgramUniform4i = 0;
PFNGLPROGRAMUNIFORM4I64ARBPROC glProgramUniform4i64ARB = 0;
PFNGLPROGRAMUNIFORM4I64NVPROC glProgramUniform4i64NV = 0;
PFNGLPROGRAMUNIFORM4I64VARBPROC glProgramUniform4i64vARB = 0;
PFNGLPROGRAMUNIFORM4I64VNVPROC glProgramUniform4i64vNV = 0;
PFNGLPROGRAMUNIFORM4IEXTPROC glProgramUniform4iEXT = 0;
PFNGLPROGRAMUNIFORM4IVPROC glProgramUniform4iv = 0;
PFNGLPROGRAMUNIFORM4IVEXTPROC glProgramUniform4ivEXT = 0;
PFNGLPROGRAMUNIFORM4UIPROC glProgramUniform4ui = 0;
PFNGLPROGRAMUNIFORM4UI64ARBPROC glProgramUniform4ui64ARB = 0;
PFNGLPROGRAMUNIFORM4UI64NVPROC glProgramUniform4ui64NV = 0;
PFNGLPROGRAMUNIFORM4UI64VARBPROC glProgramUniform4ui64vARB = 0;
PFNGLPROGRAMUNIFORM4UI64VNVPROC glProgramUniform4ui64vNV = 0;
PFNGLPROGRAMUNIFORM4UIEXTPROC glProgramUniform4uiEXT = 0;
PFNGLPROGRAMUNIFORM4UIVPROC glProgramUniform4uiv = 0;
PFNGLPROGRAMUNIFORM4UIVEXTPROC glProgramUniform4uivEXT = 0;
PFNGLPROGRAMUNIFORMHANDLEUI64ARBPROC glProgramUniformHandleui64ARB = 0;
PFNGLPROGRAMUNIFORMHANDLEUI64IMGPROC glProgramUniformHandleui64IMG = 0;
PFNGLPROGRAMUNIFORMHANDLEUI64NVPROC glProgramUniformHandleui64NV = 0;
PFNGLPROGRAMUNIFORMHANDLEUI64VARBPROC glProgramUniformHandleui64vARB = 0;
PFNGLPROGRAMUNIFORMHANDLEUI64VIMGPROC glProgramUniformHandleui64vIMG = 0;
PFNGLPROGRAMUNIFORMHANDLEUI64VNVPROC glProgramUniformHandleui64vNV = 0;
PFNGLPROGRAMUNIFORMMATRIX2DVPROC glProgramUniformMatrix2dv = 0;
PFNGLPROGRAMUNIFORMMATRIX2DVEXTPROC glProgramUniformMatrix2dvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX2FVPROC glProgramUniformMatrix2fv = 0;
PFNGLPROGRAMUNIFORMMATRIX2FVEXTPROC glProgramUniformMatrix2fvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX2X3DVPROC glProgramUniformMatrix2x3dv = 0;
PFNGLPROGRAMUNIFORMMATRIX2X3DVEXTPROC glProgramUniformMatrix2x3dvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX2X3FVPROC glProgramUniformMatrix2x3fv = 0;
PFNGLPROGRAMUNIFORMMATRIX2X3FVEXTPROC glProgramUniformMatrix2x3fvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX2X4DVPROC glProgramUniformMatrix2x4dv = 0;
PFNGLPROGRAMUNIFORMMATRIX2X4DVEXTPROC glProgramUniformMatrix2x4dvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX2X4FVPROC glProgramUniformMatrix2x4fv = 0;
PFNGLPROGRAMUNIFORMMATRIX2X4FVEXTPROC glProgramUniformMatrix2x4fvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX3DVPROC glProgramUniformMatrix3dv = 0;
PFNGLPROGRAMUNIFORMMATRIX3DVEXTPROC glProgramUniformMatrix3dvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX3FVPROC glProgramUniformMatrix3fv = 0;
PFNGLPROGRAMUNIFORMMATRIX3FVEXTPROC glProgramUniformMatrix3fvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX3X2DVPROC glProgramUniformMatrix3x2dv = 0;
PFNGLPROGRAMUNIFORMMATRIX3X2DVEXTPROC glProgramUniformMatrix3x2dvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX3X2FVPROC glProgramUniformMatrix3x2fv = 0;
PFNGLPROGRAMUNIFORMMATRIX3X2FVEXTPROC glProgramUniformMatrix3x2fvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX3X4DVPROC glProgramUniformMatrix3x4dv = 0;
PFNGLPROGRAMUNIFORMMATRIX3X4DVEXTPROC glProgramUniformMatrix3x4dvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX3X4FVPROC glProgramUniformMatrix3x4fv = 0;
PFNGLPROGRAMUNIFORMMATRIX3X4FVEXTPROC glProgramUniformMatrix3x4fvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX4DVPROC glProgramUniformMatrix4dv = 0;
PFNGLPROGRAMUNIFORMMATRIX4DVEXTPROC glProgramUniformMatrix4dvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX4FVPROC glProgramUniformMatrix4fv = 0;
PFNGLPROGRAMUNIFORMMATRIX4FVEXTPROC glProgramUniformMatrix4fvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX4X2DVPROC glProgramUniformMatrix4x2dv = 0;
PFNGLPROGRAMUNIFORMMATRIX4X2DVEXTPROC glProgramUniformMatrix4x2dvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX4X2FVPROC glProgramUniformMatrix4x2fv = 0;
PFNGLPROGRAMUNIFORMMATRIX4X2FVEXTPROC glProgramUniformMatrix4x2fvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX4X3DVPROC glProgramUniformMatrix4x3dv = 0;
PFNGLPROGRAMUNIFORMMATRIX4X3DVEXTPROC glProgramUniformMatrix4x3dvEXT = 0;
PFNGLPROGRAMUNIFORMMATRIX4X3FVPROC glProgramUniformMatrix4x3fv = 0;
PFNGLPROGRAMUNIFORMMATRIX4X3FVEXTPROC glProgramUniformMatrix4x3fvEXT = 0;
PFNGLPROGRAMUNIFORMUI64NVPROC glProgramUniformui64NV = 0;
PFNGLPROGRAMUNIFORMUI64VNVPROC glProgramUniformui64vNV = 0;
PFNGLPROGRAMVERTEXLIMITNVPROC glProgramVertexLimitNV = 0;
PFNGLPROVOKINGVERTEXPROC glProvokingVertex = 0;
PFNGLPROVOKINGVERTEXEXTPROC glProvokingVertexEXT = 0;
PFNGLPUSHATTRIBPROC glPushAttrib = 0;
PFNGLPUSHCLIENTATTRIBPROC glPushClientAttrib = 0;
PFNGLPUSHCLIENTATTRIBDEFAULTEXTPROC glPushClientAttribDefaultEXT = 0;
PFNGLPUSHDEBUGGROUPPROC glPushDebugGroup = 0;
PFNGLPUSHDEBUGGROUPKHRPROC glPushDebugGroupKHR = 0;
PFNGLPUSHGROUPMARKEREXTPROC glPushGroupMarkerEXT = 0;
PFNGLPUSHMATRIXPROC glPushMatrix = 0;
PFNGLPUSHNAMEPROC glPushName = 0;
PFNGLQUERYCOUNTERPROC glQueryCounter = 0;
PFNGLQUERYCOUNTEREXTPROC glQueryCounterEXT = 0;
PFNGLQUERYMATRIXXOESPROC glQueryMatrixxOES = 0;
PFNGLQUERYOBJECTPARAMETERUIAMDPROC glQueryObjectParameteruiAMD = 0;
PFNGLQUERYRESOURCENVPROC glQueryResourceNV = 0;
PFNGLQUERYRESOURCETAGNVPROC glQueryResourceTagNV = 0;
PFNGLRASTERPOS2DPROC glRasterPos2d = 0;
PFNGLRASTERPOS2DVPROC glRasterPos2dv = 0;
PFNGLRASTERPOS2FPROC glRasterPos2f = 0;
PFNGLRASTERPOS2FVPROC glRasterPos2fv = 0;
PFNGLRASTERPOS2IPROC glRasterPos2i = 0;
PFNGLRASTERPOS2IVPROC glRasterPos2iv = 0;
PFNGLRASTERPOS2SPROC glRasterPos2s = 0;
PFNGLRASTERPOS2SVPROC glRasterPos2sv = 0;
PFNGLRASTERPOS2XOESPROC glRasterPos2xOES = 0;
PFNGLRASTERPOS2XVOESPROC glRasterPos2xvOES = 0;
PFNGLRASTERPOS3DPROC glRasterPos3d = 0;
PFNGLRASTERPOS3DVPROC glRasterPos3dv = 0;
PFNGLRASTERPOS3FPROC glRasterPos3f = 0;
PFNGLRASTERPOS3FVPROC glRasterPos3fv = 0;
PFNGLRASTERPOS3IPROC glRasterPos3i = 0;
PFNGLRASTERPOS3IVPROC glRasterPos3iv = 0;
PFNGLRASTERPOS3SPROC glRasterPos3s = 0;
PFNGLRASTERPOS3SVPROC glRasterPos3sv = 0;
PFNGLRASTERPOS3XOESPROC glRasterPos3xOES = 0;
PFNGLRASTERPOS3XVOESPROC glRasterPos3xvOES = 0;
PFNGLRASTERPOS4DPROC glRasterPos4d = 0;
PFNGLRASTERPOS4DVPROC glRasterPos4dv = 0;
PFNGLRASTERPOS4FPROC glRasterPos4f = 0;
PFNGLRASTERPOS4FVPROC glRasterPos4fv = 0;
PFNGLRASTERPOS4IPROC glRasterPos4i = 0;
PFNGLRASTERPOS4IVPROC glRasterPos4iv = 0;
PFNGLRASTERPOS4SPROC glRasterPos4s = 0;
PFNGLRASTERPOS4SVPROC glRasterPos4sv = 0;
PFNGLRASTERPOS4XOESPROC glRasterPos4xOES = 0;
PFNGLRASTERPOS4XVOESPROC glRasterPos4xvOES = 0;
PFNGLRASTERSAMPLESEXTPROC glRasterSamplesEXT = 0;
PFNGLREADBUFFERPROC glReadBuffer = 0;
PFNGLREADBUFFERINDEXEDEXTPROC glReadBufferIndexedEXT = 0;
PFNGLREADBUFFERNVPROC glReadBufferNV = 0;
PFNGLREADINSTRUMENTSSGIXPROC glReadInstrumentsSGIX = 0;
PFNGLREADPIXELSPROC glReadPixels = 0;
PFNGLREADNPIXELSPROC glReadnPixels = 0;
PFNGLREADNPIXELSARBPROC glReadnPixelsARB = 0;
PFNGLREADNPIXELSEXTPROC glReadnPixelsEXT = 0;
PFNGLREADNPIXELSKHRPROC glReadnPixelsKHR = 0;
PFNGLRELEASEKEYEDMUTEXWIN32EXTPROC glReleaseKeyedMutexWin32EXT = 0;
PFNGLRECTDPROC glRectd = 0;
PFNGLRECTDVPROC glRectdv = 0;
PFNGLRECTFPROC glRectf = 0;
PFNGLRECTFVPROC glRectfv = 0;
PFNGLRECTIPROC glRecti = 0;
PFNGLRECTIVPROC glRectiv = 0;
PFNGLRECTSPROC glRects = 0;
PFNGLRECTSVPROC glRectsv = 0;
PFNGLRECTXOESPROC glRectxOES = 0;
PFNGLRECTXVOESPROC glRectxvOES = 0;
PFNGLREFERENCEPLANESGIXPROC glReferencePlaneSGIX = 0;
PFNGLRELEASESHADERCOMPILERPROC glReleaseShaderCompiler = 0;
PFNGLRENDERGPUMASKNVPROC glRenderGpuMaskNV = 0;
PFNGLRENDERMODEPROC glRenderMode = 0;
PFNGLRENDERBUFFERSTORAGEPROC glRenderbufferStorage = 0;
PFNGLRENDERBUFFERSTORAGEEXTPROC glRenderbufferStorageEXT = 0;
PFNGLRENDERBUFFERSTORAGEMULTISAMPLEPROC glRenderbufferStorageMultisample = 0;
PFNGLRENDERBUFFERSTORAGEMULTISAMPLEANGLEPROC glRenderbufferStorageMultisampleANGLE = 0;
PFNGLRENDERBUFFERSTORAGEMULTISAMPLEAPPLEPROC glRenderbufferStorageMultisampleAPPLE = 0;
PFNGLRENDERBUFFERSTORAGEMULTISAMPLEADVANCEDAMDPROC glRenderbufferStorageMultisampleAdvancedAMD = 0;
PFNGLRENDERBUFFERSTORAGEMULTISAMPLECOVERAGENVPROC glRenderbufferStorageMultisampleCoverageNV = 0;
PFNGLRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC glRenderbufferStorageMultisampleEXT = 0;
PFNGLRENDERBUFFERSTORAGEMULTISAMPLEIMGPROC glRenderbufferStorageMultisampleIMG = 0;
PFNGLRENDERBUFFERSTORAGEMULTISAMPLENVPROC glRenderbufferStorageMultisampleNV = 0;
PFNGLRENDERBUFFERSTORAGEOESPROC glRenderbufferStorageOES = 0;
PFNGLREPLACEMENTCODEPOINTERSUNPROC glReplacementCodePointerSUN = 0;
PFNGLREPLACEMENTCODEUBSUNPROC glReplacementCodeubSUN = 0;
PFNGLREPLACEMENTCODEUBVSUNPROC glReplacementCodeubvSUN = 0;
PFNGLREPLACEMENTCODEUICOLOR3FVERTEX3FSUNPROC glReplacementCodeuiColor3fVertex3fSUN = 0;
PFNGLREPLACEMENTCODEUICOLOR3FVERTEX3FVSUNPROC glReplacementCodeuiColor3fVertex3fvSUN = 0;
PFNGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FSUNPROC glReplacementCodeuiColor4fNormal3fVertex3fSUN = 0;
PFNGLREPLACEMENTCODEUICOLOR4FNORMAL3FVERTEX3FVSUNPROC glReplacementCodeuiColor4fNormal3fVertex3fvSUN = 0;
PFNGLREPLACEMENTCODEUICOLOR4UBVERTEX3FSUNPROC glReplacementCodeuiColor4ubVertex3fSUN = 0;
PFNGLREPLACEMENTCODEUICOLOR4UBVERTEX3FVSUNPROC glReplacementCodeuiColor4ubVertex3fvSUN = 0;
PFNGLREPLACEMENTCODEUINORMAL3FVERTEX3FSUNPROC glReplacementCodeuiNormal3fVertex3fSUN = 0;
PFNGLREPLACEMENTCODEUINORMAL3FVERTEX3FVSUNPROC glReplacementCodeuiNormal3fVertex3fvSUN = 0;
PFNGLREPLACEMENTCODEUISUNPROC glReplacementCodeuiSUN = 0;
PFNGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUNPROC glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN = 0;
PFNGLREPLACEMENTCODEUITEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUNPROC glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN = 0;
PFNGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FSUNPROC glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN = 0;
PFNGLREPLACEMENTCODEUITEXCOORD2FNORMAL3FVERTEX3FVSUNPROC glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN = 0;
PFNGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FSUNPROC glReplacementCodeuiTexCoord2fVertex3fSUN = 0;
PFNGLREPLACEMENTCODEUITEXCOORD2FVERTEX3FVSUNPROC glReplacementCodeuiTexCoord2fVertex3fvSUN = 0;
PFNGLREPLACEMENTCODEUIVERTEX3FSUNPROC glReplacementCodeuiVertex3fSUN = 0;
PFNGLREPLACEMENTCODEUIVERTEX3FVSUNPROC glReplacementCodeuiVertex3fvSUN = 0;
PFNGLREPLACEMENTCODEUIVSUNPROC glReplacementCodeuivSUN = 0;
PFNGLREPLACEMENTCODEUSSUNPROC glReplacementCodeusSUN = 0;
PFNGLREPLACEMENTCODEUSVSUNPROC glReplacementCodeusvSUN = 0;
PFNGLREQUESTRESIDENTPROGRAMSNVPROC glRequestResidentProgramsNV = 0;
PFNGLRESETHISTOGRAMPROC glResetHistogram = 0;
PFNGLRESETHISTOGRAMEXTPROC glResetHistogramEXT = 0;
PFNGLRESETMEMORYOBJECTPARAMETERNVPROC glResetMemoryObjectParameterNV = 0;
PFNGLRESETMINMAXPROC glResetMinmax = 0;
PFNGLRESETMINMAXEXTPROC glResetMinmaxEXT = 0;
PFNGLRESIZEBUFFERSMESAPROC glResizeBuffersMESA = 0;
PFNGLRESOLVEDEPTHVALUESNVPROC glResolveDepthValuesNV = 0;
PFNGLRESOLVEMULTISAMPLEFRAMEBUFFERAPPLEPROC glResolveMultisampleFramebufferAPPLE = 0;
PFNGLRESUMETRANSFORMFEEDBACKPROC glResumeTransformFeedback = 0;
PFNGLRESUMETRANSFORMFEEDBACKNVPROC glResumeTransformFeedbackNV = 0;
PFNGLROTATEDPROC glRotated = 0;
PFNGLROTATEFPROC glRotatef = 0;
PFNGLROTATEXPROC glRotatex = 0;
PFNGLROTATEXOESPROC glRotatexOES = 0;
PFNGLSAMPLECOVERAGEPROC glSampleCoverage = 0;
PFNGLSAMPLECOVERAGEARBPROC glSampleCoverageARB = 0;
PFNGLSAMPLECOVERAGEXPROC glSampleCoveragex = 0;
PFNGLSAMPLECOVERAGEXOESPROC glSampleCoveragexOES = 0;
PFNGLSAMPLEMAPATIPROC glSampleMapATI = 0;
PFNGLSAMPLEMASKEXTPROC glSampleMaskEXT = 0;
PFNGLSAMPLEMASKINDEXEDNVPROC glSampleMaskIndexedNV = 0;
PFNGLSAMPLEMASKSGISPROC glSampleMaskSGIS = 0;
PFNGLSAMPLEMASKIPROC glSampleMaski = 0;
PFNGLSAMPLEPATTERNEXTPROC glSamplePatternEXT = 0;
PFNGLSAMPLEPATTERNSGISPROC glSamplePatternSGIS = 0;
PFNGLSAMPLERPARAMETERIIVPROC glSamplerParameterIiv = 0;
PFNGLSAMPLERPARAMETERIIVEXTPROC glSamplerParameterIivEXT = 0;
PFNGLSAMPLERPARAMETERIIVOESPROC glSamplerParameterIivOES = 0;
PFNGLSAMPLERPARAMETERIUIVPROC glSamplerParameterIuiv = 0;
PFNGLSAMPLERPARAMETERIUIVEXTPROC glSamplerParameterIuivEXT = 0;
PFNGLSAMPLERPARAMETERIUIVOESPROC glSamplerParameterIuivOES = 0;
PFNGLSAMPLERPARAMETERFPROC glSamplerParameterf = 0;
PFNGLSAMPLERPARAMETERFVPROC glSamplerParameterfv = 0;
PFNGLSAMPLERPARAMETERIPROC glSamplerParameteri = 0;
PFNGLSAMPLERPARAMETERIVPROC glSamplerParameteriv = 0;
PFNGLSCALEDPROC glScaled = 0;
PFNGLSCALEFPROC glScalef = 0;
PFNGLSCALEXPROC glScalex = 0;
PFNGLSCALEXOESPROC glScalexOES = 0;
PFNGLSCISSORPROC glScissor = 0;
PFNGLSCISSORARRAYVPROC glScissorArrayv = 0;
PFNGLSCISSORARRAYVNVPROC glScissorArrayvNV = 0;
PFNGLSCISSORARRAYVOESPROC glScissorArrayvOES = 0;
PFNGLSCISSOREXCLUSIVEARRAYVNVPROC glScissorExclusiveArrayvNV = 0;
PFNGLSCISSOREXCLUSIVENVPROC glScissorExclusiveNV = 0;
PFNGLSCISSORINDEXEDPROC glScissorIndexed = 0;
PFNGLSCISSORINDEXEDNVPROC glScissorIndexedNV = 0;
PFNGLSCISSORINDEXEDOESPROC glScissorIndexedOES = 0;
PFNGLSCISSORINDEXEDVPROC glScissorIndexedv = 0;
PFNGLSCISSORINDEXEDVNVPROC glScissorIndexedvNV = 0;
PFNGLSCISSORINDEXEDVOESPROC glScissorIndexedvOES = 0;
PFNGLSECONDARYCOLOR3BPROC glSecondaryColor3b = 0;
PFNGLSECONDARYCOLOR3BEXTPROC glSecondaryColor3bEXT = 0;
PFNGLSECONDARYCOLOR3BVPROC glSecondaryColor3bv = 0;
PFNGLSECONDARYCOLOR3BVEXTPROC glSecondaryColor3bvEXT = 0;
PFNGLSECONDARYCOLOR3DPROC glSecondaryColor3d = 0;
PFNGLSECONDARYCOLOR3DEXTPROC glSecondaryColor3dEXT = 0;
PFNGLSECONDARYCOLOR3DVPROC glSecondaryColor3dv = 0;
PFNGLSECONDARYCOLOR3DVEXTPROC glSecondaryColor3dvEXT = 0;
PFNGLSECONDARYCOLOR3FPROC glSecondaryColor3f = 0;
PFNGLSECONDARYCOLOR3FEXTPROC glSecondaryColor3fEXT = 0;
PFNGLSECONDARYCOLOR3FVPROC glSecondaryColor3fv = 0;
PFNGLSECONDARYCOLOR3FVEXTPROC glSecondaryColor3fvEXT = 0;
PFNGLSECONDARYCOLOR3HNVPROC glSecondaryColor3hNV = 0;
PFNGLSECONDARYCOLOR3HVNVPROC glSecondaryColor3hvNV = 0;
PFNGLSECONDARYCOLOR3IPROC glSecondaryColor3i = 0;
PFNGLSECONDARYCOLOR3IEXTPROC glSecondaryColor3iEXT = 0;
PFNGLSECONDARYCOLOR3IVPROC glSecondaryColor3iv = 0;
PFNGLSECONDARYCOLOR3IVEXTPROC glSecondaryColor3ivEXT = 0;
PFNGLSECONDARYCOLOR3SPROC glSecondaryColor3s = 0;
PFNGLSECONDARYCOLOR3SEXTPROC glSecondaryColor3sEXT = 0;
PFNGLSECONDARYCOLOR3SVPROC glSecondaryColor3sv = 0;
PFNGLSECONDARYCOLOR3SVEXTPROC glSecondaryColor3svEXT = 0;
PFNGLSECONDARYCOLOR3UBPROC glSecondaryColor3ub = 0;
PFNGLSECONDARYCOLOR3UBEXTPROC glSecondaryColor3ubEXT = 0;
PFNGLSECONDARYCOLOR3UBVPROC glSecondaryColor3ubv = 0;
PFNGLSECONDARYCOLOR3UBVEXTPROC glSecondaryColor3ubvEXT = 0;
PFNGLSECONDARYCOLOR3UIPROC glSecondaryColor3ui = 0;
PFNGLSECONDARYCOLOR3UIEXTPROC glSecondaryColor3uiEXT = 0;
PFNGLSECONDARYCOLOR3UIVPROC glSecondaryColor3uiv = 0;
PFNGLSECONDARYCOLOR3UIVEXTPROC glSecondaryColor3uivEXT = 0;
PFNGLSECONDARYCOLOR3USPROC glSecondaryColor3us = 0;
PFNGLSECONDARYCOLOR3USEXTPROC glSecondaryColor3usEXT = 0;
PFNGLSECONDARYCOLOR3USVPROC glSecondaryColor3usv = 0;
PFNGLSECONDARYCOLOR3USVEXTPROC glSecondaryColor3usvEXT = 0;
PFNGLSECONDARYCOLORFORMATNVPROC glSecondaryColorFormatNV = 0;
PFNGLSECONDARYCOLORP3UIPROC glSecondaryColorP3ui = 0;
PFNGLSECONDARYCOLORP3UIVPROC glSecondaryColorP3uiv = 0;
PFNGLSECONDARYCOLORPOINTERPROC glSecondaryColorPointer = 0;
PFNGLSECONDARYCOLORPOINTEREXTPROC glSecondaryColorPointerEXT = 0;
PFNGLSECONDARYCOLORPOINTERLISTIBMPROC glSecondaryColorPointerListIBM = 0;
PFNGLSELECTBUFFERPROC glSelectBuffer = 0;
PFNGLSELECTPERFMONITORCOUNTERSAMDPROC glSelectPerfMonitorCountersAMD = 0;
PFNGLSEMAPHOREPARAMETERIVNVPROC glSemaphoreParameterivNV = 0;
PFNGLSEMAPHOREPARAMETERUI64VEXTPROC glSemaphoreParameterui64vEXT = 0;
PFNGLSEPARABLEFILTER2DPROC glSeparableFilter2D = 0;
PFNGLSEPARABLEFILTER2DEXTPROC glSeparableFilter2DEXT = 0;
PFNGLSETFENCEAPPLEPROC glSetFenceAPPLE = 0;
PFNGLSETFENCENVPROC glSetFenceNV = 0;
PFNGLSETFRAGMENTSHADERCONSTANTATIPROC glSetFragmentShaderConstantATI = 0;
PFNGLSETINVARIANTEXTPROC glSetInvariantEXT = 0;
PFNGLSETLOCALCONSTANTEXTPROC glSetLocalConstantEXT = 0;
PFNGLSETMULTISAMPLEFVAMDPROC glSetMultisamplefvAMD = 0;
PFNGLSHADEMODELPROC glShadeModel = 0;
PFNGLSHADERBINARYPROC glShaderBinary = 0;
PFNGLSHADEROP1EXTPROC glShaderOp1EXT = 0;
PFNGLSHADEROP2EXTPROC glShaderOp2EXT = 0;
PFNGLSHADEROP3EXTPROC glShaderOp3EXT = 0;
PFNGLSHADERSOURCEPROC glShaderSource = 0;
PFNGLSHADERSOURCEARBPROC glShaderSourceARB = 0;
PFNGLSHADERSTORAGEBLOCKBINDINGPROC glShaderStorageBlockBinding = 0;
PFNGLSHADINGRATEEXTPROC glShadingRateEXT = 0;
PFNGLSHADINGRATECOMBINEROPSEXTPROC glShadingRateCombinerOpsEXT = 0;
PFNGLSHADINGRATEIMAGEBARRIERNVPROC glShadingRateImageBarrierNV = 0;
PFNGLSHADINGRATEQCOMPROC glShadingRateQCOM = 0;
PFNGLSHADINGRATEIMAGEPALETTENVPROC glShadingRateImagePaletteNV = 0;
PFNGLSHADINGRATESAMPLEORDERNVPROC glShadingRateSampleOrderNV = 0;
PFNGLSHADINGRATESAMPLEORDERCUSTOMNVPROC glShadingRateSampleOrderCustomNV = 0;
PFNGLSHARPENTEXFUNCSGISPROC glSharpenTexFuncSGIS = 0;
PFNGLSIGNALSEMAPHOREEXTPROC glSignalSemaphoreEXT = 0;
PFNGLSIGNALSEMAPHOREUI64NVXPROC glSignalSemaphoreui64NVX = 0;
PFNGLSPECIALIZESHADERPROC glSpecializeShader = 0;
PFNGLSPECIALIZESHADERARBPROC glSpecializeShaderARB = 0;
PFNGLSPRITEPARAMETERFSGIXPROC glSpriteParameterfSGIX = 0;
PFNGLSPRITEPARAMETERFVSGIXPROC glSpriteParameterfvSGIX = 0;
PFNGLSPRITEPARAMETERISGIXPROC glSpriteParameteriSGIX = 0;
PFNGLSPRITEPARAMETERIVSGIXPROC glSpriteParameterivSGIX = 0;
PFNGLSTARTINSTRUMENTSSGIXPROC glStartInstrumentsSGIX = 0;
PFNGLSTARTTILINGQCOMPROC glStartTilingQCOM = 0;
PFNGLSTATECAPTURENVPROC glStateCaptureNV = 0;
PFNGLSTENCILCLEARTAGEXTPROC glStencilClearTagEXT = 0;
PFNGLSTENCILFILLPATHINSTANCEDNVPROC glStencilFillPathInstancedNV = 0;
PFNGLSTENCILFILLPATHNVPROC glStencilFillPathNV = 0;
PFNGLSTENCILFUNCPROC glStencilFunc = 0;
PFNGLSTENCILFUNCSEPARATEPROC glStencilFuncSeparate = 0;
PFNGLSTENCILFUNCSEPARATEATIPROC glStencilFuncSeparateATI = 0;
PFNGLSTENCILMASKPROC glStencilMask = 0;
PFNGLSTENCILMASKSEPARATEPROC glStencilMaskSeparate = 0;
PFNGLSTENCILOPPROC glStencilOp = 0;
PFNGLSTENCILOPSEPARATEPROC glStencilOpSeparate = 0;
PFNGLSTENCILOPSEPARATEATIPROC glStencilOpSeparateATI = 0;
PFNGLSTENCILOPVALUEAMDPROC glStencilOpValueAMD = 0;
PFNGLSTENCILSTROKEPATHINSTANCEDNVPROC glStencilStrokePathInstancedNV = 0;
PFNGLSTENCILSTROKEPATHNVPROC glStencilStrokePathNV = 0;
PFNGLSTENCILTHENCOVERFILLPATHINSTANCEDNVPROC glStencilThenCoverFillPathInstancedNV = 0;
PFNGLSTENCILTHENCOVERFILLPATHNVPROC glStencilThenCoverFillPathNV = 0;
PFNGLSTENCILTHENCOVERSTROKEPATHINSTANCEDNVPROC glStencilThenCoverStrokePathInstancedNV = 0;
PFNGLSTENCILTHENCOVERSTROKEPATHNVPROC glStencilThenCoverStrokePathNV = 0;
PFNGLSTOPINSTRUMENTSSGIXPROC glStopInstrumentsSGIX = 0;
PFNGLSTRINGMARKERGREMEDYPROC glStringMarkerGREMEDY = 0;
PFNGLSUBPIXELPRECISIONBIASNVPROC glSubpixelPrecisionBiasNV = 0;
PFNGLSWIZZLEEXTPROC glSwizzleEXT = 0;
PFNGLSYNCTEXTUREINTELPROC glSyncTextureINTEL = 0;
PFNGLTAGSAMPLEBUFFERSGIXPROC glTagSampleBufferSGIX = 0;
PFNGLTANGENT3BEXTPROC glTangent3bEXT = 0;
PFNGLTANGENT3BVEXTPROC glTangent3bvEXT = 0;
PFNGLTANGENT3DEXTPROC glTangent3dEXT = 0;
PFNGLTANGENT3DVEXTPROC glTangent3dvEXT = 0;
PFNGLTANGENT3FEXTPROC glTangent3fEXT = 0;
PFNGLTANGENT3FVEXTPROC glTangent3fvEXT = 0;
PFNGLTANGENT3IEXTPROC glTangent3iEXT = 0;
PFNGLTANGENT3IVEXTPROC glTangent3ivEXT = 0;
PFNGLTANGENT3SEXTPROC glTangent3sEXT = 0;
PFNGLTANGENT3SVEXTPROC glTangent3svEXT = 0;
PFNGLTANGENTPOINTEREXTPROC glTangentPointerEXT = 0;
PFNGLTBUFFERMASK3DFXPROC glTbufferMask3DFX = 0;
PFNGLTESSELLATIONFACTORAMDPROC glTessellationFactorAMD = 0;
PFNGLTESSELLATIONMODEAMDPROC glTessellationModeAMD = 0;
PFNGLTESTFENCEAPPLEPROC glTestFenceAPPLE = 0;
PFNGLTESTFENCENVPROC glTestFenceNV = 0;
PFNGLTESTOBJECTAPPLEPROC glTestObjectAPPLE = 0;
PFNGLTEXATTACHMEMORYNVPROC glTexAttachMemoryNV = 0;
PFNGLTEXBUFFERPROC glTexBuffer = 0;
PFNGLTEXBUFFERARBPROC glTexBufferARB = 0;
PFNGLTEXBUFFEREXTPROC glTexBufferEXT = 0;
PFNGLTEXBUFFEROESPROC glTexBufferOES = 0;
PFNGLTEXBUFFERRANGEPROC glTexBufferRange = 0;
PFNGLTEXBUFFERRANGEEXTPROC glTexBufferRangeEXT = 0;
PFNGLTEXBUFFERRANGEOESPROC glTexBufferRangeOES = 0;
PFNGLTEXBUMPPARAMETERFVATIPROC glTexBumpParameterfvATI = 0;
PFNGLTEXBUMPPARAMETERIVATIPROC glTexBumpParameterivATI = 0;
PFNGLTEXCOORD1BOESPROC glTexCoord1bOES = 0;
PFNGLTEXCOORD1BVOESPROC glTexCoord1bvOES = 0;
PFNGLTEXCOORD1DPROC glTexCoord1d = 0;
PFNGLTEXCOORD1DVPROC glTexCoord1dv = 0;
PFNGLTEXCOORD1FPROC glTexCoord1f = 0;
PFNGLTEXCOORD1FVPROC glTexCoord1fv = 0;
PFNGLTEXCOORD1HNVPROC glTexCoord1hNV = 0;
PFNGLTEXCOORD1HVNVPROC glTexCoord1hvNV = 0;
PFNGLTEXCOORD1IPROC glTexCoord1i = 0;
PFNGLTEXCOORD1IVPROC glTexCoord1iv = 0;
PFNGLTEXCOORD1SPROC glTexCoord1s = 0;
PFNGLTEXCOORD1SVPROC glTexCoord1sv = 0;
PFNGLTEXCOORD1XOESPROC glTexCoord1xOES = 0;
PFNGLTEXCOORD1XVOESPROC glTexCoord1xvOES = 0;
PFNGLTEXCOORD2BOESPROC glTexCoord2bOES = 0;
PFNGLTEXCOORD2BVOESPROC glTexCoord2bvOES = 0;
PFNGLTEXCOORD2DPROC glTexCoord2d = 0;
PFNGLTEXCOORD2DVPROC glTexCoord2dv = 0;
PFNGLTEXCOORD2FPROC glTexCoord2f = 0;
PFNGLTEXCOORD2FCOLOR3FVERTEX3FSUNPROC glTexCoord2fColor3fVertex3fSUN = 0;
PFNGLTEXCOORD2FCOLOR3FVERTEX3FVSUNPROC glTexCoord2fColor3fVertex3fvSUN = 0;
PFNGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FSUNPROC glTexCoord2fColor4fNormal3fVertex3fSUN = 0;
PFNGLTEXCOORD2FCOLOR4FNORMAL3FVERTEX3FVSUNPROC glTexCoord2fColor4fNormal3fVertex3fvSUN = 0;
PFNGLTEXCOORD2FCOLOR4UBVERTEX3FSUNPROC glTexCoord2fColor4ubVertex3fSUN = 0;
PFNGLTEXCOORD2FCOLOR4UBVERTEX3FVSUNPROC glTexCoord2fColor4ubVertex3fvSUN = 0;
PFNGLTEXCOORD2FNORMAL3FVERTEX3FSUNPROC glTexCoord2fNormal3fVertex3fSUN = 0;
PFNGLTEXCOORD2FNORMAL3FVERTEX3FVSUNPROC glTexCoord2fNormal3fVertex3fvSUN = 0;
PFNGLTEXCOORD2FVERTEX3FSUNPROC glTexCoord2fVertex3fSUN = 0;
PFNGLTEXCOORD2FVERTEX3FVSUNPROC glTexCoord2fVertex3fvSUN = 0;
PFNGLTEXCOORD2FVPROC glTexCoord2fv = 0;
PFNGLTEXCOORD2HNVPROC glTexCoord2hNV = 0;
PFNGLTEXCOORD2HVNVPROC glTexCoord2hvNV = 0;
PFNGLTEXCOORD2IPROC glTexCoord2i = 0;
PFNGLTEXCOORD2IVPROC glTexCoord2iv = 0;
PFNGLTEXCOORD2SPROC glTexCoord2s = 0;
PFNGLTEXCOORD2SVPROC glTexCoord2sv = 0;
PFNGLTEXCOORD2XOESPROC glTexCoord2xOES = 0;
PFNGLTEXCOORD2XVOESPROC glTexCoord2xvOES = 0;
PFNGLTEXCOORD3BOESPROC glTexCoord3bOES = 0;
PFNGLTEXCOORD3BVOESPROC glTexCoord3bvOES = 0;
PFNGLTEXCOORD3DPROC glTexCoord3d = 0;
PFNGLTEXCOORD3DVPROC glTexCoord3dv = 0;
PFNGLTEXCOORD3FPROC glTexCoord3f = 0;
PFNGLTEXCOORD3FVPROC glTexCoord3fv = 0;
PFNGLTEXCOORD3HNVPROC glTexCoord3hNV = 0;
PFNGLTEXCOORD3HVNVPROC glTexCoord3hvNV = 0;
PFNGLTEXCOORD3IPROC glTexCoord3i = 0;
PFNGLTEXCOORD3IVPROC glTexCoord3iv = 0;
PFNGLTEXCOORD3SPROC glTexCoord3s = 0;
PFNGLTEXCOORD3SVPROC glTexCoord3sv = 0;
PFNGLTEXCOORD3XOESPROC glTexCoord3xOES = 0;
PFNGLTEXCOORD3XVOESPROC glTexCoord3xvOES = 0;
PFNGLTEXCOORD4BOESPROC glTexCoord4bOES = 0;
PFNGLTEXCOORD4BVOESPROC glTexCoord4bvOES = 0;
PFNGLTEXCOORD4DPROC glTexCoord4d = 0;
PFNGLTEXCOORD4DVPROC glTexCoord4dv = 0;
PFNGLTEXCOORD4FPROC glTexCoord4f = 0;
PFNGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FSUNPROC glTexCoord4fColor4fNormal3fVertex4fSUN = 0;
PFNGLTEXCOORD4FCOLOR4FNORMAL3FVERTEX4FVSUNPROC glTexCoord4fColor4fNormal3fVertex4fvSUN = 0;
PFNGLTEXCOORD4FVERTEX4FSUNPROC glTexCoord4fVertex4fSUN = 0;
PFNGLTEXCOORD4FVERTEX4FVSUNPROC glTexCoord4fVertex4fvSUN = 0;
PFNGLTEXCOORD4FVPROC glTexCoord4fv = 0;
PFNGLTEXCOORD4HNVPROC glTexCoord4hNV = 0;
PFNGLTEXCOORD4HVNVPROC glTexCoord4hvNV = 0;
PFNGLTEXCOORD4IPROC glTexCoord4i = 0;
PFNGLTEXCOORD4IVPROC glTexCoord4iv = 0;
PFNGLTEXCOORD4SPROC glTexCoord4s = 0;
PFNGLTEXCOORD4SVPROC glTexCoord4sv = 0;
PFNGLTEXCOORD4XOESPROC glTexCoord4xOES = 0;
PFNGLTEXCOORD4XVOESPROC glTexCoord4xvOES = 0;
PFNGLTEXCOORDFORMATNVPROC glTexCoordFormatNV = 0;
PFNGLTEXCOORDP1UIPROC glTexCoordP1ui = 0;
PFNGLTEXCOORDP1UIVPROC glTexCoordP1uiv = 0;
PFNGLTEXCOORDP2UIPROC glTexCoordP2ui = 0;
PFNGLTEXCOORDP2UIVPROC glTexCoordP2uiv = 0;
PFNGLTEXCOORDP3UIPROC glTexCoordP3ui = 0;
PFNGLTEXCOORDP3UIVPROC glTexCoordP3uiv = 0;
PFNGLTEXCOORDP4UIPROC glTexCoordP4ui = 0;
PFNGLTEXCOORDP4UIVPROC glTexCoordP4uiv = 0;
PFNGLTEXCOORDPOINTERPROC glTexCoordPointer = 0;
PFNGLTEXCOORDPOINTEREXTPROC glTexCoordPointerEXT = 0;
PFNGLTEXCOORDPOINTERLISTIBMPROC glTexCoordPointerListIBM = 0;
PFNGLTEXCOORDPOINTERVINTELPROC glTexCoordPointervINTEL = 0;
PFNGLTEXENVFPROC glTexEnvf = 0;
PFNGLTEXENVFVPROC glTexEnvfv = 0;
PFNGLTEXENVIPROC glTexEnvi = 0;
PFNGLTEXENVIVPROC glTexEnviv = 0;
PFNGLTEXENVXPROC glTexEnvx = 0;
PFNGLTEXENVXOESPROC glTexEnvxOES = 0;
PFNGLTEXENVXVPROC glTexEnvxv = 0;
PFNGLTEXENVXVOESPROC glTexEnvxvOES = 0;
PFNGLTEXESTIMATEMOTIONQCOMPROC glTexEstimateMotionQCOM = 0;
PFNGLTEXESTIMATEMOTIONREGIONSQCOMPROC glTexEstimateMotionRegionsQCOM = 0;
PFNGLEXTRAPOLATETEX2DQCOMPROC glExtrapolateTex2DQCOM = 0;
PFNGLTEXFILTERFUNCSGISPROC glTexFilterFuncSGIS = 0;
PFNGLTEXGENDPROC glTexGend = 0;
PFNGLTEXGENDVPROC glTexGendv = 0;
PFNGLTEXGENFPROC glTexGenf = 0;
PFNGLTEXGENFOESPROC glTexGenfOES = 0;
PFNGLTEXGENFVPROC glTexGenfv = 0;
PFNGLTEXGENFVOESPROC glTexGenfvOES = 0;
PFNGLTEXGENIPROC glTexGeni = 0;
PFNGLTEXGENIOESPROC glTexGeniOES = 0;
PFNGLTEXGENIVPROC glTexGeniv = 0;
PFNGLTEXGENIVOESPROC glTexGenivOES = 0;
PFNGLTEXGENXOESPROC glTexGenxOES = 0;
PFNGLTEXGENXVOESPROC glTexGenxvOES = 0;
PFNGLTEXIMAGE1DPROC glTexImage1D = 0;
PFNGLTEXIMAGE2DPROC glTexImage2D = 0;
PFNGLTEXIMAGE2DMULTISAMPLEPROC glTexImage2DMultisample = 0;
PFNGLTEXIMAGE2DMULTISAMPLECOVERAGENVPROC glTexImage2DMultisampleCoverageNV = 0;
PFNGLTEXIMAGE3DPROC glTexImage3D = 0;
PFNGLTEXIMAGE3DEXTPROC glTexImage3DEXT = 0;
PFNGLTEXIMAGE3DMULTISAMPLEPROC glTexImage3DMultisample = 0;
PFNGLTEXIMAGE3DMULTISAMPLECOVERAGENVPROC glTexImage3DMultisampleCoverageNV = 0;
PFNGLTEXIMAGE3DOESPROC glTexImage3DOES = 0;
PFNGLTEXIMAGE4DSGISPROC glTexImage4DSGIS = 0;
PFNGLTEXPAGECOMMITMENTARBPROC glTexPageCommitmentARB = 0;
PFNGLTEXPAGECOMMITMENTEXTPROC glTexPageCommitmentEXT = 0;
PFNGLTEXPAGECOMMITMENTMEMNVPROC glTexPageCommitmentMemNV = 0;
PFNGLTEXPARAMETERIIVPROC glTexParameterIiv = 0;
PFNGLTEXPARAMETERIIVEXTPROC glTexParameterIivEXT = 0;
PFNGLTEXPARAMETERIIVOESPROC glTexParameterIivOES = 0;
PFNGLTEXPARAMETERIUIVPROC glTexParameterIuiv = 0;
PFNGLTEXPARAMETERIUIVEXTPROC glTexParameterIuivEXT = 0;
PFNGLTEXPARAMETERIUIVOESPROC glTexParameterIuivOES = 0;
PFNGLTEXPARAMETERFPROC glTexParameterf = 0;
PFNGLTEXPARAMETERFVPROC glTexParameterfv = 0;
PFNGLTEXPARAMETERIPROC glTexParameteri = 0;
PFNGLTEXPARAMETERIVPROC glTexParameteriv = 0;
PFNGLTEXPARAMETERXPROC glTexParameterx = 0;
PFNGLTEXPARAMETERXOESPROC glTexParameterxOES = 0;
PFNGLTEXPARAMETERXVPROC glTexParameterxv = 0;
PFNGLTEXPARAMETERXVOESPROC glTexParameterxvOES = 0;
PFNGLTEXRENDERBUFFERNVPROC glTexRenderbufferNV = 0;
PFNGLTEXSTORAGE1DPROC glTexStorage1D = 0;
PFNGLTEXSTORAGE1DEXTPROC glTexStorage1DEXT = 0;
PFNGLTEXSTORAGE2DPROC glTexStorage2D = 0;
PFNGLTEXSTORAGE2DEXTPROC glTexStorage2DEXT = 0;
PFNGLTEXSTORAGE2DMULTISAMPLEPROC glTexStorage2DMultisample = 0;
PFNGLTEXSTORAGE3DPROC glTexStorage3D = 0;
PFNGLTEXSTORAGE3DEXTPROC glTexStorage3DEXT = 0;
PFNGLTEXSTORAGE3DMULTISAMPLEPROC glTexStorage3DMultisample = 0;
PFNGLTEXSTORAGE3DMULTISAMPLEOESPROC glTexStorage3DMultisampleOES = 0;
PFNGLTEXSTORAGEATTRIBS2DEXTPROC glTexStorageAttribs2DEXT = 0;
PFNGLTEXSTORAGEATTRIBS3DEXTPROC glTexStorageAttribs3DEXT = 0;
PFNGLTEXSTORAGEMEM1DEXTPROC glTexStorageMem1DEXT = 0;
PFNGLTEXSTORAGEMEM2DEXTPROC glTexStorageMem2DEXT = 0;
PFNGLTEXSTORAGEMEM2DMULTISAMPLEEXTPROC glTexStorageMem2DMultisampleEXT = 0;
PFNGLTEXSTORAGEMEM3DEXTPROC glTexStorageMem3DEXT = 0;
PFNGLTEXSTORAGEMEM3DMULTISAMPLEEXTPROC glTexStorageMem3DMultisampleEXT = 0;
PFNGLTEXSTORAGESPARSEAMDPROC glTexStorageSparseAMD = 0;
PFNGLTEXSUBIMAGE1DPROC glTexSubImage1D = 0;
PFNGLTEXSUBIMAGE1DEXTPROC glTexSubImage1DEXT = 0;
PFNGLTEXSUBIMAGE2DPROC glTexSubImage2D = 0;
PFNGLTEXSUBIMAGE2DEXTPROC glTexSubImage2DEXT = 0;
PFNGLTEXSUBIMAGE3DPROC glTexSubImage3D = 0;
PFNGLTEXSUBIMAGE3DEXTPROC glTexSubImage3DEXT = 0;
PFNGLTEXSUBIMAGE3DOESPROC glTexSubImage3DOES = 0;
PFNGLTEXSUBIMAGE4DSGISPROC glTexSubImage4DSGIS = 0;
PFNGLTEXTUREATTACHMEMORYNVPROC glTextureAttachMemoryNV = 0;
PFNGLTEXTUREBARRIERPROC glTextureBarrier = 0;
PFNGLTEXTUREBARRIERNVPROC glTextureBarrierNV = 0;
PFNGLTEXTUREBUFFERPROC glTextureBuffer = 0;
PFNGLTEXTUREBUFFEREXTPROC glTextureBufferEXT = 0;
PFNGLTEXTUREBUFFERRANGEPROC glTextureBufferRange = 0;
PFNGLTEXTUREBUFFERRANGEEXTPROC glTextureBufferRangeEXT = 0;
PFNGLTEXTURECOLORMASKSGISPROC glTextureColorMaskSGIS = 0;
PFNGLTEXTUREFOVEATIONPARAMETERSQCOMPROC glTextureFoveationParametersQCOM = 0;
PFNGLTEXTUREIMAGE1DEXTPROC glTextureImage1DEXT = 0;
PFNGLTEXTUREIMAGE2DEXTPROC glTextureImage2DEXT = 0;
PFNGLTEXTUREIMAGE2DMULTISAMPLECOVERAGENVPROC glTextureImage2DMultisampleCoverageNV = 0;
PFNGLTEXTUREIMAGE2DMULTISAMPLENVPROC glTextureImage2DMultisampleNV = 0;
PFNGLTEXTUREIMAGE3DEXTPROC glTextureImage3DEXT = 0;
PFNGLTEXTUREIMAGE3DMULTISAMPLECOVERAGENVPROC glTextureImage3DMultisampleCoverageNV = 0;
PFNGLTEXTUREIMAGE3DMULTISAMPLENVPROC glTextureImage3DMultisampleNV = 0;
PFNGLTEXTURELIGHTEXTPROC glTextureLightEXT = 0;
PFNGLTEXTUREMATERIALEXTPROC glTextureMaterialEXT = 0;
PFNGLTEXTURENORMALEXTPROC glTextureNormalEXT = 0;
PFNGLTEXTUREPAGECOMMITMENTEXTPROC glTexturePageCommitmentEXT = 0;
PFNGLTEXTUREPAGECOMMITMENTMEMNVPROC glTexturePageCommitmentMemNV = 0;
PFNGLTEXTUREPARAMETERIIVPROC glTextureParameterIiv = 0;
PFNGLTEXTUREPARAMETERIIVEXTPROC glTextureParameterIivEXT = 0;
PFNGLTEXTUREPARAMETERIUIVPROC glTextureParameterIuiv = 0;
PFNGLTEXTUREPARAMETERIUIVEXTPROC glTextureParameterIuivEXT = 0;
PFNGLTEXTUREPARAMETERFPROC glTextureParameterf = 0;
PFNGLTEXTUREPARAMETERFEXTPROC glTextureParameterfEXT = 0;
PFNGLTEXTUREPARAMETERFVPROC glTextureParameterfv = 0;
PFNGLTEXTUREPARAMETERFVEXTPROC glTextureParameterfvEXT = 0;
PFNGLTEXTUREPARAMETERIPROC glTextureParameteri = 0;
PFNGLTEXTUREPARAMETERIEXTPROC glTextureParameteriEXT = 0;
PFNGLTEXTUREPARAMETERIVPROC glTextureParameteriv = 0;
PFNGLTEXTUREPARAMETERIVEXTPROC glTextureParameterivEXT = 0;
PFNGLTEXTURERANGEAPPLEPROC glTextureRangeAPPLE = 0;
PFNGLTEXTURERENDERBUFFEREXTPROC glTextureRenderbufferEXT = 0;
PFNGLTEXTURESTORAGE1DPROC glTextureStorage1D = 0;
PFNGLTEXTURESTORAGE1DEXTPROC glTextureStorage1DEXT = 0;
PFNGLTEXTURESTORAGE2DPROC glTextureStorage2D = 0;
PFNGLTEXTURESTORAGE2DEXTPROC glTextureStorage2DEXT = 0;
PFNGLTEXTURESTORAGE2DMULTISAMPLEPROC glTextureStorage2DMultisample = 0;
PFNGLTEXTURESTORAGE2DMULTISAMPLEEXTPROC glTextureStorage2DMultisampleEXT = 0;
PFNGLTEXTURESTORAGE3DPROC glTextureStorage3D = 0;
PFNGLTEXTURESTORAGE3DEXTPROC glTextureStorage3DEXT = 0;
PFNGLTEXTURESTORAGE3DMULTISAMPLEPROC glTextureStorage3DMultisample = 0;
PFNGLTEXTURESTORAGE3DMULTISAMPLEEXTPROC glTextureStorage3DMultisampleEXT = 0;
PFNGLTEXTURESTORAGEMEM1DEXTPROC glTextureStorageMem1DEXT = 0;
PFNGLTEXTURESTORAGEMEM2DEXTPROC glTextureStorageMem2DEXT = 0;
PFNGLTEXTURESTORAGEMEM2DMULTISAMPLEEXTPROC glTextureStorageMem2DMultisampleEXT = 0;
PFNGLTEXTURESTORAGEMEM3DEXTPROC glTextureStorageMem3DEXT = 0;
PFNGLTEXTURESTORAGEMEM3DMULTISAMPLEEXTPROC glTextureStorageMem3DMultisampleEXT = 0;
PFNGLTEXTURESTORAGESPARSEAMDPROC glTextureStorageSparseAMD = 0;
PFNGLTEXTURESUBIMAGE1DPROC glTextureSubImage1D = 0;
PFNGLTEXTURESUBIMAGE1DEXTPROC glTextureSubImage1DEXT = 0;
PFNGLTEXTURESUBIMAGE2DPROC glTextureSubImage2D = 0;
PFNGLTEXTURESUBIMAGE2DEXTPROC glTextureSubImage2DEXT = 0;
PFNGLTEXTURESUBIMAGE3DPROC glTextureSubImage3D = 0;
PFNGLTEXTURESUBIMAGE3DEXTPROC glTextureSubImage3DEXT = 0;
PFNGLTEXTUREVIEWPROC glTextureView = 0;
PFNGLTEXTUREVIEWEXTPROC glTextureViewEXT = 0;
PFNGLTEXTUREVIEWOESPROC glTextureViewOES = 0;
PFNGLTRACKMATRIXNVPROC glTrackMatrixNV = 0;
PFNGLTRANSFORMFEEDBACKATTRIBSNVPROC glTransformFeedbackAttribsNV = 0;
PFNGLTRANSFORMFEEDBACKBUFFERBASEPROC glTransformFeedbackBufferBase = 0;
PFNGLTRANSFORMFEEDBACKBUFFERRANGEPROC glTransformFeedbackBufferRange = 0;
PFNGLTRANSFORMFEEDBACKSTREAMATTRIBSNVPROC glTransformFeedbackStreamAttribsNV = 0;
PFNGLTRANSFORMFEEDBACKVARYINGSPROC glTransformFeedbackVaryings = 0;
PFNGLTRANSFORMFEEDBACKVARYINGSEXTPROC glTransformFeedbackVaryingsEXT = 0;
PFNGLTRANSFORMFEEDBACKVARYINGSNVPROC glTransformFeedbackVaryingsNV = 0;
PFNGLTRANSFORMPATHNVPROC glTransformPathNV = 0;
PFNGLTRANSLATEDPROC glTranslated = 0;
PFNGLTRANSLATEFPROC glTranslatef = 0;
PFNGLTRANSLATEXPROC glTranslatex = 0;
PFNGLTRANSLATEXOESPROC glTranslatexOES = 0;
PFNGLUNIFORM1DPROC glUniform1d = 0;
PFNGLUNIFORM1DVPROC glUniform1dv = 0;
PFNGLUNIFORM1FPROC glUniform1f = 0;
PFNGLUNIFORM1FARBPROC glUniform1fARB = 0;
PFNGLUNIFORM1FVPROC glUniform1fv = 0;
PFNGLUNIFORM1FVARBPROC glUniform1fvARB = 0;
PFNGLUNIFORM1IPROC glUniform1i = 0;
PFNGLUNIFORM1I64ARBPROC glUniform1i64ARB = 0;
PFNGLUNIFORM1I64NVPROC glUniform1i64NV = 0;
PFNGLUNIFORM1I64VARBPROC glUniform1i64vARB = 0;
PFNGLUNIFORM1I64VNVPROC glUniform1i64vNV = 0;
PFNGLUNIFORM1IARBPROC glUniform1iARB = 0;
PFNGLUNIFORM1IVPROC glUniform1iv = 0;
PFNGLUNIFORM1IVARBPROC glUniform1ivARB = 0;
PFNGLUNIFORM1UIPROC glUniform1ui = 0;
PFNGLUNIFORM1UI64ARBPROC glUniform1ui64ARB = 0;
PFNGLUNIFORM1UI64NVPROC glUniform1ui64NV = 0;
PFNGLUNIFORM1UI64VARBPROC glUniform1ui64vARB = 0;
PFNGLUNIFORM1UI64VNVPROC glUniform1ui64vNV = 0;
PFNGLUNIFORM1UIEXTPROC glUniform1uiEXT = 0;
PFNGLUNIFORM1UIVPROC glUniform1uiv = 0;
PFNGLUNIFORM1UIVEXTPROC glUniform1uivEXT = 0;
PFNGLUNIFORM2DPROC glUniform2d = 0;
PFNGLUNIFORM2DVPROC glUniform2dv = 0;
PFNGLUNIFORM2FPROC glUniform2f = 0;
PFNGLUNIFORM2FARBPROC glUniform2fARB = 0;
PFNGLUNIFORM2FVPROC glUniform2fv = 0;
PFNGLUNIFORM2FVARBPROC glUniform2fvARB = 0;
PFNGLUNIFORM2IPROC glUniform2i = 0;
PFNGLUNIFORM2I64ARBPROC glUniform2i64ARB = 0;
PFNGLUNIFORM2I64NVPROC glUniform2i64NV = 0;
PFNGLUNIFORM2I64VARBPROC glUniform2i64vARB = 0;
PFNGLUNIFORM2I64VNVPROC glUniform2i64vNV = 0;
PFNGLUNIFORM2IARBPROC glUniform2iARB = 0;
PFNGLUNIFORM2IVPROC glUniform2iv = 0;
PFNGLUNIFORM2IVARBPROC glUniform2ivARB = 0;
PFNGLUNIFORM2UIPROC glUniform2ui = 0;
PFNGLUNIFORM2UI64ARBPROC glUniform2ui64ARB = 0;
PFNGLUNIFORM2UI64NVPROC glUniform2ui64NV = 0;
PFNGLUNIFORM2UI64VARBPROC glUniform2ui64vARB = 0;
PFNGLUNIFORM2UI64VNVPROC glUniform2ui64vNV = 0;
PFNGLUNIFORM2UIEXTPROC glUniform2uiEXT = 0;
PFNGLUNIFORM2UIVPROC glUniform2uiv = 0;
PFNGLUNIFORM2UIVEXTPROC glUniform2uivEXT = 0;
PFNGLUNIFORM3DPROC glUniform3d = 0;
PFNGLUNIFORM3DVPROC glUniform3dv = 0;
PFNGLUNIFORM3FPROC glUniform3f = 0;
PFNGLUNIFORM3FARBPROC glUniform3fARB = 0;
PFNGLUNIFORM3FVPROC glUniform3fv = 0;
PFNGLUNIFORM3FVARBPROC glUniform3fvARB = 0;
PFNGLUNIFORM3IPROC glUniform3i = 0;
PFNGLUNIFORM3I64ARBPROC glUniform3i64ARB = 0;
PFNGLUNIFORM3I64NVPROC glUniform3i64NV = 0;
PFNGLUNIFORM3I64VARBPROC glUniform3i64vARB = 0;
PFNGLUNIFORM3I64VNVPROC glUniform3i64vNV = 0;
PFNGLUNIFORM3IARBPROC glUniform3iARB = 0;
PFNGLUNIFORM3IVPROC glUniform3iv = 0;
PFNGLUNIFORM3IVARBPROC glUniform3ivARB = 0;
PFNGLUNIFORM3UIPROC glUniform3ui = 0;
PFNGLUNIFORM3UI64ARBPROC glUniform3ui64ARB = 0;
PFNGLUNIFORM3UI64NVPROC glUniform3ui64NV = 0;
PFNGLUNIFORM3UI64VARBPROC glUniform3ui64vARB = 0;
PFNGLUNIFORM3UI64VNVPROC glUniform3ui64vNV = 0;
PFNGLUNIFORM3UIEXTPROC glUniform3uiEXT = 0;
PFNGLUNIFORM3UIVPROC glUniform3uiv = 0;
PFNGLUNIFORM3UIVEXTPROC glUniform3uivEXT = 0;
PFNGLUNIFORM4DPROC glUniform4d = 0;
PFNGLUNIFORM4DVPROC glUniform4dv = 0;
PFNGLUNIFORM4FPROC glUniform4f = 0;
PFNGLUNIFORM4FARBPROC glUniform4fARB = 0;
PFNGLUNIFORM4FVPROC glUniform4fv = 0;
PFNGLUNIFORM4FVARBPROC glUniform4fvARB = 0;
PFNGLUNIFORM4IPROC glUniform4i = 0;
PFNGLUNIFORM4I64ARBPROC glUniform4i64ARB = 0;
PFNGLUNIFORM4I64NVPROC glUniform4i64NV = 0;
PFNGLUNIFORM4I64VARBPROC glUniform4i64vARB = 0;
PFNGLUNIFORM4I64VNVPROC glUniform4i64vNV = 0;
PFNGLUNIFORM4IARBPROC glUniform4iARB = 0;
PFNGLUNIFORM4IVPROC glUniform4iv = 0;
PFNGLUNIFORM4IVARBPROC glUniform4ivARB = 0;
PFNGLUNIFORM4UIPROC glUniform4ui = 0;
PFNGLUNIFORM4UI64ARBPROC glUniform4ui64ARB = 0;
PFNGLUNIFORM4UI64NVPROC glUniform4ui64NV = 0;
PFNGLUNIFORM4UI64VARBPROC glUniform4ui64vARB = 0;
PFNGLUNIFORM4UI64VNVPROC glUniform4ui64vNV = 0;
PFNGLUNIFORM4UIEXTPROC glUniform4uiEXT = 0;
PFNGLUNIFORM4UIVPROC glUniform4uiv = 0;
PFNGLUNIFORM4UIVEXTPROC glUniform4uivEXT = 0;
PFNGLUNIFORMBLOCKBINDINGPROC glUniformBlockBinding = 0;
PFNGLUNIFORMBUFFEREXTPROC glUniformBufferEXT = 0;
PFNGLUNIFORMHANDLEUI64ARBPROC glUniformHandleui64ARB = 0;
PFNGLUNIFORMHANDLEUI64IMGPROC glUniformHandleui64IMG = 0;
PFNGLUNIFORMHANDLEUI64NVPROC glUniformHandleui64NV = 0;
PFNGLUNIFORMHANDLEUI64VARBPROC glUniformHandleui64vARB = 0;
PFNGLUNIFORMHANDLEUI64VIMGPROC glUniformHandleui64vIMG = 0;
PFNGLUNIFORMHANDLEUI64VNVPROC glUniformHandleui64vNV = 0;
PFNGLUNIFORMMATRIX2DVPROC glUniformMatrix2dv = 0;
PFNGLUNIFORMMATRIX2FVPROC glUniformMatrix2fv = 0;
PFNGLUNIFORMMATRIX2FVARBPROC glUniformMatrix2fvARB = 0;
PFNGLUNIFORMMATRIX2X3DVPROC glUniformMatrix2x3dv = 0;
PFNGLUNIFORMMATRIX2X3FVPROC glUniformMatrix2x3fv = 0;
PFNGLUNIFORMMATRIX2X3FVNVPROC glUniformMatrix2x3fvNV = 0;
PFNGLUNIFORMMATRIX2X4DVPROC glUniformMatrix2x4dv = 0;
PFNGLUNIFORMMATRIX2X4FVPROC glUniformMatrix2x4fv = 0;
PFNGLUNIFORMMATRIX2X4FVNVPROC glUniformMatrix2x4fvNV = 0;
PFNGLUNIFORMMATRIX3DVPROC glUniformMatrix3dv = 0;
PFNGLUNIFORMMATRIX3FVPROC glUniformMatrix3fv = 0;
PFNGLUNIFORMMATRIX3FVARBPROC glUniformMatrix3fvARB = 0;
PFNGLUNIFORMMATRIX3X2DVPROC glUniformMatrix3x2dv = 0;
PFNGLUNIFORMMATRIX3X2FVPROC glUniformMatrix3x2fv = 0;
PFNGLUNIFORMMATRIX3X2FVNVPROC glUniformMatrix3x2fvNV = 0;
PFNGLUNIFORMMATRIX3X4DVPROC glUniformMatrix3x4dv = 0;
PFNGLUNIFORMMATRIX3X4FVPROC glUniformMatrix3x4fv = 0;
PFNGLUNIFORMMATRIX3X4FVNVPROC glUniformMatrix3x4fvNV = 0;
PFNGLUNIFORMMATRIX4DVPROC glUniformMatrix4dv = 0;
PFNGLUNIFORMMATRIX4FVPROC glUniformMatrix4fv = 0;
PFNGLUNIFORMMATRIX4FVARBPROC glUniformMatrix4fvARB = 0;
PFNGLUNIFORMMATRIX4X2DVPROC glUniformMatrix4x2dv = 0;
PFNGLUNIFORMMATRIX4X2FVPROC glUniformMatrix4x2fv = 0;
PFNGLUNIFORMMATRIX4X2FVNVPROC glUniformMatrix4x2fvNV = 0;
PFNGLUNIFORMMATRIX4X3DVPROC glUniformMatrix4x3dv = 0;
PFNGLUNIFORMMATRIX4X3FVPROC glUniformMatrix4x3fv = 0;
PFNGLUNIFORMMATRIX4X3FVNVPROC glUniformMatrix4x3fvNV = 0;
PFNGLUNIFORMSUBROUTINESUIVPROC glUniformSubroutinesuiv = 0;
PFNGLUNIFORMUI64NVPROC glUniformui64NV = 0;
PFNGLUNIFORMUI64VNVPROC glUniformui64vNV = 0;
PFNGLUNLOCKARRAYSEXTPROC glUnlockArraysEXT = 0;
PFNGLUNMAPBUFFERPROC glUnmapBuffer = 0;
PFNGLUNMAPBUFFERARBPROC glUnmapBufferARB = 0;
PFNGLUNMAPBUFFEROESPROC glUnmapBufferOES = 0;
PFNGLUNMAPNAMEDBUFFERPROC glUnmapNamedBuffer = 0;
PFNGLUNMAPNAMEDBUFFEREXTPROC glUnmapNamedBufferEXT = 0;
PFNGLUNMAPOBJECTBUFFERATIPROC glUnmapObjectBufferATI = 0;
PFNGLUNMAPTEXTURE2DINTELPROC glUnmapTexture2DINTEL = 0;
PFNGLUPDATEOBJECTBUFFERATIPROC glUpdateObjectBufferATI = 0;
PFNGLUPLOADGPUMASKNVXPROC glUploadGpuMaskNVX = 0;
PFNGLUSEPROGRAMPROC glUseProgram = 0;
PFNGLUSEPROGRAMOBJECTARBPROC glUseProgramObjectARB = 0;
PFNGLUSEPROGRAMSTAGESPROC glUseProgramStages = 0;
PFNGLUSEPROGRAMSTAGESEXTPROC glUseProgramStagesEXT = 0;
PFNGLUSESHADERPROGRAMEXTPROC glUseShaderProgramEXT = 0;
PFNGLVDPAUFININVPROC glVDPAUFiniNV = 0;
PFNGLVDPAUGETSURFACEIVNVPROC glVDPAUGetSurfaceivNV = 0;
PFNGLVDPAUINITNVPROC glVDPAUInitNV = 0;
PFNGLVDPAUISSURFACENVPROC glVDPAUIsSurfaceNV = 0;
PFNGLVDPAUMAPSURFACESNVPROC glVDPAUMapSurfacesNV = 0;
PFNGLVDPAUREGISTEROUTPUTSURFACENVPROC glVDPAURegisterOutputSurfaceNV = 0;
PFNGLVDPAUREGISTERVIDEOSURFACENVPROC glVDPAURegisterVideoSurfaceNV = 0;
PFNGLVDPAUREGISTERVIDEOSURFACEWITHPICTURESTRUCTURENVPROC glVDPAURegisterVideoSurfaceWithPictureStructureNV = 0;
PFNGLVDPAUSURFACEACCESSNVPROC glVDPAUSurfaceAccessNV = 0;
PFNGLVDPAUUNMAPSURFACESNVPROC glVDPAUUnmapSurfacesNV = 0;
PFNGLVDPAUUNREGISTERSURFACENVPROC glVDPAUUnregisterSurfaceNV = 0;
PFNGLVALIDATEPROGRAMPROC glValidateProgram = 0;
PFNGLVALIDATEPROGRAMARBPROC glValidateProgramARB = 0;
PFNGLVALIDATEPROGRAMPIPELINEPROC glValidateProgramPipeline = 0;
PFNGLVALIDATEPROGRAMPIPELINEEXTPROC glValidateProgramPipelineEXT = 0;
PFNGLVARIANTARRAYOBJECTATIPROC glVariantArrayObjectATI = 0;
PFNGLVARIANTPOINTEREXTPROC glVariantPointerEXT = 0;
PFNGLVARIANTBVEXTPROC glVariantbvEXT = 0;
PFNGLVARIANTDVEXTPROC glVariantdvEXT = 0;
PFNGLVARIANTFVEXTPROC glVariantfvEXT = 0;
PFNGLVARIANTIVEXTPROC glVariantivEXT = 0;
PFNGLVARIANTSVEXTPROC glVariantsvEXT = 0;
PFNGLVARIANTUBVEXTPROC glVariantubvEXT = 0;
PFNGLVARIANTUIVEXTPROC glVariantuivEXT = 0;
PFNGLVARIANTUSVEXTPROC glVariantusvEXT = 0;
PFNGLVERTEX2BOESPROC glVertex2bOES = 0;
PFNGLVERTEX2BVOESPROC glVertex2bvOES = 0;
PFNGLVERTEX2DPROC glVertex2d = 0;
PFNGLVERTEX2DVPROC glVertex2dv = 0;
PFNGLVERTEX2FPROC glVertex2f = 0;
PFNGLVERTEX2FVPROC glVertex2fv = 0;
PFNGLVERTEX2HNVPROC glVertex2hNV = 0;
PFNGLVERTEX2HVNVPROC glVertex2hvNV = 0;
PFNGLVERTEX2IPROC glVertex2i = 0;
PFNGLVERTEX2IVPROC glVertex2iv = 0;
PFNGLVERTEX2SPROC glVertex2s = 0;
PFNGLVERTEX2SVPROC glVertex2sv = 0;
PFNGLVERTEX2XOESPROC glVertex2xOES = 0;
PFNGLVERTEX2XVOESPROC glVertex2xvOES = 0;
PFNGLVERTEX3BOESPROC glVertex3bOES = 0;
PFNGLVERTEX3BVOESPROC glVertex3bvOES = 0;
PFNGLVERTEX3DPROC glVertex3d = 0;
PFNGLVERTEX3DVPROC glVertex3dv = 0;
PFNGLVERTEX3FPROC glVertex3f = 0;
PFNGLVERTEX3FVPROC glVertex3fv = 0;
PFNGLVERTEX3HNVPROC glVertex3hNV = 0;
PFNGLVERTEX3HVNVPROC glVertex3hvNV = 0;
PFNGLVERTEX3IPROC glVertex3i = 0;
PFNGLVERTEX3IVPROC glVertex3iv = 0;
PFNGLVERTEX3SPROC glVertex3s = 0;
PFNGLVERTEX3SVPROC glVertex3sv = 0;
PFNGLVERTEX3XOESPROC glVertex3xOES = 0;
PFNGLVERTEX3XVOESPROC glVertex3xvOES = 0;
PFNGLVERTEX4BOESPROC glVertex4bOES = 0;
PFNGLVERTEX4BVOESPROC glVertex4bvOES = 0;
PFNGLVERTEX4DPROC glVertex4d = 0;
PFNGLVERTEX4DVPROC glVertex4dv = 0;
PFNGLVERTEX4FPROC glVertex4f = 0;
PFNGLVERTEX4FVPROC glVertex4fv = 0;
PFNGLVERTEX4HNVPROC glVertex4hNV = 0;
PFNGLVERTEX4HVNVPROC glVertex4hvNV = 0;
PFNGLVERTEX4IPROC glVertex4i = 0;
PFNGLVERTEX4IVPROC glVertex4iv = 0;
PFNGLVERTEX4SPROC glVertex4s = 0;
PFNGLVERTEX4SVPROC glVertex4sv = 0;
PFNGLVERTEX4XOESPROC glVertex4xOES = 0;
PFNGLVERTEX4XVOESPROC glVertex4xvOES = 0;
PFNGLVERTEXARRAYATTRIBBINDINGPROC glVertexArrayAttribBinding = 0;
PFNGLVERTEXARRAYATTRIBFORMATPROC glVertexArrayAttribFormat = 0;
PFNGLVERTEXARRAYATTRIBIFORMATPROC glVertexArrayAttribIFormat = 0;
PFNGLVERTEXARRAYATTRIBLFORMATPROC glVertexArrayAttribLFormat = 0;
PFNGLVERTEXARRAYBINDVERTEXBUFFEREXTPROC glVertexArrayBindVertexBufferEXT = 0;
PFNGLVERTEXARRAYBINDINGDIVISORPROC glVertexArrayBindingDivisor = 0;
PFNGLVERTEXARRAYCOLOROFFSETEXTPROC glVertexArrayColorOffsetEXT = 0;
PFNGLVERTEXARRAYEDGEFLAGOFFSETEXTPROC glVertexArrayEdgeFlagOffsetEXT = 0;
PFNGLVERTEXARRAYELEMENTBUFFERPROC glVertexArrayElementBuffer = 0;
PFNGLVERTEXARRAYFOGCOORDOFFSETEXTPROC glVertexArrayFogCoordOffsetEXT = 0;
PFNGLVERTEXARRAYINDEXOFFSETEXTPROC glVertexArrayIndexOffsetEXT = 0;
PFNGLVERTEXARRAYMULTITEXCOORDOFFSETEXTPROC glVertexArrayMultiTexCoordOffsetEXT = 0;
PFNGLVERTEXARRAYNORMALOFFSETEXTPROC glVertexArrayNormalOffsetEXT = 0;
PFNGLVERTEXARRAYPARAMETERIAPPLEPROC glVertexArrayParameteriAPPLE = 0;
PFNGLVERTEXARRAYRANGEAPPLEPROC glVertexArrayRangeAPPLE = 0;
PFNGLVERTEXARRAYRANGENVPROC glVertexArrayRangeNV = 0;
PFNGLVERTEXARRAYSECONDARYCOLOROFFSETEXTPROC glVertexArraySecondaryColorOffsetEXT = 0;
PFNGLVERTEXARRAYTEXCOORDOFFSETEXTPROC glVertexArrayTexCoordOffsetEXT = 0;
PFNGLVERTEXARRAYVERTEXATTRIBBINDINGEXTPROC glVertexArrayVertexAttribBindingEXT = 0;
PFNGLVERTEXARRAYVERTEXATTRIBDIVISOREXTPROC glVertexArrayVertexAttribDivisorEXT = 0;
PFNGLVERTEXARRAYVERTEXATTRIBFORMATEXTPROC glVertexArrayVertexAttribFormatEXT = 0;
PFNGLVERTEXARRAYVERTEXATTRIBIFORMATEXTPROC glVertexArrayVertexAttribIFormatEXT = 0;
PFNGLVERTEXARRAYVERTEXATTRIBIOFFSETEXTPROC glVertexArrayVertexAttribIOffsetEXT = 0;
PFNGLVERTEXARRAYVERTEXATTRIBLFORMATEXTPROC glVertexArrayVertexAttribLFormatEXT = 0;
PFNGLVERTEXARRAYVERTEXATTRIBLOFFSETEXTPROC glVertexArrayVertexAttribLOffsetEXT = 0;
PFNGLVERTEXARRAYVERTEXATTRIBOFFSETEXTPROC glVertexArrayVertexAttribOffsetEXT = 0;
PFNGLVERTEXARRAYVERTEXBINDINGDIVISOREXTPROC glVertexArrayVertexBindingDivisorEXT = 0;
PFNGLVERTEXARRAYVERTEXBUFFERPROC glVertexArrayVertexBuffer = 0;
PFNGLVERTEXARRAYVERTEXBUFFERSPROC glVertexArrayVertexBuffers = 0;
PFNGLVERTEXARRAYVERTEXOFFSETEXTPROC glVertexArrayVertexOffsetEXT = 0;
PFNGLVERTEXATTRIB1DPROC glVertexAttrib1d = 0;
PFNGLVERTEXATTRIB1DARBPROC glVertexAttrib1dARB = 0;
PFNGLVERTEXATTRIB1DNVPROC glVertexAttrib1dNV = 0;
PFNGLVERTEXATTRIB1DVPROC glVertexAttrib1dv = 0;
PFNGLVERTEXATTRIB1DVARBPROC glVertexAttrib1dvARB = 0;
PFNGLVERTEXATTRIB1DVNVPROC glVertexAttrib1dvNV = 0;
PFNGLVERTEXATTRIB1FPROC glVertexAttrib1f = 0;
PFNGLVERTEXATTRIB1FARBPROC glVertexAttrib1fARB = 0;
PFNGLVERTEXATTRIB1FNVPROC glVertexAttrib1fNV = 0;
PFNGLVERTEXATTRIB1FVPROC glVertexAttrib1fv = 0;
PFNGLVERTEXATTRIB1FVARBPROC glVertexAttrib1fvARB = 0;
PFNGLVERTEXATTRIB1FVNVPROC glVertexAttrib1fvNV = 0;
PFNGLVERTEXATTRIB1HNVPROC glVertexAttrib1hNV = 0;
PFNGLVERTEXATTRIB1HVNVPROC glVertexAttrib1hvNV = 0;
PFNGLVERTEXATTRIB1SPROC glVertexAttrib1s = 0;
PFNGLVERTEXATTRIB1SARBPROC glVertexAttrib1sARB = 0;
PFNGLVERTEXATTRIB1SNVPROC glVertexAttrib1sNV = 0;
PFNGLVERTEXATTRIB1SVPROC glVertexAttrib1sv = 0;
PFNGLVERTEXATTRIB1SVARBPROC glVertexAttrib1svARB = 0;
PFNGLVERTEXATTRIB1SVNVPROC glVertexAttrib1svNV = 0;
PFNGLVERTEXATTRIB2DPROC glVertexAttrib2d = 0;
PFNGLVERTEXATTRIB2DARBPROC glVertexAttrib2dARB = 0;
PFNGLVERTEXATTRIB2DNVPROC glVertexAttrib2dNV = 0;
PFNGLVERTEXATTRIB2DVPROC glVertexAttrib2dv = 0;
PFNGLVERTEXATTRIB2DVARBPROC glVertexAttrib2dvARB = 0;
PFNGLVERTEXATTRIB2DVNVPROC glVertexAttrib2dvNV = 0;
PFNGLVERTEXATTRIB2FPROC glVertexAttrib2f = 0;
PFNGLVERTEXATTRIB2FARBPROC glVertexAttrib2fARB = 0;
PFNGLVERTEXATTRIB2FNVPROC glVertexAttrib2fNV = 0;
PFNGLVERTEXATTRIB2FVPROC glVertexAttrib2fv = 0;
PFNGLVERTEXATTRIB2FVARBPROC glVertexAttrib2fvARB = 0;
PFNGLVERTEXATTRIB2FVNVPROC glVertexAttrib2fvNV = 0;
PFNGLVERTEXATTRIB2HNVPROC glVertexAttrib2hNV = 0;
PFNGLVERTEXATTRIB2HVNVPROC glVertexAttrib2hvNV = 0;
PFNGLVERTEXATTRIB2SPROC glVertexAttrib2s = 0;
PFNGLVERTEXATTRIB2SARBPROC glVertexAttrib2sARB = 0;
PFNGLVERTEXATTRIB2SNVPROC glVertexAttrib2sNV = 0;
PFNGLVERTEXATTRIB2SVPROC glVertexAttrib2sv = 0;
PFNGLVERTEXATTRIB2SVARBPROC glVertexAttrib2svARB = 0;
PFNGLVERTEXATTRIB2SVNVPROC glVertexAttrib2svNV = 0;
PFNGLVERTEXATTRIB3DPROC glVertexAttrib3d = 0;
PFNGLVERTEXATTRIB3DARBPROC glVertexAttrib3dARB = 0;
PFNGLVERTEXATTRIB3DNVPROC glVertexAttrib3dNV = 0;
PFNGLVERTEXATTRIB3DVPROC glVertexAttrib3dv = 0;
PFNGLVERTEXATTRIB3DVARBPROC glVertexAttrib3dvARB = 0;
PFNGLVERTEXATTRIB3DVNVPROC glVertexAttrib3dvNV = 0;
PFNGLVERTEXATTRIB3FPROC glVertexAttrib3f = 0;
PFNGLVERTEXATTRIB3FARBPROC glVertexAttrib3fARB = 0;
PFNGLVERTEXATTRIB3FNVPROC glVertexAttrib3fNV = 0;
PFNGLVERTEXATTRIB3FVPROC glVertexAttrib3fv = 0;
PFNGLVERTEXATTRIB3FVARBPROC glVertexAttrib3fvARB = 0;
PFNGLVERTEXATTRIB3FVNVPROC glVertexAttrib3fvNV = 0;
PFNGLVERTEXATTRIB3HNVPROC glVertexAttrib3hNV = 0;
PFNGLVERTEXATTRIB3HVNVPROC glVertexAttrib3hvNV = 0;
PFNGLVERTEXATTRIB3SPROC glVertexAttrib3s = 0;
PFNGLVERTEXATTRIB3SARBPROC glVertexAttrib3sARB = 0;
PFNGLVERTEXATTRIB3SNVPROC glVertexAttrib3sNV = 0;
PFNGLVERTEXATTRIB3SVPROC glVertexAttrib3sv = 0;
PFNGLVERTEXATTRIB3SVARBPROC glVertexAttrib3svARB = 0;
PFNGLVERTEXATTRIB3SVNVPROC glVertexAttrib3svNV = 0;
PFNGLVERTEXATTRIB4NBVPROC glVertexAttrib4Nbv = 0;
PFNGLVERTEXATTRIB4NBVARBPROC glVertexAttrib4NbvARB = 0;
PFNGLVERTEXATTRIB4NIVPROC glVertexAttrib4Niv = 0;
PFNGLVERTEXATTRIB4NIVARBPROC glVertexAttrib4NivARB = 0;
PFNGLVERTEXATTRIB4NSVPROC glVertexAttrib4Nsv = 0;
PFNGLVERTEXATTRIB4NSVARBPROC glVertexAttrib4NsvARB = 0;
PFNGLVERTEXATTRIB4NUBPROC glVertexAttrib4Nub = 0;
PFNGLVERTEXATTRIB4NUBARBPROC glVertexAttrib4NubARB = 0;
PFNGLVERTEXATTRIB4NUBVPROC glVertexAttrib4Nubv = 0;
PFNGLVERTEXATTRIB4NUBVARBPROC glVertexAttrib4NubvARB = 0;
PFNGLVERTEXATTRIB4NUIVPROC glVertexAttrib4Nuiv = 0;
PFNGLVERTEXATTRIB4NUIVARBPROC glVertexAttrib4NuivARB = 0;
PFNGLVERTEXATTRIB4NUSVPROC glVertexAttrib4Nusv = 0;
PFNGLVERTEXATTRIB4NUSVARBPROC glVertexAttrib4NusvARB = 0;
PFNGLVERTEXATTRIB4BVPROC glVertexAttrib4bv = 0;
PFNGLVERTEXATTRIB4BVARBPROC glVertexAttrib4bvARB = 0;
PFNGLVERTEXATTRIB4DPROC glVertexAttrib4d = 0;
PFNGLVERTEXATTRIB4DARBPROC glVertexAttrib4dARB = 0;
PFNGLVERTEXATTRIB4DNVPROC glVertexAttrib4dNV = 0;
PFNGLVERTEXATTRIB4DVPROC glVertexAttrib4dv = 0;
PFNGLVERTEXATTRIB4DVARBPROC glVertexAttrib4dvARB = 0;
PFNGLVERTEXATTRIB4DVNVPROC glVertexAttrib4dvNV = 0;
PFNGLVERTEXATTRIB4FPROC glVertexAttrib4f = 0;
PFNGLVERTEXATTRIB4FARBPROC glVertexAttrib4fARB = 0;
PFNGLVERTEXATTRIB4FNVPROC glVertexAttrib4fNV = 0;
PFNGLVERTEXATTRIB4FVPROC glVertexAttrib4fv = 0;
PFNGLVERTEXATTRIB4FVARBPROC glVertexAttrib4fvARB = 0;
PFNGLVERTEXATTRIB4FVNVPROC glVertexAttrib4fvNV = 0;
PFNGLVERTEXATTRIB4HNVPROC glVertexAttrib4hNV = 0;
PFNGLVERTEXATTRIB4HVNVPROC glVertexAttrib4hvNV = 0;
PFNGLVERTEXATTRIB4IVPROC glVertexAttrib4iv = 0;
PFNGLVERTEXATTRIB4IVARBPROC glVertexAttrib4ivARB = 0;
PFNGLVERTEXATTRIB4SPROC glVertexAttrib4s = 0;
PFNGLVERTEXATTRIB4SARBPROC glVertexAttrib4sARB = 0;
PFNGLVERTEXATTRIB4SNVPROC glVertexAttrib4sNV = 0;
PFNGLVERTEXATTRIB4SVPROC glVertexAttrib4sv = 0;
PFNGLVERTEXATTRIB4SVARBPROC glVertexAttrib4svARB = 0;
PFNGLVERTEXATTRIB4SVNVPROC glVertexAttrib4svNV = 0;
PFNGLVERTEXATTRIB4UBNVPROC glVertexAttrib4ubNV = 0;
PFNGLVERTEXATTRIB4UBVPROC glVertexAttrib4ubv = 0;
PFNGLVERTEXATTRIB4UBVARBPROC glVertexAttrib4ubvARB = 0;
PFNGLVERTEXATTRIB4UBVNVPROC glVertexAttrib4ubvNV = 0;
PFNGLVERTEXATTRIB4UIVPROC glVertexAttrib4uiv = 0;
PFNGLVERTEXATTRIB4UIVARBPROC glVertexAttrib4uivARB = 0;
PFNGLVERTEXATTRIB4USVPROC glVertexAttrib4usv = 0;
PFNGLVERTEXATTRIB4USVARBPROC glVertexAttrib4usvARB = 0;
PFNGLVERTEXATTRIBARRAYOBJECTATIPROC glVertexAttribArrayObjectATI = 0;
PFNGLVERTEXATTRIBBINDINGPROC glVertexAttribBinding = 0;
PFNGLVERTEXATTRIBDIVISORPROC glVertexAttribDivisor = 0;
PFNGLVERTEXATTRIBDIVISORANGLEPROC glVertexAttribDivisorANGLE = 0;
PFNGLVERTEXATTRIBDIVISORARBPROC glVertexAttribDivisorARB = 0;
PFNGLVERTEXATTRIBDIVISOREXTPROC glVertexAttribDivisorEXT = 0;
PFNGLVERTEXATTRIBDIVISORNVPROC glVertexAttribDivisorNV = 0;
PFNGLVERTEXATTRIBFORMATPROC glVertexAttribFormat = 0;
PFNGLVERTEXATTRIBFORMATNVPROC glVertexAttribFormatNV = 0;
PFNGLVERTEXATTRIBI1IPROC glVertexAttribI1i = 0;
PFNGLVERTEXATTRIBI1IEXTPROC glVertexAttribI1iEXT = 0;
PFNGLVERTEXATTRIBI1IVPROC glVertexAttribI1iv = 0;
PFNGLVERTEXATTRIBI1IVEXTPROC glVertexAttribI1ivEXT = 0;
PFNGLVERTEXATTRIBI1UIPROC glVertexAttribI1ui = 0;
PFNGLVERTEXATTRIBI1UIEXTPROC glVertexAttribI1uiEXT = 0;
PFNGLVERTEXATTRIBI1UIVPROC glVertexAttribI1uiv = 0;
PFNGLVERTEXATTRIBI1UIVEXTPROC glVertexAttribI1uivEXT = 0;
PFNGLVERTEXATTRIBI2IPROC glVertexAttribI2i = 0;
PFNGLVERTEXATTRIBI2IEXTPROC glVertexAttribI2iEXT = 0;
PFNGLVERTEXATTRIBI2IVPROC glVertexAttribI2iv = 0;
PFNGLVERTEXATTRIBI2IVEXTPROC glVertexAttribI2ivEXT = 0;
PFNGLVERTEXATTRIBI2UIPROC glVertexAttribI2ui = 0;
PFNGLVERTEXATTRIBI2UIEXTPROC glVertexAttribI2uiEXT = 0;
PFNGLVERTEXATTRIBI2UIVPROC glVertexAttribI2uiv = 0;
PFNGLVERTEXATTRIBI2UIVEXTPROC glVertexAttribI2uivEXT = 0;
PFNGLVERTEXATTRIBI3IPROC glVertexAttribI3i = 0;
PFNGLVERTEXATTRIBI3IEXTPROC glVertexAttribI3iEXT = 0;
PFNGLVERTEXATTRIBI3IVPROC glVertexAttribI3iv = 0;
PFNGLVERTEXATTRIBI3IVEXTPROC glVertexAttribI3ivEXT = 0;
PFNGLVERTEXATTRIBI3UIPROC glVertexAttribI3ui = 0;
PFNGLVERTEXATTRIBI3UIEXTPROC glVertexAttribI3uiEXT = 0;
PFNGLVERTEXATTRIBI3UIVPROC glVertexAttribI3uiv = 0;
PFNGLVERTEXATTRIBI3UIVEXTPROC glVertexAttribI3uivEXT = 0;
PFNGLVERTEXATTRIBI4BVPROC glVertexAttribI4bv = 0;
PFNGLVERTEXATTRIBI4BVEXTPROC glVertexAttribI4bvEXT = 0;
PFNGLVERTEXATTRIBI4IPROC glVertexAttribI4i = 0;
PFNGLVERTEXATTRIBI4IEXTPROC glVertexAttribI4iEXT = 0;
PFNGLVERTEXATTRIBI4IVPROC glVertexAttribI4iv = 0;
PFNGLVERTEXATTRIBI4IVEXTPROC glVertexAttribI4ivEXT = 0;
PFNGLVERTEXATTRIBI4SVPROC glVertexAttribI4sv = 0;
PFNGLVERTEXATTRIBI4SVEXTPROC glVertexAttribI4svEXT = 0;
PFNGLVERTEXATTRIBI4UBVPROC glVertexAttribI4ubv = 0;
PFNGLVERTEXATTRIBI4UBVEXTPROC glVertexAttribI4ubvEXT = 0;
PFNGLVERTEXATTRIBI4UIPROC glVertexAttribI4ui = 0;
PFNGLVERTEXATTRIBI4UIEXTPROC glVertexAttribI4uiEXT = 0;
PFNGLVERTEXATTRIBI4UIVPROC glVertexAttribI4uiv = 0;
PFNGLVERTEXATTRIBI4UIVEXTPROC glVertexAttribI4uivEXT = 0;
PFNGLVERTEXATTRIBI4USVPROC glVertexAttribI4usv = 0;
PFNGLVERTEXATTRIBI4USVEXTPROC glVertexAttribI4usvEXT = 0;
PFNGLVERTEXATTRIBIFORMATPROC glVertexAttribIFormat = 0;
PFNGLVERTEXATTRIBIFORMATNVPROC glVertexAttribIFormatNV = 0;
PFNGLVERTEXATTRIBIPOINTERPROC glVertexAttribIPointer = 0;
PFNGLVERTEXATTRIBIPOINTEREXTPROC glVertexAttribIPointerEXT = 0;
PFNGLVERTEXATTRIBL1DPROC glVertexAttribL1d = 0;
PFNGLVERTEXATTRIBL1DEXTPROC glVertexAttribL1dEXT = 0;
PFNGLVERTEXATTRIBL1DVPROC glVertexAttribL1dv = 0;
PFNGLVERTEXATTRIBL1DVEXTPROC glVertexAttribL1dvEXT = 0;
PFNGLVERTEXATTRIBL1I64NVPROC glVertexAttribL1i64NV = 0;
PFNGLVERTEXATTRIBL1I64VNVPROC glVertexAttribL1i64vNV = 0;
PFNGLVERTEXATTRIBL1UI64ARBPROC glVertexAttribL1ui64ARB = 0;
PFNGLVERTEXATTRIBL1UI64NVPROC glVertexAttribL1ui64NV = 0;
PFNGLVERTEXATTRIBL1UI64VARBPROC glVertexAttribL1ui64vARB = 0;
PFNGLVERTEXATTRIBL1UI64VNVPROC glVertexAttribL1ui64vNV = 0;
PFNGLVERTEXATTRIBL2DPROC glVertexAttribL2d = 0;
PFNGLVERTEXATTRIBL2DEXTPROC glVertexAttribL2dEXT = 0;
PFNGLVERTEXATTRIBL2DVPROC glVertexAttribL2dv = 0;
PFNGLVERTEXATTRIBL2DVEXTPROC glVertexAttribL2dvEXT = 0;
PFNGLVERTEXATTRIBL2I64NVPROC glVertexAttribL2i64NV = 0;
PFNGLVERTEXATTRIBL2I64VNVPROC glVertexAttribL2i64vNV = 0;
PFNGLVERTEXATTRIBL2UI64NVPROC glVertexAttribL2ui64NV = 0;
PFNGLVERTEXATTRIBL2UI64VNVPROC glVertexAttribL2ui64vNV = 0;
PFNGLVERTEXATTRIBL3DPROC glVertexAttribL3d = 0;
PFNGLVERTEXATTRIBL3DEXTPROC glVertexAttribL3dEXT = 0;
PFNGLVERTEXATTRIBL3DVPROC glVertexAttribL3dv = 0;
PFNGLVERTEXATTRIBL3DVEXTPROC glVertexAttribL3dvEXT = 0;
PFNGLVERTEXATTRIBL3I64NVPROC glVertexAttribL3i64NV = 0;
PFNGLVERTEXATTRIBL3I64VNVPROC glVertexAttribL3i64vNV = 0;
PFNGLVERTEXATTRIBL3UI64NVPROC glVertexAttribL3ui64NV = 0;
PFNGLVERTEXATTRIBL3UI64VNVPROC glVertexAttribL3ui64vNV = 0;
PFNGLVERTEXATTRIBL4DPROC glVertexAttribL4d = 0;
PFNGLVERTEXATTRIBL4DEXTPROC glVertexAttribL4dEXT = 0;
PFNGLVERTEXATTRIBL4DVPROC glVertexAttribL4dv = 0;
PFNGLVERTEXATTRIBL4DVEXTPROC glVertexAttribL4dvEXT = 0;
PFNGLVERTEXATTRIBL4I64NVPROC glVertexAttribL4i64NV = 0;
PFNGLVERTEXATTRIBL4I64VNVPROC glVertexAttribL4i64vNV = 0;
PFNGLVERTEXATTRIBL4UI64NVPROC glVertexAttribL4ui64NV = 0;
PFNGLVERTEXATTRIBL4UI64VNVPROC glVertexAttribL4ui64vNV = 0;
PFNGLVERTEXATTRIBLFORMATPROC glVertexAttribLFormat = 0;
PFNGLVERTEXATTRIBLFORMATNVPROC glVertexAttribLFormatNV = 0;
PFNGLVERTEXATTRIBLPOINTERPROC glVertexAttribLPointer = 0;
PFNGLVERTEXATTRIBLPOINTEREXTPROC glVertexAttribLPointerEXT = 0;
PFNGLVERTEXATTRIBP1UIPROC glVertexAttribP1ui = 0;
PFNGLVERTEXATTRIBP1UIVPROC glVertexAttribP1uiv = 0;
PFNGLVERTEXATTRIBP2UIPROC glVertexAttribP2ui = 0;
PFNGLVERTEXATTRIBP2UIVPROC glVertexAttribP2uiv = 0;
PFNGLVERTEXATTRIBP3UIPROC glVertexAttribP3ui = 0;
PFNGLVERTEXATTRIBP3UIVPROC glVertexAttribP3uiv = 0;
PFNGLVERTEXATTRIBP4UIPROC glVertexAttribP4ui = 0;
PFNGLVERTEXATTRIBP4UIVPROC glVertexAttribP4uiv = 0;
PFNGLVERTEXATTRIBPARAMETERIAMDPROC glVertexAttribParameteriAMD = 0;
PFNGLVERTEXATTRIBPOINTERPROC glVertexAttribPointer = 0;
PFNGLVERTEXATTRIBPOINTERARBPROC glVertexAttribPointerARB = 0;
PFNGLVERTEXATTRIBPOINTERNVPROC glVertexAttribPointerNV = 0;
PFNGLVERTEXATTRIBS1DVNVPROC glVertexAttribs1dvNV = 0;
PFNGLVERTEXATTRIBS1FVNVPROC glVertexAttribs1fvNV = 0;
PFNGLVERTEXATTRIBS1HVNVPROC glVertexAttribs1hvNV = 0;
PFNGLVERTEXATTRIBS1SVNVPROC glVertexAttribs1svNV = 0;
PFNGLVERTEXATTRIBS2DVNVPROC glVertexAttribs2dvNV = 0;
PFNGLVERTEXATTRIBS2FVNVPROC glVertexAttribs2fvNV = 0;
PFNGLVERTEXATTRIBS2HVNVPROC glVertexAttribs2hvNV = 0;
PFNGLVERTEXATTRIBS2SVNVPROC glVertexAttribs2svNV = 0;
PFNGLVERTEXATTRIBS3DVNVPROC glVertexAttribs3dvNV = 0;
PFNGLVERTEXATTRIBS3FVNVPROC glVertexAttribs3fvNV = 0;
PFNGLVERTEXATTRIBS3HVNVPROC glVertexAttribs3hvNV = 0;
PFNGLVERTEXATTRIBS3SVNVPROC glVertexAttribs3svNV = 0;
PFNGLVERTEXATTRIBS4DVNVPROC glVertexAttribs4dvNV = 0;
PFNGLVERTEXATTRIBS4FVNVPROC glVertexAttribs4fvNV = 0;
PFNGLVERTEXATTRIBS4HVNVPROC glVertexAttribs4hvNV = 0;
PFNGLVERTEXATTRIBS4SVNVPROC glVertexAttribs4svNV = 0;
PFNGLVERTEXATTRIBS4UBVNVPROC glVertexAttribs4ubvNV = 0;
PFNGLVERTEXBINDINGDIVISORPROC glVertexBindingDivisor = 0;
PFNGLVERTEXBLENDARBPROC glVertexBlendARB = 0;
PFNGLVERTEXBLENDENVFATIPROC glVertexBlendEnvfATI = 0;
PFNGLVERTEXBLENDENVIATIPROC glVertexBlendEnviATI = 0;
PFNGLVERTEXFORMATNVPROC glVertexFormatNV = 0;
PFNGLVERTEXP2UIPROC glVertexP2ui = 0;
PFNGLVERTEXP2UIVPROC glVertexP2uiv = 0;
PFNGLVERTEXP3UIPROC glVertexP3ui = 0;
PFNGLVERTEXP3UIVPROC glVertexP3uiv = 0;
PFNGLVERTEXP4UIPROC glVertexP4ui = 0;
PFNGLVERTEXP4UIVPROC glVertexP4uiv = 0;
PFNGLVERTEXPOINTERPROC glVertexPointer = 0;
PFNGLVERTEXPOINTEREXTPROC glVertexPointerEXT = 0;
PFNGLVERTEXPOINTERLISTIBMPROC glVertexPointerListIBM = 0;
PFNGLVERTEXPOINTERVINTELPROC glVertexPointervINTEL = 0;
PFNGLVERTEXSTREAM1DATIPROC glVertexStream1dATI = 0;
PFNGLVERTEXSTREAM1DVATIPROC glVertexStream1dvATI = 0;
PFNGLVERTEXSTREAM1FATIPROC glVertexStream1fATI = 0;
PFNGLVERTEXSTREAM1FVATIPROC glVertexStream1fvATI = 0;
PFNGLVERTEXSTREAM1IATIPROC glVertexStream1iATI = 0;
PFNGLVERTEXSTREAM1IVATIPROC glVertexStream1ivATI = 0;
PFNGLVERTEXSTREAM1SATIPROC glVertexStream1sATI = 0;
PFNGLVERTEXSTREAM1SVATIPROC glVertexStream1svATI = 0;
PFNGLVERTEXSTREAM2DATIPROC glVertexStream2dATI = 0;
PFNGLVERTEXSTREAM2DVATIPROC glVertexStream2dvATI = 0;
PFNGLVERTEXSTREAM2FATIPROC glVertexStream2fATI = 0;
PFNGLVERTEXSTREAM2FVATIPROC glVertexStream2fvATI = 0;
PFNGLVERTEXSTREAM2IATIPROC glVertexStream2iATI = 0;
PFNGLVERTEXSTREAM2IVATIPROC glVertexStream2ivATI = 0;
PFNGLVERTEXSTREAM2SATIPROC glVertexStream2sATI = 0;
PFNGLVERTEXSTREAM2SVATIPROC glVertexStream2svATI = 0;
PFNGLVERTEXSTREAM3DATIPROC glVertexStream3dATI = 0;
PFNGLVERTEXSTREAM3DVATIPROC glVertexStream3dvATI = 0;
PFNGLVERTEXSTREAM3FATIPROC glVertexStream3fATI = 0;
PFNGLVERTEXSTREAM3FVATIPROC glVertexStream3fvATI = 0;
PFNGLVERTEXSTREAM3IATIPROC glVertexStream3iATI = 0;
PFNGLVERTEXSTREAM3IVATIPROC glVertexStream3ivATI = 0;
PFNGLVERTEXSTREAM3SATIPROC glVertexStream3sATI = 0;
PFNGLVERTEXSTREAM3SVATIPROC glVertexStream3svATI = 0;
PFNGLVERTEXSTREAM4DATIPROC glVertexStream4dATI = 0;
PFNGLVERTEXSTREAM4DVATIPROC glVertexStream4dvATI = 0;
PFNGLVERTEXSTREAM4FATIPROC glVertexStream4fATI = 0;
PFNGLVERTEXSTREAM4FVATIPROC glVertexStream4fvATI = 0;
PFNGLVERTEXSTREAM4IATIPROC glVertexStream4iATI = 0;
PFNGLVERTEXSTREAM4IVATIPROC glVertexStream4ivATI = 0;
PFNGLVERTEXSTREAM4SATIPROC glVertexStream4sATI = 0;
PFNGLVERTEXSTREAM4SVATIPROC glVertexStream4svATI = 0;
PFNGLVERTEXWEIGHTPOINTEREXTPROC glVertexWeightPointerEXT = 0;
PFNGLVERTEXWEIGHTFEXTPROC glVertexWeightfEXT = 0;
PFNGLVERTEXWEIGHTFVEXTPROC glVertexWeightfvEXT = 0;
PFNGLVERTEXWEIGHTHNVPROC glVertexWeighthNV = 0;
PFNGLVERTEXWEIGHTHVNVPROC glVertexWeighthvNV = 0;
PFNGLVIDEOCAPTURENVPROC glVideoCaptureNV = 0;
PFNGLVIDEOCAPTURESTREAMPARAMETERDVNVPROC glVideoCaptureStreamParameterdvNV = 0;
PFNGLVIDEOCAPTURESTREAMPARAMETERFVNVPROC glVideoCaptureStreamParameterfvNV = 0;
PFNGLVIDEOCAPTURESTREAMPARAMETERIVNVPROC glVideoCaptureStreamParameterivNV = 0;
PFNGLVIEWPORTPROC glViewport = 0;
PFNGLVIEWPORTARRAYVPROC glViewportArrayv = 0;
PFNGLVIEWPORTARRAYVNVPROC glViewportArrayvNV = 0;
PFNGLVIEWPORTARRAYVOESPROC glViewportArrayvOES = 0;
PFNGLVIEWPORTINDEXEDFPROC glViewportIndexedf = 0;
PFNGLVIEWPORTINDEXEDFOESPROC glViewportIndexedfOES = 0;
PFNGLVIEWPORTINDEXEDFNVPROC glViewportIndexedfNV = 0;
PFNGLVIEWPORTINDEXEDFVPROC glViewportIndexedfv = 0;
PFNGLVIEWPORTINDEXEDFVOESPROC glViewportIndexedfvOES = 0;
PFNGLVIEWPORTINDEXEDFVNVPROC glViewportIndexedfvNV = 0;
PFNGLVIEWPORTPOSITIONWSCALENVPROC glViewportPositionWScaleNV = 0;
PFNGLVIEWPORTSWIZZLENVPROC glViewportSwizzleNV = 0;
PFNGLWAITSEMAPHOREEXTPROC glWaitSemaphoreEXT = 0;
PFNGLWAITSEMAPHOREUI64NVXPROC glWaitSemaphoreui64NVX = 0;
PFNGLWAITSYNCPROC glWaitSync = 0;
PFNGLWAITSYNCAPPLEPROC glWaitSyncAPPLE = 0;
PFNGLWEIGHTPATHSNVPROC glWeightPathsNV = 0;
PFNGLWEIGHTPOINTERARBPROC glWeightPointerARB = 0;
PFNGLWEIGHTPOINTEROESPROC glWeightPointerOES = 0;
PFNGLWEIGHTBVARBPROC glWeightbvARB = 0;
PFNGLWEIGHTDVARBPROC glWeightdvARB = 0;
PFNGLWEIGHTFVARBPROC glWeightfvARB = 0;
PFNGLWEIGHTIVARBPROC glWeightivARB = 0;
PFNGLWEIGHTSVARBPROC glWeightsvARB = 0;
PFNGLWEIGHTUBVARBPROC glWeightubvARB = 0;
PFNGLWEIGHTUIVARBPROC glWeightuivARB = 0;
PFNGLWEIGHTUSVARBPROC glWeightusvARB = 0;
PFNGLWINDOWPOS2DPROC glWindowPos2d = 0;
PFNGLWINDOWPOS2DARBPROC glWindowPos2dARB = 0;
PFNGLWINDOWPOS2DMESAPROC glWindowPos2dMESA = 0;
PFNGLWINDOWPOS2DVPROC glWindowPos2dv = 0;
PFNGLWINDOWPOS2DVARBPROC glWindowPos2dvARB = 0;
PFNGLWINDOWPOS2DVMESAPROC glWindowPos2dvMESA = 0;
PFNGLWINDOWPOS2FPROC glWindowPos2f = 0;
PFNGLWINDOWPOS2FARBPROC glWindowPos2fARB = 0;
PFNGLWINDOWPOS2FMESAPROC glWindowPos2fMESA = 0;
PFNGLWINDOWPOS2FVPROC glWindowPos2fv = 0;
PFNGLWINDOWPOS2FVARBPROC glWindowPos2fvARB = 0;
PFNGLWINDOWPOS2FVMESAPROC glWindowPos2fvMESA = 0;
PFNGLWINDOWPOS2IPROC glWindowPos2i = 0;
PFNGLWINDOWPOS2IARBPROC glWindowPos2iARB = 0;
PFNGLWINDOWPOS2IMESAPROC glWindowPos2iMESA = 0;
PFNGLWINDOWPOS2IVPROC glWindowPos2iv = 0;
PFNGLWINDOWPOS2IVARBPROC glWindowPos2ivARB = 0;
PFNGLWINDOWPOS2IVMESAPROC glWindowPos2ivMESA = 0;
PFNGLWINDOWPOS2SPROC glWindowPos2s = 0;
PFNGLWINDOWPOS2SARBPROC glWindowPos2sARB = 0;
PFNGLWINDOWPOS2SMESAPROC glWindowPos2sMESA = 0;
PFNGLWINDOWPOS2SVPROC glWindowPos2sv = 0;
PFNGLWINDOWPOS2SVARBPROC glWindowPos2svARB = 0;
PFNGLWINDOWPOS2SVMESAPROC glWindowPos2svMESA = 0;
PFNGLWINDOWPOS3DPROC glWindowPos3d = 0;
PFNGLWINDOWPOS3DARBPROC glWindowPos3dARB = 0;
PFNGLWINDOWPOS3DMESAPROC glWindowPos3dMESA = 0;
PFNGLWINDOWPOS3DVPROC glWindowPos3dv = 0;
PFNGLWINDOWPOS3DVARBPROC glWindowPos3dvARB = 0;
PFNGLWINDOWPOS3DVMESAPROC glWindowPos3dvMESA = 0;
PFNGLWINDOWPOS3FPROC glWindowPos3f = 0;
PFNGLWINDOWPOS3FARBPROC glWindowPos3fARB = 0;
PFNGLWINDOWPOS3FMESAPROC glWindowPos3fMESA = 0;
PFNGLWINDOWPOS3FVPROC glWindowPos3fv = 0;
PFNGLWINDOWPOS3FVARBPROC glWindowPos3fvARB = 0;
PFNGLWINDOWPOS3FVMESAPROC glWindowPos3fvMESA = 0;
PFNGLWINDOWPOS3IPROC glWindowPos3i = 0;
PFNGLWINDOWPOS3IARBPROC glWindowPos3iARB = 0;
PFNGLWINDOWPOS3IMESAPROC glWindowPos3iMESA = 0;
PFNGLWINDOWPOS3IVPROC glWindowPos3iv = 0;
PFNGLWINDOWPOS3IVARBPROC glWindowPos3ivARB = 0;
PFNGLWINDOWPOS3IVMESAPROC glWindowPos3ivMESA = 0;
PFNGLWINDOWPOS3SPROC glWindowPos3s = 0;
PFNGLWINDOWPOS3SARBPROC glWindowPos3sARB = 0;
PFNGLWINDOWPOS3SMESAPROC glWindowPos3sMESA = 0;
PFNGLWINDOWPOS3SVPROC glWindowPos3sv = 0;
PFNGLWINDOWPOS3SVARBPROC glWindowPos3svARB = 0;
PFNGLWINDOWPOS3SVMESAPROC glWindowPos3svMESA = 0;
PFNGLWINDOWPOS4DMESAPROC glWindowPos4dMESA = 0;
PFNGLWINDOWPOS4DVMESAPROC glWindowPos4dvMESA = 0;
PFNGLWINDOWPOS4FMESAPROC glWindowPos4fMESA = 0;
PFNGLWINDOWPOS4FVMESAPROC glWindowPos4fvMESA = 0;
PFNGLWINDOWPOS4IMESAPROC glWindowPos4iMESA = 0;
PFNGLWINDOWPOS4IVMESAPROC glWindowPos4ivMESA = 0;
PFNGLWINDOWPOS4SMESAPROC glWindowPos4sMESA = 0;
PFNGLWINDOWPOS4SVMESAPROC glWindowPos4svMESA = 0;
PFNGLWINDOWRECTANGLESEXTPROC glWindowRectanglesEXT = 0;
PFNGLWRITEMASKEXTPROC glWriteMaskEXT = 0;
PFNGLDRAWVKIMAGENVPROC glDrawVkImageNV = 0;
PFNGLGETVKPROCADDRNVPROC glGetVkProcAddrNV = 0;
PFNGLWAITVKSEMAPHORENVPROC glWaitVkSemaphoreNV = 0;
PFNGLSIGNALVKSEMAPHORENVPROC glSignalVkSemaphoreNV = 0;
PFNGLSIGNALVKFENCENVPROC glSignalVkFenceNV = 0;
PFNGLFRAMEBUFFERPARAMETERIMESAPROC glFramebufferParameteriMESA = 0;
PFNGLGETFRAMEBUFFERPARAMETERIVMESAPROC glGetFramebufferParameterivMESA = 0;
